@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2009 - 2015 by Yurii Chernyi <terraninfo@terraninfo.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2009 - 2018 by Yurii Chernyi <terraninfo@terraninfo.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * @file
  */
 
-#include "contexts.hpp"
+#include "ai/composite/contexts.hpp"
 
 // =======================================================================
 namespace ai {
@@ -34,6 +34,9 @@ ai_context_proxy::~ai_context_proxy()
 }
 
 
+bool rca_context::is_offense_ = false;
+bool rca_context::is_defense_ = false;
+bool rca_context::strategy_set_ = false;
 rca_context::rca_context()
 {
 }
