@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2009 - 2015 by Yurii Chernyi <terraninfo@terraninfo.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2009 - 2018 by Yurii Chernyi <terraninfo@terraninfo.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,18 +16,17 @@
  * @file
  */
 
-#ifndef VALUE_TRANSLATOR_HPP_INCLUDED
-#define VALUE_TRANSLATOR_HPP_INCLUDED
+#pragma once
 
-#include "engine.hpp"
-#include "stage.hpp"
+#include "ai/composite/engine.hpp"
+#include "ai/composite/stage.hpp"
 
-#include "../manager.hpp"
-#include "../../terrain_filter.hpp"
-#include "../../util.hpp"
-#include "../../serialization/string_utils.hpp"
-#include "../../resources.hpp"
-#include "../lua/unit_advancements_aspect.hpp"
+#include "ai/manager.hpp"
+#include "terrain/filter.hpp"
+#include "lexical_cast.hpp"
+#include "serialization/string_utils.hpp"
+#include "resources.hpp"
+#include "ai/lua/aspect_advancements.hpp"
 
 namespace ai {
 
@@ -47,7 +46,7 @@ public:
 
 	static void value_to_cfg(const T &value, config &cfg)
 	{
-		cfg["value"] = str_cast(value);
+		cfg["value"] = lexical_cast<std::string>(value);
 	}
 
 	static config value_to_cfg(const T &value)
@@ -88,7 +87,7 @@ public:
 };
 
 template<>
-class config_value_translator< std::vector<std::string> > {
+class config_value_translator< std::vector<std::string>> {
 public:
 
 	static std::vector<std::string> cfg_to_value(const config &cfg)
@@ -145,33 +144,6 @@ public:
 	}
 };
 
-template<>
-class config_value_translator<ministage> {
-public:
-
-	static ministage cfg_to_value(const config &cfg)
-	{
-		return ministage(cfg.child_or_empty("value"));
-	}
-
-	static void cfg_to_value(const config &cfg, ministage &value)
-	{
-		value = cfg_to_value(cfg);
-	}
-
-	static void value_to_cfg(const ministage &value, config &cfg)
-	{
-		cfg.add_child("value",value.to_config());
-	}
-
-	static config value_to_cfg(const ministage &value)
-	{
-		config cfg;
-		value_to_cfg(value,cfg);
-		return cfg;
-	}
-};
-
 template<>
 class config_value_translator<terrain_filter> {
 public:
@@ -179,10 +151,10 @@ public:
 	static terrain_filter cfg_to_value(const config &cfg)
 	{
 		if (const config &v = cfg.child("value")) {
-			return terrain_filter(vconfig(v), *resources::units);
+			return terrain_filter(vconfig(v), resources::filter_con);
 		}
 		static config c("not");
-		return terrain_filter(vconfig(c),*resources::units);
+		return terrain_filter(vconfig(c),resources::filter_con);
 	}
 
 	static void cfg_to_value(const config &cfg, terrain_filter &value)
@@ -239,24 +211,24 @@ template<typename T>
 class variant_value_translator {
 public:
 
-	static void variant_to_value(const variant &/*var*/, T &/*value*/)
+	static void variant_to_value(const wfl::variant &/*var*/, T &/*value*/)
 	{
 	        assert(false);//not implemented
 	}
 
-	static void value_to_variant(const T &/*value*/, variant &/*var*/)
+	static void value_to_variant(const T &/*value*/, wfl::variant &/*var*/)
 	{
 		assert(false);//not implemented
 	}
 
-	static variant value_to_variant(const T &value)
+	static wfl::variant value_to_variant(const T &value)
 	{
-		variant var;
+		wfl::variant var;
 		value_to_variant(value,var);
 		return var;
 	}
 
-	static T variant_to_value(const variant &var)
+	static T variant_to_value(const wfl::variant &var)
 	{
 		T value = T();
 		variant_to_value(var,value);
@@ -264,56 +236,28 @@ public:
 	}
 };
 
-template<>
-class variant_value_translator<ministage> {
-public:
-
-	static void variant_to_value(const variant &/*var*/, ministage &/*value*/)
-	{
-	        assert(false);//not implemented
-	}
-
-	static void value_to_variant(const ministage &/*value*/, variant &/*var*/)
-	{
-		assert(false);//not implemented
-	}
-
-	static variant value_to_variant(const ministage &/*value*/)
-	{
-		assert(false);
-		return variant();
-	}
-
-	static ministage variant_to_value(const variant &/*var*/)
-	{
-		assert(false);
-		config cfg;
-		return ministage(cfg);
-	}
-};
-
 template<>
 class variant_value_translator<int> {
 public:
 
-	static void variant_to_value(const variant &var, int &value)
+	static void variant_to_value(const wfl::variant &var, int &value)
 	{
 	        value = var.as_int();
 	}
 
-	static void value_to_variant(const int &value, variant &var)
+	static void value_to_variant(const int &value, wfl::variant &var)
 	{
-		var = variant(value);
+		var = wfl::variant(value);
 	}
 
-	static variant value_to_variant(const int &value)
+	static wfl::variant value_to_variant(const int &value)
 	{
-		variant var;
+		wfl::variant var;
 		value_to_variant(value,var);
 		return var;
 	}
 
-	static int variant_to_value(const variant &var)
+	static int variant_to_value(const wfl::variant &var)
 	{
 		int value;
 		variant_to_value(var,value);
@@ -326,24 +270,24 @@ template<>
 class variant_value_translator<bool> {
 public:
 
-	static void variant_to_value(const variant &var, bool &value)
+	static void variant_to_value(const wfl::variant &var, bool &value)
 	{
 	        value = var.as_bool();
 	}
 
-	static void value_to_variant(const bool &value, variant &var)
+	static void value_to_variant(const bool &value, wfl::variant &var)
 	{
-		var = variant(value);
+		var = wfl::variant(value);
 	}
 
-	static variant value_to_variant(const bool &value)
+	static wfl::variant value_to_variant(const bool &value)
 	{
-		variant var;
+		wfl::variant var;
 		value_to_variant(value,var);
 		return var;
 	}
 
-	static bool variant_to_value(const variant &var)
+	static bool variant_to_value(const wfl::variant &var)
 	{
 		bool value;
 		variant_to_value(var,value);
@@ -357,24 +301,24 @@ template<>
 class variant_value_translator<std::string> {
 public:
 
-	static void variant_to_value(const variant &var, std::string &value)
+	static void variant_to_value(const wfl::variant &var, std::string &value)
 	{
 	        value = var.as_string();
 	}
 
-	static void value_to_variant(const std::string &value, variant &var)
+	static void value_to_variant(const std::string &value, wfl::variant &var)
 	{
-		var = variant(value);
+		var = wfl::variant(value);
 	}
 
-	static variant value_to_variant(const std::string &value)
+	static wfl::variant value_to_variant(const std::string &value)
 	{
-		variant var;
+		wfl::variant var;
 		value_to_variant(value,var);
 		return var;
 	}
 
-	static std::string variant_to_value(const variant &var)
+	static std::string variant_to_value(const wfl::variant &var)
 	{
 		std::string value;
 		variant_to_value(var,value);
@@ -388,28 +332,28 @@ template<>
 class variant_value_translator<attacks_vector> {
 public:
 
-	static void variant_to_value(const variant &/*var*/, attacks_vector &/*value*/)
+	static void variant_to_value(const wfl::variant &/*var*/, attacks_vector &/*value*/)
 	{
 		assert(false);//not implemented
 	}
 
-	static void value_to_variant(const attacks_vector &value, variant &var)
+	static void value_to_variant(const attacks_vector &value, wfl::variant &var)
 	{
-                std::vector<variant> vars;
+                std::vector<wfl::variant> vars;
                 for(attacks_vector::const_iterator i = value.begin(); i != value.end(); ++i) {
-                        vars.push_back(variant(new attack_analysis(*i)));
+                        vars.emplace_back(std::make_shared<attack_analysis>(*i));
                 }
-		var = variant(&vars);
+		var = wfl::variant(vars);
 	}
 
-	static variant value_to_variant(const attacks_vector &value)
+	static wfl::variant value_to_variant(const attacks_vector &value)
 	{
-		variant var;
+		wfl::variant var;
 		value_to_variant(value,var);
 		return var;
 	}
 
-	static attacks_vector variant_to_value(const variant &var)
+	static attacks_vector variant_to_value(const wfl::variant &var)
 	{
 		attacks_vector value;
 		variant_to_value(var,value);
@@ -422,31 +366,29 @@ template<>
 class variant_value_translator<terrain_filter> {
 public:
 
-	static void variant_to_value(const variant &/*var*/, terrain_filter &/*value*/)
+	static void variant_to_value(const wfl::variant &/*var*/, terrain_filter &/*value*/)
 	{
 	        assert(false);//not implemented
 	}
 
-	static void value_to_variant(const terrain_filter &/*value*/, variant &/*var*/)
+	static void value_to_variant(const terrain_filter &/*value*/, wfl::variant &/*var*/)
 	{
 		assert(false);//not implemented
 	}
 
-	static variant value_to_variant(const terrain_filter &value)
+	static wfl::variant value_to_variant(const terrain_filter &value)
 	{
-		variant var;
+		wfl::variant var;
 		value_to_variant(value,var);
 		return var;
 	}
 
-	static terrain_filter variant_to_value(const variant &var)
+	static terrain_filter variant_to_value(const wfl::variant &var)
 	{
 		static config c("not");
-		terrain_filter value(vconfig(c),*resources::units);
+		terrain_filter value(vconfig(c),resources::filter_con);
 		variant_to_value(var,value);
 		return value;
 	}
 };
 }  //end of namespace ai
-
-#endif
