@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2009 - 2015 by Yurii Chernyi <terraninfo@terraninfo.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2009 - 2018 by Yurii Chernyi <terraninfo@terraninfo.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,18 +17,9 @@
  * Stage which executes unit formulas
  * */
 
+#pragma once
 
-#ifndef AI_FORMULA_STAGE_UNIT_FORMULAS_HPP_INCLUDED
-#define AI_FORMULA_STAGE_UNIT_FORMULAS_HPP_INCLUDED
-
-#include "../composite/stage.hpp"
-
-
-#ifdef _MSC_VER
-#pragma warning(push)
-//silence "inherits via dominance" warnings
-#pragma warning(disable:4250)
-#endif
+#include "ai/composite/stage.hpp"
 
 namespace ai {
 
@@ -52,9 +43,3 @@ private:
 };
 
 } //end of namespace ai
-
-#ifdef _MSC_VER
-#pragma warning(pop)
-#endif
-
-#endif
