@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2010 - 2015 by Yurii Chernyi <terraninfo@terraninfo.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2010 - 2018 by Yurii Chernyi <terraninfo@terraninfo.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@
  * @file
  */
 
-#include "manager.hpp"
-#include "gamestate_observer.hpp"
+#include "ai/manager.hpp"
+#include "ai/gamestate_observer.hpp"
 
 namespace ai {
 // =======================================================================
@@ -27,13 +27,13 @@ namespace ai {
 gamestate_observer::gamestate_observer()
 	: gamestate_change_counter_(0)
 {
-	ai::manager::add_gamestate_observer(this);
+	ai::manager::get_singleton().add_gamestate_observer(this);
 }
 
 
 gamestate_observer::~gamestate_observer()
 {
-	ai::manager::remove_gamestate_observer(this);
+	ai::manager::get_singleton().remove_gamestate_observer(this);
 }
 
 
