@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2010 - 2015 by Yurii Chernyi <terraninfo@terraninfo.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2010 - 2018 by Yurii Chernyi <terraninfo@terraninfo.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,10 +17,9 @@
  * A helper class to observe the game state
  */
 
-#ifndef AI_GAMESTATE_OBSERVER_HPP_INCLUDED
-#define AI_GAMESTATE_OBSERVER_HPP_INCLUDED
+#pragma once
 
-#include "../generic_event.hpp"
+#include "generic_event.hpp"
 
 namespace ai {
 
@@ -55,5 +54,3 @@ private:
 };
 
 } //of namespace ai
-
-#endif
