@@ -1,6 +1,6 @@
 /*
- Copyright (C) 2010 - 2015 by Gabriel Morin <gabrielmorin (at) gmail (dot) com>
- Part of the Battle for Wesnoth Project http://www.wesnoth.org
+ Copyright (C) 2010 - 2018 by Gabriel Morin <gabrielmorin (at) gmail (dot) com>
+ Part of the Battle for Wesnoth Project https://www.wesnoth.org
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  * Arrows destined to be drawn on the map. Created for the whiteboard project.
  */
 
-#ifndef ARROW_HPP_INCLUDED
-#define ARROW_HPP_INCLUDED
+#pragma once
 
 #include "display.hpp"
 
@@ -27,10 +26,13 @@ typedef std::vector<map_location> arrow_path_t;
 /**
  * Arrows destined to be drawn on the map. Created for the whiteboard system.
  */
-class arrow : private boost::noncopyable {
+class arrow {
 
 public:
 
+	arrow(const arrow&) = delete;
+	arrow& operator=(const arrow&) = delete;
+
 	arrow(bool hidden = false);
 	virtual ~arrow();
 
@@ -38,7 +40,7 @@ public:
 	void hide();
 	void show();
 
-	virtual void set_path(arrow_path_t const& path);
+	virtual void set_path(const arrow_path_t& path);
 
 	///invalidates and clears the present path, forgets the previous path, clears the symbols map
 	virtual void reset();
@@ -46,9 +48,9 @@ public:
 	/**
 	 * The string color parameter is in the same format expected by the
 	 * image::locator modifiers parameter. Examples: red is "red" or "FF0000" or "255,0,0".
-	 * Feel free to add another method that accepts an Uint32 as a parameter instead.
+	 * Feel free to add another method that accepts an uint32_t as a parameter instead.
 	 */
-	virtual void set_color(std::string const& color);
+	virtual void set_color(const std::string& color);
 
 	virtual std::string get_color() const { return color_; }
 
@@ -58,26 +60,25 @@ public:
 	 * If it doesn't exist or has missing images, you'll get "under construction"
 	 * symbols instead of arrow graphics.
 	 */
-	typedef std::string STYLE;
-	STYLE get_style() {return style_;}
-	void set_style(std::string const& style);
+	std::string get_style() const {return style_;}
+	void set_style(const std::string& style);
 	///If you add more styles, you should look at move::update_arrow_style()
-	static std::string const STYLE_STANDARD;
-	static std::string const STYLE_HIGHLIGHTED;
-	static std::string const STYLE_FOCUS;
-	static std::string const STYLE_FOCUS_INVALID;
+	static const std::string STYLE_STANDARD;
+	static const std::string STYLE_HIGHLIGHTED;
+	static const std::string STYLE_FOCUS;
+	static const std::string STYLE_FOCUS_INVALID;
 
-	arrow_path_t const& get_path() const;
-	arrow_path_t const& get_previous_path() const;
+	const arrow_path_t& get_path() const;
+	const arrow_path_t& get_previous_path() const;
 
-	bool path_contains(map_location const& hex) const;
+	bool path_contains(const map_location& hex) const;
 
-	virtual void draw_hex(map_location const& hex);
+	virtual void draw_hex(const map_location& hex);
 
 	/// Checks that the path is not of length 0 or 1
-	static bool valid_path(arrow_path_t const& path);
+	static bool valid_path(const arrow_path_t& path);
 	/// Invalidates every hex along the given path
-	static void invalidate_arrow_path(arrow_path_t const& path);
+	static void invalidate_arrow_path(const arrow_path_t& path);
 
 	virtual void notify_arrow_changed();
 
@@ -89,7 +90,7 @@ protected:
 	 */
 	virtual void update_symbols();
 
-	display::tdrawing_layer layer_;
+	display::drawing_layer layer_;
 
 	std::string color_;
 	/// represents the subdirectory that holds images for this arrow style
@@ -103,4 +104,3 @@ protected:
 
 	bool hidden_;
 };
-#endif
