@@ -945,6 +945,10 @@ double prob_matrix::prob_of_zero(bool check_a, bool check_b) const
  */
 double prob_matrix::row_sum(unsigned plane, unsigned row) const
 {
+	if(!plane_used(plane)) {
+		return 0.0;
+	}
+
 	double sum = 0.0;
 	for(unsigned col : used_cols_[plane]) {
 		sum += val(plane, row, col);
@@ -957,6 +961,10 @@ double prob_matrix::row_sum(unsigned plane, unsigned row) const
  */
 double prob_matrix::col_sum(unsigned plane, unsigned column) const
 {
+	if(!plane_used(plane)) {
+		return 0.0;
+	}
+
 	double sum = 0.0;
 	for(unsigned row : used_rows_[plane]) {
 		sum += val(plane, row, column);
@@ -2099,8 +2107,8 @@ void complex_fight(attack_prediction_mode mode,
 		debug(("Using exact probability calculations.\n"));
 
 		probability_combat_matrix* pm = new probability_combat_matrix(stats.max_hp, opp_stats.max_hp, stats.hp,
-				opp_stats.hp, summary, opp_summary, stats.slows || opp_stats.is_slowed,
-				opp_stats.slows || stats.is_slowed, a_damage, b_damage, a_slow_damage, b_slow_damage,
+				opp_stats.hp, summary, opp_summary, stats.slows, opp_stats.slows,
+				a_damage, b_damage, a_slow_damage, b_slow_damage,
 				stats.drain_percent, opp_stats.drain_percent, stats.drain_constant, opp_stats.drain_constant);
 		m.reset(pm);
 
@@ -2138,6 +2146,9 @@ void complex_fight(attack_prediction_mode mode,
 			pm->dump();
 		} while(--rounds && pm->dead_prob() < 0.99);
 
+		self_hit = std::min(self_hit, 1.0);
+		opp_hit = std::min(opp_hit, 1.0);
+
 		self_not_hit = original_self_not_hit * (1.0 - self_hit);
 		opp_not_hit = original_opp_not_hit * (1.0 - opp_hit);
 
@@ -2148,17 +2159,21 @@ void complex_fight(attack_prediction_mode mode,
 			 * with simple addition.
 			 * Instead, just fetch the probability from the combat matrix.
 			 */
-			opp_not_hit = original_opp_not_hit * pm->col_sum(plane_index(stats, opp_stats), opp_stats.hp);
+			unsigned int plane = plane_index(stats, opp_stats);
+			double not_hit = pm->col_sum(plane, opp_stats.hp) + ((plane & 1) ? 0.0 : pm->col_sum(plane | 1, opp_stats.hp));
+			opp_not_hit = original_opp_not_hit * not_hit;
 		}
 		if(opp_stats.slows) {
-			self_not_hit = original_self_not_hit * pm->row_sum(plane_index(stats, opp_stats), stats.hp);
+			unsigned int plane = plane_index(stats, opp_stats);
+			double not_hit = pm->row_sum(plane, stats.hp) + ((plane & 2) ? 0.0 : pm->row_sum(plane | 2, stats.hp));
+			self_not_hit = original_self_not_hit * not_hit;
 		}
 	} else {
 		debug(("Using Monte Carlo simulation.\n"));
 
 		monte_carlo_combat_matrix* mcm = new monte_carlo_combat_matrix(stats.max_hp, opp_stats.max_hp, stats.hp,
-				opp_stats.hp, summary, opp_summary, stats.slows || opp_stats.is_slowed,
-				opp_stats.slows || stats.is_slowed, a_damage, b_damage, a_slow_damage, b_slow_damage,
+				opp_stats.hp, summary, opp_summary, stats.slows, opp_stats.slows,
+				a_damage, b_damage, a_slow_damage, b_slow_damage,
 				stats.drain_percent, opp_stats.drain_percent, stats.drain_constant, opp_stats.drain_constant, rounds,
 				hit_chance, opp_hit_chance, split, opp_split, initially_slowed_chance, opp_initially_slowed_chance);
 		m.reset(mcm);
@@ -2526,7 +2541,7 @@ void combatant::print(const char label[], unsigned int battle, unsigned int figh
 
 	// TODO: add this to the stream... no idea how to convert it properly...
 	printf("#%06u: (%02u) %s%*c %u-%d; %uhp; %02u%% to hit; %.2f%% unscathed; ", battle, fighter, label,
-			int(strlen(label)) - 12, ':', u_.swarm_max, u_.damage, u_.hp, u_.chance_to_hit, untouched * 100.0);
+		static_cast<int>(strlen(label)) - 12, ':', u_.swarm_max, u_.damage, u_.hp, u_.chance_to_hit, untouched * 100.0);
 
 	if(u_.drains) {
 		ss << "drains, ";
@@ -2695,12 +2710,12 @@ static void run(unsigned specific_battle)
 	auto total = end - start;
 
 #ifdef BENCHMARK
-	printf("Total time for %i combats was %lf\n", NUM_UNITS * (NUM_UNITS - 1) * (NUM_UNITS - 2),
+	printf("Total time for %u combats was %lf\n", NUM_UNITS * (NUM_UNITS - 1) * (NUM_UNITS - 2),
 			static_cast<double>(duration_cast<microseconds>(total).count()) / 1000000.0);
 	printf("Time per calc = %li us\n", static_cast<long>(duration_cast<microseconds>(total).count())
 											   / (NUM_UNITS * (NUM_UNITS - 1) * (NUM_UNITS - 2)));
 #else
-	printf("Total combats: %i\n", NUM_UNITS * (NUM_UNITS - 1) * (NUM_UNITS - 2));
+	printf("Total combats: %u\n", NUM_UNITS * (NUM_UNITS - 1) * (NUM_UNITS - 2));
 #endif
 
 	for(i = 0; i < NUM_UNITS; ++i) {
