@@ -1,7 +1,7 @@
 /*
-   Copyright (C) 2006 - 2015 by Joerg Hinrichs <joerg.hinrichs@alice-dsl.de>
+   Copyright (C) 2006 - 2018 by Joerg Hinrichs <joerg.hinrichs@alice-dsl.de>
    wesnoth playturn Copyright (C) 2003 by David White <dave@whitevine.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,11 +13,9 @@
    See the COPYING file for more details.
 */
 
-#ifndef CHAT_EVENTS_H_INCLUDED
-#define CHAT_EVENTS_H_INCLUDED
-
-#include "global.hpp"
+#pragma once
 
+class config;
 #include <ctime>
 #include <string>
 
@@ -32,16 +30,18 @@ public:
 	enum MESSAGE_TYPE { MESSAGE_PUBLIC, MESSAGE_PRIVATE };
 
 	void send_command(const std::string& cmd, const std::string& args="");
+
+	virtual void send_to_server(const config& cfg) = 0;
 protected:
 	void do_speak(const std::string& message, bool allies_only=false);
 
 	//called from do_speak
 	virtual void add_chat_message(const time_t& time,
 			const std::string& speaker, int side, const std::string& message,
-			MESSAGE_TYPE type=MESSAGE_PRIVATE)=0;
-
-	virtual void send_chat_message(const std::string& message, bool allies_only=false)=0;
+			MESSAGE_TYPE type=MESSAGE_PRIVATE) = 0;
+	virtual void send_chat_message(const std::string& message, bool allies_only=false) = 0;
 
+	//Why are these virtual?
 	virtual void send_whisper(const std::string& receiver, const std::string& message);
 
 	virtual void add_whisper_sent(const std::string& receiver, const std::string& message);
@@ -67,4 +67,3 @@ protected:
 };
 
 }
-#endif
