@@ -56,6 +56,8 @@ public:
 	boost::optional<int> campaign_difficulty;
 	/// Non-empty if --campaign-scenario was given on the command line. Chooses starting scenario in the campaign to be played. Dependent on --campaign.
 	boost::optional<std::string> campaign_scenario;
+	/// True if --skip-story was given on the command line. Skips [story] and [message]s through the end of the "start" event. Dependent on --campaign.
+	bool campaign_skip_story;
 	/// True if --clock was given on the command line. Enables
 	bool clock;
 	/// Non-empty if --core was given on the command line. Chooses the core to be loaded.
@@ -141,8 +143,6 @@ public:
 	bool nosound;
 	/// True if --new-widgets was given on the command line. Hidden option to enable the new widget toolkit.
 	bool new_widgets;
-	/// True if --path was given on the command line. Prints the path to data directory and exits.
-	bool path;
 	/// True if --preprocess was given on the command line. Starts Wesnoth in preprocessor-only mode.
 	bool preprocess;
 	/// Defines that were given to the --preprocess option.
