@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2008 - 2015 by Fabian Mueller <fabianmueller5@gmx.de>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2008 - 2018 by Fabian Mueller <fabianmueller5@gmx.de>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -14,15 +14,19 @@
 
 #define GETTEXT_DOMAIN "wesnoth-editor"
 
-#include "mouse_action_unit.hpp"
-#include "../action_unit.hpp"
+#include "editor/action/mouse/mouse_action_unit.hpp"
+#include "editor/action/action_unit.hpp"
 
-#include "../../editor_display.hpp"
+#include "editor/editor_display.hpp"
 #include "gui/dialogs/unit_create.hpp"
 #include "tooltips.hpp"
 #include "gettext.hpp"
 
-#include "map_location.hpp"
+#include "map/location.hpp"
+#include "sdl/rect.hpp"
+#include "team.hpp"
+#include "units/unit.hpp"
+#include "units/map.hpp"
 
 namespace editor {
 
@@ -34,10 +38,10 @@ void mouse_action_unit::move(editor_display& disp, const map_location& hex)
 		update_brush_highlights(disp, hex);
 
 		std::set<map_location> adjacent_set;
-		map_location adjacent[6];
-		get_adjacent_tiles(previous_move_hex_, adjacent);
+		adjacent_loc_array_t adjacent;
+		get_adjacent_tiles(previous_move_hex_, adjacent.data());
 
-		for (int i = 0; i < 6; i++)
+		for (unsigned i = 0; i < adjacent.size(); i++)
 			adjacent_set.insert(adjacent[i]);
 
 		disp.invalidate(adjacent_set);
@@ -47,7 +51,7 @@ void mouse_action_unit::move(editor_display& disp, const map_location& hex)
 		const unit_map::const_unit_iterator unit_it = units.find(hex);
 		if (unit_it != units.end()) {
 
-			disp.set_mouseover_hex_overlay(NULL);
+			disp.set_mouseover_hex_overlay(nullptr);
 
 			SDL_Rect rect;
 			rect.x = disp.get_location_x(hex);
@@ -74,7 +78,7 @@ editor_action* mouse_action_unit::click_left(editor_display& disp, int x, int y)
 {
 	start_hex_ = disp.hex_clicked_on(x, y);
 	if (!disp.get_map().on_board(start_hex_)) {
-		return NULL;
+		return nullptr;
 	}
 
 	const unit_map& units = disp.get_units();
@@ -83,23 +87,23 @@ editor_action* mouse_action_unit::click_left(editor_display& disp, int x, int y)
 		set_unit_mouse_overlay(disp, unit_it->type());
 
 	click_ = true;
-	return NULL;
+	return nullptr;
 }
 
 editor_action* mouse_action_unit::drag_left(editor_display& disp, int x, int y, bool& /*partial*/, editor_action* /*last_undo*/)
 {
 	map_location hex = disp.hex_clicked_on(x, y);
 	click_ = (hex == start_hex_);
-	return NULL;
+	return nullptr;
 }
 
 editor_action* mouse_action_unit::up_left(editor_display& disp, int x, int y)
 {
-	if (!click_) return NULL;
+	if (!click_) return nullptr;
 	click_ = false;
 	map_location hex = disp.hex_clicked_on(x, y);
 	if (!disp.get_map().on_board(hex)) {
-		return NULL;
+		return nullptr;
 	}
 
 	unit_type type = unit_palette_.selected_fg_item();
@@ -111,31 +115,31 @@ editor_action* mouse_action_unit::up_left(editor_display& disp, int x, int y)
 	const unit_type *new_unit_type = unit_types.find(type_id);
 	if (!new_unit_type) {
 		//TODO rewrite the error message.
-		ERR_ED << "create unit dialog returned inexistent or unusable unit_type id '" << type_id << "'\n";
-		return NULL;
+		ERR_ED << "create unit dialog returned inexistent or unusable unit_type id '" << type_id << "'" << std::endl;
+		return nullptr;
 	}
 
 	const unit_type &ut = *new_unit_type;
 	unit_race::GENDER gender = ut.genders().front();
 
-	unit new_unit(ut, disp.viewing_side(), true, gender);
-	editor_action* action = new editor_action_unit(hex, new_unit);
+	unit_ptr new_unit = unit::create(ut, disp.viewing_side(), true, gender);
+	editor_action* action = new editor_action_unit(hex, *new_unit);
 	return action;
 }
 
 editor_action* mouse_action_unit::drag_end_left(editor_display& disp, int x, int y)
 {
-	if (click_) return NULL;
-	editor_action* action = NULL;
+	if (click_) return nullptr;
+	editor_action* action = nullptr;
 
 	map_location hex = disp.hex_clicked_on(x, y);
 	if (!disp.get_map().on_board(hex))
-		return NULL;
+		return nullptr;
 
 	const unit_map& units = disp.get_units();
 	const unit_map::const_unit_iterator unit_it = units.find(start_hex_);
 	if (unit_it == units.end())
-		return NULL;
+		return nullptr;
 
 	action = new editor_action_unit_replace(start_hex_, hex);
 	return action;
@@ -148,7 +152,7 @@ editor_action* mouse_action_unit::click_right(editor_display& disp, int x, int y
 	start_hex_ = hex;
 	previous_move_hex_ = hex;
 
-	const unit_map& units = disp.get_units();
+	const unit_map& units = disp.units();
 	const unit_map::const_unit_iterator unit_it = units.find(start_hex_);
 
 	if (unit_it != units.end()) {
@@ -156,7 +160,7 @@ editor_action* mouse_action_unit::click_right(editor_display& disp, int x, int y
 	}
 
 	click_ = true;
-	return NULL;
+	return nullptr;
 }
 */
 
@@ -164,12 +168,12 @@ editor_action* mouse_action_unit::click_right(editor_display& disp, int x, int y
 //{
 //	map_location hex = disp.hex_clicked_on(x, y);
 //	if (previous_move_hex_ == hex)
-//		return NULL;
+//		return nullptr;
 //
 //	click_ = (start_hex_ == hex);
 //	previous_move_hex_ = hex;
 //
-//	const unit_map& units = disp.get_units();
+//	const unit_map& units = disp.units();
 //
 //	const unit_map::const_unit_iterator unit_it = units.find(start_hex_);
 //	if (unit_it != units.end()) {
@@ -182,41 +186,41 @@ editor_action* mouse_action_unit::click_right(editor_display& disp, int x, int y
 //		}
 //	}
 //
-//	return NULL;
+//	return nullptr;
 //}
 
 //editor_action* mouse_action_unit::up_right(editor_display& disp, int /*x*/, int /*y*/)
 //{
-//	if (!click_) return NULL;
+//	if (!click_) return nullptr;
 //	click_ = false;
 //
-//	const unit_map& units = disp.get_units();
+//	const unit_map& units = disp.units();
 //	const unit_map::const_unit_iterator unit_it = units.find(start_hex_);
 //	if (unit_it != units.end()) {
 //		return new editor_action_unit_delete(start_hex_);
 //	}
 //
-//	return NULL;
+//	return nullptr;
 //}
 
 //editor_action* mouse_action_unit::drag_end_right(editor_display& disp, int x, int y)
 //{
-//	if (click_) return NULL;
+//	if (click_) return nullptr;
 //
 //	map_location hex = disp.hex_clicked_on(x, y);
 //	if (!disp.get_map().on_board(hex))
-//		return NULL;
+//		return nullptr;
 //
 //	if(new_direction_ != old_direction_) {
 //
-//	const unit_map& units = disp.get_units();
+//	const unit_map& units = disp.units();
 //	const unit_map::const_unit_iterator unit_it = units.find(start_hex_);
 //		if (unit_it != units.end()) {
 //			return new editor_action_unit_facing(start_hex_, new_direction_, old_direction_);
 //		}
 //	}
 //
-//	return NULL;
+//	return nullptr;
 //}
 
 
@@ -231,17 +235,18 @@ void mouse_action_unit::set_unit_mouse_overlay(editor_display& disp, const unit_
 
 	std::stringstream filename;
 	filename << u.image() << "~RC(" << u.flag_rgb() << '>'
-			<< team::get_side_color_index(disp.viewing_side()) << ')';
+			<< team::get_side_color_id(disp.viewing_side()) << ')';
 
 	surface image(image::get_image(filename.str()));
-	Uint8 alpha = 196;
+	uint8_t alpha = 196;
 	//TODO don't hardcode
 	int size = 72;
 	//int size = image->w;
 	int zoom = static_cast<int>(size * disp.get_zoom_factor());
 
 	// Add the alpha factor and scale the image
-	image = scale_surface(adjust_surface_alpha(image, alpha), zoom, zoom);
+	adjust_surface_alpha(image, alpha);
+	image = scale_surface(image, zoom, zoom);
 	disp.set_mouseover_hex_overlay(image);
 }
 
