@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2008 - 2015 by Fabian Mueller <fabianmueller5@gmx.de>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2008 - 2018 by Fabian Mueller <fabianmueller5@gmx.de>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
    See the COPYING file for more details.
 */
 
-#ifndef EDITOR_MOUSE_ACTION_UNIT_HPP
-#define EDITOR_MOUSE_ACTION_UNIT_HPP
+#pragma once
 
 #include "editor/action/mouse/mouse_action.hpp"
 #include "editor/palette/unit_palette.hpp"
@@ -61,7 +60,7 @@ public:
 	editor_action* drag_end_left(editor_display& disp, int x, int y);
 
 	editor_action* click_right(editor_display& /*disp*/, int /*x*/, int /*y*/) {
-		return NULL;
+		return nullptr;
 	}
 
 	virtual void set_mouse_overlay(editor_display& disp);
@@ -76,5 +75,3 @@ private:
 
 
 } //end namespace editor
-
-#endif
