@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2008 - 2015 by Fabian Mueller <fabianmueller5@gmx.de>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2008 - 2018 by Fabian Mueller <fabianmueller5@gmx.de>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,10 +12,9 @@
    See the COPYING file for more details.
 */
 
-#ifndef EDITOR_MOUSE_ACTION_VILLAGE_HPP
-#define EDITOR_MOUSE_ACTION_VILLAGE_HPP
+#pragma once
 
-#include "mouse_action.hpp"
+#include "editor/action/mouse/mouse_action.hpp"
 
 class CKey;
 class empty_palette;
@@ -37,7 +36,7 @@ public:
 	/**
 	 * No action.
 	 */
-	editor_action* click_left(editor_display& /*disp*/, int /*x*/, int /*y*/) {return NULL;}
+	editor_action* click_left(editor_display& /*disp*/, int /*x*/, int /*y*/) {return nullptr;}
 
 	/**
 	 * If clicked on a village hex field, assigns the ownership of it to the current side.
@@ -47,7 +46,7 @@ public:
 	/**
 	 * No action.
 	 */
-	editor_action* click_right(editor_display& /*disp*/, int /*x*/, int /*y*/) {return NULL;}
+	editor_action* click_right(editor_display& /*disp*/, int /*x*/, int /*y*/) {return nullptr;}
 
 	/**
 	 * If clicked on a village hex field, unassigns it's ownership.
@@ -59,5 +58,3 @@ public:
 
 
 } //end namespace editor
-
-#endif
