@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2003 - 2015 by David White <dave@whitevine.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2003 - 2018 by David White <dave@whitevine.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,14 +12,14 @@
    See the COPYING file for more details.
 */
 
-#ifndef COMMON_PALETTES_H_INCLUDED
-#define COMMON_PALETTES_H_INCLUDED
+#pragma once
 
-#include "display.hpp"
 #include "config.hpp"
-#include "gui/widgets/widget.hpp"
+#include "tstring.hpp"
+#include "widgets/widget.hpp"
 
 struct SDL_Rect;
+class CVideo;
 
 namespace editor {
 
@@ -28,9 +28,12 @@ namespace editor {
  */
 struct item_group
 {
-	item_group(const config& cfg):
-		id(cfg["id"]), name(cfg["name"].t_str()),
-		icon(cfg["icon"]), core(cfg["core"].to_bool()) {}
+	item_group(const config& cfg)
+		: id(cfg["id"])
+		, name(cfg["name"].t_str())
+		, icon(cfg["icon"])
+		, core(cfg["core"].to_bool())
+	{}
 
 	std::string id;
 	t_string name;
@@ -43,16 +46,14 @@ class common_palette  : public gui::widget {
 
 public:
 
-	common_palette(display& gui) : gui::widget(gui.video(), true) {}
+	common_palette(CVideo& video) : gui::widget(video, true) {}
 
 	virtual ~common_palette() {}
 
 	//event handling
 
-	virtual handler_vector handler_members() { return handler_vector(); }
-	
-	virtual void select_fg_item(const std::string& item_id) = 0;
-	virtual void select_bg_item(const std::string& item_id) = 0;
+	virtual sdl_handler_vector handler_members() { return sdl_handler_vector(); }
+
 
 	/** Scroll the editor-palette up one step if possible. */
 	virtual bool scroll_up() = 0;
@@ -70,24 +71,32 @@ public:
 	virtual void set_group(size_t index) = 0;
 	virtual void next_group() = 0;
 	virtual void prev_group() = 0;
-	virtual const config active_group_report() = 0;
 	virtual const std::vector<item_group>& get_groups() const = 0;
 
 	/** Menu expanding for palette group list */
-	virtual void expand_palette_groups_menu(std::vector<std::string>& items) = 0;
-	virtual void expand_palette_groups_menu(std::vector< std::pair< std::string, std::string> >& items) = 0;
+	virtual void expand_palette_groups_menu(std::vector<config>& items, int i) = 0;
 
     //item
-	virtual size_t num_items() = 0;
+	virtual int num_items() = 0;
 	virtual size_t start_num() = 0;
 	virtual void set_start_item(size_t index) = 0;
 
 	virtual bool supports_swap() { return true; }
 	virtual void swap() = 0;
 
+	virtual std::vector<std::string> action_pressed() const { return std::vector<std::string>(); }
 };
 
+// a palette containing tristtate buttons.
+class tristate_palette : public common_palette
+{
+public:
+	tristate_palette(CVideo& video)
+		: common_palette(video)
+	{
+	}
+	virtual void select_fg_item(const std::string& item_id) = 0;
+	virtual void select_bg_item(const std::string& item_id) = 0;
+};
 
 }
-
-#endif
