@@ -1,7 +1,7 @@
 /*
    Copyright (C) 2003 by David White <dave@whitevine.net>
-   Copyright (C) 2005 - 2015 by Yann Dirson <ydirson@altern.org>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2005 - 2018 by Yann Dirson <ydirson@altern.org>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,8 +12,8 @@
 
    See the COPYING file for more details.
 */
-#ifndef GAME_ERRORS_HPP_INCLUDED
-#define GAME_ERRORS_HPP_INCLUDED
+
+#pragma once
 
 #include "exceptions.hpp"
 #include "lua_jailbreak_exception.hpp"
@@ -48,45 +48,11 @@ struct game_error : public error {
 };
 
 /**
- * Exception used to signal that the user has decided to abort a game,
- * and to load another game instead.
+ * Error used to report an error in a lua script or in the lua interpreter.
  */
-class load_game_exception
-	: public tlua_jailbreak_exception
-{
-public:
-
-	load_game_exception()
-		: tlua_jailbreak_exception()
-	{
-	}
-
-	load_game_exception(
-			  const std::string& game_
-			, const bool show_replay_
-			, const bool cancel_orders_
-			, const bool select_difficulty_
-			, const std::string& difficulty_)
-		: tlua_jailbreak_exception()
-	{
-		game = game_;
-		show_replay = show_replay_;
-		cancel_orders = cancel_orders_;
-		select_difficulty = select_difficulty_;
-		difficulty = difficulty_;
-	}
-
-	static std::string game;
-	static bool show_replay;
-	static bool cancel_orders;
-	static bool select_difficulty;
-	static std::string difficulty;
-
-private:
-
-	IMPLEMENT_LUA_JAILBREAK_EXCEPTION(load_game_exception)
+struct lua_error : public error {
+	lua_error(const std::string& msg) : error("lua_error: " + msg) {}
+	lua_error(const std::string& msg, const std::string& context) : error(context + ":\n  " + msg) {}
 };
 
 }
-
-#endif
