@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2003 - 2015 by David White <dave@whitevine.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2003 - 2018 by David White <dave@whitevine.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,17 +22,17 @@
  * The actions not implemented in this module are implemented in Lua.
  */
 
-#ifndef GAME_EVENTS_ACTION_WML_H_INCLUDED
-#define GAME_EVENTS_ACTION_WML_H_INCLUDED
+#pragma once
 
-#include "../map.hpp"
+#include "terrain/type_data.hpp"
+#include <map>
+#include <string>
 
 class  config;
-struct map_location;
 class  vconfig;
 
 namespace t_translation {
-	struct t_terrain;
+	struct terrain_code;
 }
 
 
@@ -57,25 +57,9 @@ namespace game_events
 		static map::const_iterator begin()  { return registry_.begin(); }
 		/// One past the last registered action.
 		static map::const_iterator end()    { return registry_.end(); }
-
+		static const map& registry() { return registry_; }
 	private:
 		/// Tracks the known action handlers.
 		static map registry_;
 	};
-
-
-	/**
-	 * Changes a terrain location.
-	 * Ensures that villages are properly lost and that new terrains are discovered.
-	 */
-	void change_terrain(const map_location &loc, const t_translation::t_terrain &t,
-	                    gamemap::tmerge_mode mode, bool replace_if_failed);
-
-	/** Used for [deprecated_message]. */
-	void handle_deprecated_message(const config& cfg);
-	/** Used for [wml_message]. */
-	void handle_wml_log_message(const config& cfg);
 }
-
-#endif // GAME_EVENTS_ACTION_WML_H_INCLUDED
-
