@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2003 - 2015 by David White <dave@whitevine.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2003 - 2018 by David White <dave@whitevine.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,11 +17,10 @@
  * Define locations as used by the game's events mechanism.
  */
 
-#ifndef GAME_EVENTS_ENTITY_LOCATION_H_INCLUDED
-#define GAME_EVENTS_ENTITY_LOCATION_H_INCLUDED
+#pragma once
 
-#include "../map_location.hpp"
-#include "../unit_map.hpp"
+#include "map/location.hpp"
+#include "units/map.hpp"
 
 class unit;
 class vconfig;
@@ -36,11 +35,11 @@ namespace game_events
 		explicit entity_location(const unit &);
 		entity_location(const unit &u, const map_location &filter_loc);
 
-		int filter_x() const { return filter_loc_.x; }
-		int filter_y() const { return filter_loc_.y; }
+		const map_location& filter_loc() const { return filter_loc_;  }
 		bool matches_unit(const unit_map::const_iterator & un_it) const;
 		bool matches_unit_filter(const unit_map::const_iterator & un_it,
 		                         const vconfig & filter) const;
+		unit_const_ptr get_unit() const;
 
 		static const entity_location null_entity;
 
@@ -55,6 +54,3 @@ namespace game_events
 		map_location filter_loc_;
 	};
 }
-
-#endif // GAME_EVENTS_ENTITY_LOCATION_H_INCLUDED
-
