@@ -130,7 +130,7 @@ void wmi_manager::get_items(const map_location& hex,
 				&& item->can_show(hex, gamedata, fc)) {
 			// Include this item.
 			items.push_back(item);
-			descriptions.emplace_back(config {"id", item->menu_text()});
+			descriptions.emplace_back("id", item->menu_text());
 		}
 	}
 }
@@ -194,7 +194,7 @@ void wmi_manager::set_item(const std::string& id, const vconfig& menu_item)
 	bool success;
 
 	// First, try to insert a brand new menu item.
-	std::tie(iter, success) = wml_menu_items_.emplace(id, item_ptr(new wml_menu_item(id, menu_item)));
+	std::tie(iter, success) = wml_menu_items_.emplace(id, std::make_shared<wml_menu_item>(id, menu_item));
 
 	// If an entry already exists, reset it.
 	if(!success) {
@@ -218,7 +218,7 @@ void wmi_manager::set_menu_items(const config& cfg)
 		const std::string& id = item["id"];
 		bool success;
 
-		std::tie(std::ignore, success) = wml_menu_items_.emplace(id, item_ptr(new wml_menu_item(id, item)));
+		std::tie(std::ignore, success) = wml_menu_items_.emplace(id, std::make_shared<wml_menu_item>(id, item));
 
 		if(!success) {
 			WRN_NG << "duplicate menu item (" << id << ") while loading from config" << std::endl;
