@@ -306,6 +306,11 @@ std::pair<wesnothd_connection_ptr, config> open_connection(std::string host)
 				utils::string_map i18n_symbols;
 				i18n_symbols["nick"] = login;
 
+				const bool has_extra_data = error->has_child("data");
+				if(has_extra_data) {
+					i18n_symbols["duration"] = utils::format_timespan((*error).child("data")["duration"]);
+				}
+
 				if((*error)["error_code"] == MP_MUST_LOGIN) {
 					error_message = _("You must login first.");
 				} else if((*error)["error_code"] == MP_NAME_TAKEN_ERROR) {
@@ -323,11 +328,23 @@ std::pair<wesnothd_connection_ptr, config> open_connection(std::string host)
 					error_message = VGETTEXT("The nickname ‘$nick’ is not registered on this server.", i18n_symbols)
 							+ _(" This server disallows unregistered nicknames.");
 				} else if((*error)["error_code"] == MP_NAME_AUTH_BAN_USER_ERROR) {
-					error_message = VGETTEXT("The nickname ‘$nick’ is banned on this server’s forums.", i18n_symbols);
+					if(has_extra_data) {
+						error_message = VGETTEXT("The nickname ‘$nick’ is banned on this server’s forums for $duration|.", i18n_symbols);
+					} else {
+						error_message = VGETTEXT("The nickname ‘$nick’ is banned on this server’s forums.", i18n_symbols);
+					}
 				} else if((*error)["error_code"] == MP_NAME_AUTH_BAN_IP_ERROR) {
-					error_message = _("Your IP address is banned on this server’s forums.");
+					if(has_extra_data) {
+						error_message = VGETTEXT("Your IP address is banned on this server’s forums for $duration|.", i18n_symbols);
+					} else {
+						error_message = _("Your IP address is banned on this server’s forums.");
+					}
 				} else if((*error)["error_code"] == MP_NAME_AUTH_BAN_EMAIL_ERROR) {
-					error_message = VGETTEXT("The email address for the nickname ‘$nick’ is banned on this server’s forums.", i18n_symbols);
+					if(has_extra_data) {
+						error_message = VGETTEXT("The email address for the nickname ‘$nick’ is banned on this server’s forums for $duration|.", i18n_symbols);
+					} else {
+						error_message = VGETTEXT("The email address for the nickname ‘$nick’ is banned on this server’s forums.", i18n_symbols);
+					}
 				} else if((*error)["error_code"] == MP_PASSWORD_REQUEST) {
 					error_message = VGETTEXT("The nickname ‘$nick’ is registered on this server.", i18n_symbols);
 				} else if((*error)["error_code"] == MP_PASSWORD_REQUEST_FOR_LOGGED_IN_NAME) {
@@ -442,7 +459,7 @@ void enter_wait_mode(mp_workflow_helper_ptr helper, int game_id, bool observe)
 	}
 
 	if(dlg_ok) {
-		campaign_controller controller(helper->state, helper->game_config, game_config_manager::get()->terrain_types());
+		campaign_controller controller(helper->state, game_config_manager::get()->terrain_types());
 		controller.set_mp_info(campaign_info.get());
 		controller.play_game();
 	}
@@ -473,7 +490,7 @@ void enter_staging_mode(mp_workflow_helper_ptr helper)
 	} // end connect_engine_ptr, dlg scope
 
 	if(dlg_ok) {
-		campaign_controller controller(helper->state, helper->game_config, game_config_manager::get()->terrain_types());
+		campaign_controller controller(helper->state, game_config_manager::get()->terrain_types());
 		controller.set_mp_info(campaign_info.get());
 		controller.play_game();
 	}
@@ -527,7 +544,7 @@ bool enter_lobby_mode(mp_workflow_helper_ptr helper, const std::vector<std::stri
 			sound::stop_music();
 		}
 
-		mp::lobby_info li(helper->game_config, installed_addons);
+		mp::lobby_info li(installed_addons);
 		helper->lobby_info = &li;
 
 		if(!initial_lobby_config.empty()) {
@@ -639,17 +656,17 @@ void start_client(const config& game_config,	saved_game& state, const std::strin
 	} while(re_enter);
 }
 
-bool goto_mp_connect(ng::connect_engine& engine, const config& game_config, wesnothd_connection* connection)
+bool goto_mp_connect(ng::connect_engine& engine, wesnothd_connection* connection)
 {
-	lobby_info li(game_config, {});
+	lobby_info li({});
 
 	gui2::dialogs::mp_staging dlg(engine, li, connection);
 	return dlg.show();
 }
 
-bool goto_mp_wait(saved_game& state, const config& game_config, wesnothd_connection* connection, bool observe)
+bool goto_mp_wait(saved_game& state, wesnothd_connection* connection, bool observe)
 {
-	lobby_info li(game_config, std::vector<std::string>());
+	lobby_info li({});
 
 	gui2::dialogs::mp_join_game dlg(state, li, *connection, false, observe);
 
@@ -672,7 +689,7 @@ void start_local_game(const config& game_config, saved_game& state)
 	preferences::set_message_private(false);
 
 	// TODO: should lobby_info take a nullptr in this case, or should we pass the installed_addons data here too?
-	lobby_info li(game_config, {});
+	lobby_info li({});
 	mp_workflow_helper_ptr workflow_helper = std::make_shared<mp_workflow_helper>(game_config, state, nullptr, &li);
 
 	enter_create_mode(workflow_helper);
@@ -750,9 +767,9 @@ void start_local_game_commandline(const config& game_config, saved_game& state,
 	state.expand_mp_options();
 
 	// Should number of turns be determined from scenario data?
-	if(parameters.use_map_settings && state.get_starting_pos()["turns"]) {
-		DBG_MP << "setting turns from scenario data: " << state.get_starting_pos()["turns"] << std::endl;
-		parameters.num_turns = state.get_starting_pos()["turns"];
+	if(parameters.use_map_settings && state.get_starting_point()["turns"]) {
+		DBG_MP << "setting turns from scenario data: " << state.get_starting_point()["turns"] << std::endl;
+		parameters.num_turns = state.get_starting_point()["turns"];
 	}
 
 	DBG_MP << "entering connect mode" << std::endl;
@@ -763,7 +780,7 @@ void start_local_game_commandline(const config& game_config, saved_game& state,
 		ng::connect_engine_ptr connect_engine(new ng::connect_engine(state, true, nullptr));
 
 		// Update the parameters to reflect game start conditions
-		connect_engine->start_game_commandline(cmdline_opts);
+		connect_engine->start_game_commandline(cmdline_opts, game_config);
 	}
 
 	if(resources::recorder && cmdline_opts.multiplayer_label) {
@@ -774,7 +791,7 @@ void start_local_game_commandline(const config& game_config, saved_game& state,
 	unsigned int repeat = (cmdline_opts.multiplayer_repeat) ? *cmdline_opts.multiplayer_repeat : 1;
 	for(unsigned int i = 0; i < repeat; i++){
 		saved_game state_copy(state);
-		campaign_controller controller(state_copy, game_config, game_config_manager::get()->terrain_types());
+		campaign_controller controller(state_copy, game_config_manager::get()->terrain_types());
 		controller.play_game();
 	}
 }
