@@ -67,7 +67,7 @@
 #include <iostream>                     // for operator<<, basic_ostream, etc
 #include <new>
 #include <utility>                      // for pair
-#include <SDL.h>                        // for SDL_INIT_JOYSTICK, etc
+#include <SDL2/SDL.h>                        // for SDL_INIT_JOYSTICK, etc
 
 #ifdef DEBUG_WINDOW_LAYOUT_GRAPHS
 #include "gui/widgets/debug.hpp"
@@ -118,7 +118,7 @@ game_launcher::game_launcher(const commandline_options& cmdline_opts, const char
 	play_replay_(false),
 	multiplayer_server_(),
 	jump_to_multiplayer_(false),
-	jump_to_campaign_(false, -1, "", ""),
+	jump_to_campaign_(false, false, -1, "", ""),
 	jump_to_editor_(false),
 	load_data_()
 {
@@ -164,6 +164,10 @@ game_launcher::game_launcher(const commandline_options& cmdline_opts, const char
 			jump_to_campaign_.scenario_id_ = *cmdline_opts_.campaign_scenario;
 			std::cerr << "selected scenario id: [" << jump_to_campaign_.scenario_id_ << "]\n";
 		}
+
+		if (cmdline_opts_.campaign_skip_story) {
+			jump_to_campaign_.skip_story_ = true;
+		}
 	}
 	if (cmdline_opts_.clock)
 		gui2::dialogs::show_debug_clock_button = true;
@@ -489,7 +493,7 @@ bool game_launcher::play_test()
 		load_game_config_for_game(state_.classification());
 
 	try {
-		campaign_controller ccontroller(state_, game_config_manager::get()->game_config(), game_config_manager::get()->terrain_types());
+		campaign_controller ccontroller(state_, game_config_manager::get()->terrain_types());
 		ccontroller.play_game();
 	} catch(const savegame::load_game_exception &e) {
 		load_data_.reset(new savegame::load_game_metadata(std::move(e.data_)));
@@ -523,7 +527,7 @@ int game_launcher::unit_test()
 		load_game_config_for_game(state_.classification());
 
 	try {
-		campaign_controller ccontroller(state_, game_config_manager::get()->game_config(), game_config_manager::get()->terrain_types(), true);
+		campaign_controller ccontroller(state_, game_config_manager::get()->terrain_types(), true);
 		LEVEL_RESULT res = ccontroller.play_game();
 		if (!(res == LEVEL_RESULT::VICTORY) || lg::broke_strict()) {
 			return 1;
@@ -549,7 +553,7 @@ int game_launcher::unit_test()
 	}
 
 	try {
-		campaign_controller ccontroller(state_, game_config_manager::get()->game_config(), game_config_manager::get()->terrain_types(), true);
+		campaign_controller ccontroller(state_, game_config_manager::get()->terrain_types(), true);
 		LEVEL_RESULT res = ccontroller.play_replay();
 		if (!(res == LEVEL_RESULT::VICTORY) || lg::broke_strict()) {
 			std::cerr << "Observed failure on replay" << std::endl;
@@ -573,8 +577,7 @@ bool game_launcher::play_screenshot_mode()
 
 	::init_textdomains(game_config_manager::get()->game_config());
 
-	editor::start(game_config_manager::get()->game_config(),
-	    screenshot_map_, true, screenshot_filename_);
+	editor::start(screenshot_map_, true, screenshot_filename_);
 	return false;
 }
 
@@ -729,6 +732,7 @@ bool game_launcher::goto_campaign()
 {
 	if(jump_to_campaign_.jump_){
 		if(new_campaign()) {
+			state_.set_skip_story(jump_to_campaign_.skip_story_);
 			jump_to_campaign_.jump_ = false;
 			launch_game(NO_RELOAD_DATA);
 		}else{
@@ -979,7 +983,7 @@ void game_launcher::launch_game(RELOAD_GAME_DATA reload)
 	});
 
 	try {
-		campaign_controller ccontroller(state_, game_config_manager::get()->game_config(), game_config_manager::get()->terrain_types());
+		campaign_controller ccontroller(state_, game_config_manager::get()->terrain_types());
 		LEVEL_RESULT result = ccontroller.play_game();
 		ai::manager::singleton_ = nullptr;
 		// don't show The End for multiplayer scenario
@@ -1007,7 +1011,7 @@ void game_launcher::play_replay()
 {
 	assert(!load_data_);
 	try {
-		campaign_controller ccontroller(state_, game_config_manager::get()->game_config(), game_config_manager::get()->terrain_types());
+		campaign_controller ccontroller(state_, game_config_manager::get()->terrain_types());
 		ccontroller.play_replay();
 	} catch (const savegame::load_game_exception &e) {
 		load_data_.reset(new savegame::load_game_metadata(std::move(e.data_)));
@@ -1024,8 +1028,7 @@ editor::EXIT_STATUS game_launcher::start_editor(const std::string& filename)
 
 		::init_textdomains(game_config_manager::get()->game_config());
 
-		editor::EXIT_STATUS res = editor::start(
-		    game_config_manager::get()->game_config(), filename);
+		editor::EXIT_STATUS res = editor::start(filename);
 
 		if(res != editor::EXIT_RELOAD_DATA)
 			return res;
