@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2006 - 2015 by Joerg Hinrichs <joerg.hinrichs@alice-dsl.de>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2006 - 2018 by Joerg Hinrichs <joerg.hinrichs@alice-dsl.de>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,10 +12,7 @@
    See the COPYING file for more details.
 */
 
-#ifndef GENERIC_EVENT_HPP_INCLUDED
-#define GENERIC_EVENT_HPP_INCLUDED
-
-#include "global.hpp"
+#pragma once
 
 #include <string>
 #include <vector>
@@ -45,7 +42,7 @@ This is the class that notifies the observers and maintains a list of them.
 */
 class generic_event{
 public:
-	generic_event(std::string name);
+	generic_event(const std::string& name);
 	virtual ~generic_event() {}
 
 	virtual bool attach_handler(observer* obs);
@@ -67,5 +64,3 @@ private:
 	bool notify_active_;
 };
 }
-
-#endif
