@@ -229,7 +229,7 @@ namespace
 			}
 
 			generator_.use_ansi_encoding(false);
-			generator_.categories(bl::message_facet | bl::information_facet | bl::collation_facet | bl::formatting_facet);
+			generator_.categories(bl::message_facet | bl::information_facet | bl::collation_facet | bl::formatting_facet | bl::convert_facet);
 			generator_.characters(bl::char_facet);
 			// We cannot have current_locale_ be a non boost-generated locale since it might not supply
 			// the bl::info facet. As soon as we add message paths, update_locale_internal might fail,
@@ -492,7 +492,7 @@ int icompare(const std::string& s1, const std::string& s2)
 
 		if(!bad_cast_once) {
 			ERR_G << "locale set-up for icompare() is broken, falling back to std::string::compare()\n";
-			
+
 			try { //just to be safe.
 				ERR_G << get_manager().debug_description() << "\n";
 			} catch (const std::exception& e) {
@@ -517,7 +517,8 @@ std::string strftime(const std::string& format, const std::tm* time)
 	std::lock_guard<std::mutex> lock(get_mutex());
 	dummy.imbue(get_manager().get_locale());
 	// See utils/io.hpp for explanation of this check
-#if HAVE_PUT_TIME
+#if 0	// HAVE_PUT_TIME is 1 for nearly everything except GCC < 5 however put_time does not adjust for locale in Linux
+	// HAVE_PUT_TIME is still used by io.hpp so change the value here instead of in global.hpp
 	dummy << std::put_time(time, format.c_str());
 #else
 	dummy << bl::as::ftime(format) << mktime(const_cast<std::tm*>(time));
@@ -526,4 +527,16 @@ std::string strftime(const std::string& format, const std::tm* time)
 	return dummy.str();
 }
 
+bool ci_search(const std::string& s1, const std::string& s2)
+{
+	std::lock_guard<std::mutex> lock(get_mutex());
+	const std::locale& locale = get_manager().get_locale();
+
+	std::string ls1 = bl::to_lower(s1, locale);
+	std::string ls2 = bl::to_lower(s2, locale);
+
+	return std::search(ls1.begin(), ls1.end(),
+	                   ls2.begin(), ls2.end()) != ls1.end();
+}
+
 }
