@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2011 - 2015 by Mark de Wever <koraq@xs4all.nl>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2011 - 2018 by Mark de Wever <koraq@xs4all.nl>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,34 +12,31 @@
    See the COPYING file for more details.
 */
 
-#ifndef GUI_WIDGETS_AUXILIARY_ITERATOR_WALKER_HPP_INCLUDED
-#define GUI_WIDGETS_AUXILIARY_ITERATOR_WALKER_HPP_INCLUDED
+#pragma once
 
 namespace gui2
 {
 
-class twidget;
+class widget;
 
-namespace iterator
+namespace iteration
 {
 
 /** The walker abstract base class. */
-class twalker_
+class walker_base
 {
 public:
-	virtual ~twalker_()
+	virtual ~walker_base()
 	{
 	}
 
 	/** The level to walk at. */
-	enum tlevel {
+	enum level {
 		/** Visit the widget itself. */
-		widget
+		self,
 		/** Visit its nested grid. */
-		,
-		grid
+		internal,
 		/** Visit the children of its nested grid. */
-		,
 		child
 	};
 
@@ -48,7 +45,7 @@ public:
 	 *
 	 * The enum is used to return the state of @ref next.
 	 */
-	enum tstate {
+	enum state_t {
 		/**
 		 * When calling next the following it has the following results.
 		 *
@@ -89,7 +86,7 @@ public:
 	 *
 	 * @returns                   The status of the operation.
 	 */
-	virtual tstate next(const tlevel level) = 0;
+	virtual state_t next(const level level) = 0;
 
 	/**
 	 * Returns whether the current widget is valid.
@@ -100,7 +97,7 @@ public:
 	 *
 	 * @returns                   Whether the current widget is valid.
 	 */
-	virtual bool at_end(const tlevel level) const = 0;
+	virtual bool at_end(const level level) const = 0;
 
 	/**
 	 * Returns a pointer to the current widget.
@@ -113,11 +110,9 @@ public:
 	 *
 	 * @returns                   Pointer to the current widget.
 	 */
-	virtual gui2::twidget* get(const tlevel level) = 0;
+	virtual gui2::widget* get(const level level) = 0;
 };
 
-} // namespace iterator
+} // namespace iteration
 
 } // namespace gui2
-
-#endif
