@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2011 - 2015 by Mark de Wever <koraq@xs4all.nl>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2011 - 2018 by Mark de Wever <koraq@xs4all.nl>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
    See the COPYING file for more details.
 */
 
-#ifndef GUI_WIDGETS_AUXILIARY_WALKER_VISITOR_GRID_HPP_INCLUDED
-#define GUI_WIDGETS_AUXILIARY_WALKER_VISITOR_GRID_HPP_INCLUDED
+#pragma once
 
 #include "gui/auxiliary/iterator/walker.hpp"
 
@@ -22,11 +21,11 @@
 namespace gui2
 {
 
-namespace iterator
+namespace iteration
 {
 
-/** A walker for a @ref gui2::tgrid. */
-class tgrid : public twalker_
+/** A walker for a @ref gui2::grid. */
+class grid : public walker_base
 {
 public:
 	/**
@@ -34,40 +33,38 @@ public:
 	 *
 	 * @param grid                The grid which the walker is attached to.
 	 */
-	explicit tgrid(gui2::tgrid& grid);
+	explicit grid(gui2::grid& grid);
 
-	/** Inherited from @ref gui2::iterator::twalker_. */
-	virtual tstate next(const tlevel level);
+	/** Inherited from @ref gui2::iteration::walker_base. */
+	virtual state_t next(const level level);
 
-	/** Inherited from @ref gui2::iterator::twalker_. */
-	virtual bool at_end(const tlevel level) const;
+	/** Inherited from @ref gui2::iteration::walker_base. */
+	virtual bool at_end(const level level) const;
 
-	/** Inherited from @ref gui2::iterator::twalker_. */
-	virtual gui2::twidget* get(const tlevel level);
+	/** Inherited from @ref gui2::iteration::walker_base. */
+	virtual gui2::widget* get(const level level);
 
 private:
 	/** The grid which the walker is attached to. */
-	gui2::tgrid& grid_;
+	gui2::grid& grid_;
 
 	/**
 	 * The grid which the walker is attached to.
 	 *
 	 * This variable is used to track whether the @ref
-	 * gui2::iterator::twalker_::widget level has been visited.
+	 * gui2::iteration::walker_base::widget level has been visited.
 	 */
-	gui2::twidget* widget_;
+	gui2::widget* widget_;
 
 	/**
 	 * The iterator to the children of @ref grid_.
 	 *
 	 * This variable is used to track where the @ref
-	 * gui2::iterator::twalker_::child level visiting is.
+	 * gui2::iteration::walker_base::child level visiting is.
 	 */
-	gui2::tgrid::iterator itor_;
+	gui2::grid::iterator itor_;
 };
 
-} // namespace iterator
+} // namespace iteration
 
 } // namespace gui2
-
-#endif
