@@ -57,10 +57,16 @@
  *
  * "Calls" REGISTER_WIDGET3(id_definition, id, nullptr)
  */
-#define REGISTER_WIDGET(id) REGISTER_WIDGET3(id##_definition, id, nullptr)                                             \
+#define REGISTER_WIDGET(id)                                                                                            \
+	REGISTER_WIDGET3(id##_definition, id, nullptr)                                                                     \
                                                                                                                        \
-	const std::string& id::get_control_type() const                                                                    \
+	const std::string& id::type()                                                                                      \
 	{                                                                                                                  \
 		static const std::string result(#id);                                                                          \
 		return result;                                                                                                 \
+	}                                                                                                                  \
+                                                                                                                       \
+	const std::string& id::get_control_type() const                                                                    \
+	{                                                                                                                  \
+		return id::type();                                                                                             \
 	}
