@@ -36,11 +36,7 @@
 #include "gui/widgets/stacked_widget.hpp"
 #include "gui/widgets/drawing.hpp"
 #include "gui/widgets/image.hpp"
-#ifdef GUI2_EXPERIMENTAL_LISTBOX
-#include "gui/widgets/list.hpp"
-#else
 #include "gui/widgets/listbox.hpp"
-#endif
 #include "gui/widgets/pane.hpp"
 #include "gui/widgets/settings.hpp"
 #include "gui/widgets/toggle_button.hpp"
@@ -334,7 +330,7 @@ void addon_manager::pre_show(window& window)
 
 	std::vector<config> status_filter_entries;
 	for(const auto& f : status_filter_types_) {
-		status_filter_entries.emplace_back(config {"label", t_string(f.second, GETTEXT_DOMAIN)});
+		status_filter_entries.emplace_back("label", t_string(f.second, GETTEXT_DOMAIN));
 	}
 
 	status_filter.set_values(status_filter_entries);
@@ -346,7 +342,7 @@ void addon_manager::pre_show(window& window)
 
 	std::vector<config> type_filter_entries;
 	for(const auto& f : type_filter_types_) {
-		type_filter_entries.emplace_back(config {"label", t_string(f.second, GETTEXT_DOMAIN), "checkbox", false});
+		type_filter_entries.emplace_back("label", t_string(f.second, GETTEXT_DOMAIN), "checkbox", false);
 	}
 
 	type_filter.set_values(type_filter_entries);
