@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2010 - 2015 by Mark de Wever <koraq@xs4all.nl>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2010 - 2018 by Mark de Wever <koraq@xs4all.nl>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,21 +16,22 @@
 
 #include "gui/dialogs/debug_clock.hpp"
 
-#include "gui/auxiliary/find_widget.tpp"
-#include "gui/dialogs/dialog.hpp"
+#include "gui/auxiliary/find_widget.hpp"
+#include "gui/dialogs/modal_dialog.hpp"
 #include "gui/widgets/integer_selector.hpp"
 #include "gui/widgets/window.hpp"
 #include "gui/widgets/settings.hpp"
 #include "gui/widgets/pane.hpp"
 #include "gui/widgets/progress_bar.hpp"
-#include "utils/foreach.tpp"
 
-#include <boost/bind.hpp>
+#include "utils/functional.hpp"
 
 #include <ctime>
 
 namespace gui2
 {
+namespace dialogs
+{
 
 /*WIKI
  * @page = GUIWindowDefinitionWML
@@ -50,74 +51,72 @@ namespace gui2
  *         This shows the seconds as a percentage, where 60 seconds is 100%. $
  *
  * hour              & & integer_selector & o &
- *         This shows the seconds since the beginning of the day. The control
+ *         This shows the seconds since the beginning of the day. The styled_widget
  *         should have a ''minimum_value'' of 0 and a ''maximum_value'' of 86399
  *         (24 * 60 * 60 - 1). $
  *
  * minute            & & integer_selector & o &
  *         This shows the seconds since the beginning of the current hour. The
- *         control should have a ''minimum_value'' of 0 and a ''maximum_value''
+ *         styled_widget should have a ''minimum_value'' of 0 and a ''maximum_value''
  *         of 3599 (60 * 60 - 1). $
  *
  * minute            & & integer_selector & o &
  *         This shows the seconds since the beginning of the current minute. The
- *         control should have a ''minimum_value'' of 0 and a ''maximum_value''
+ *         styled_widget should have a ''minimum_value'' of 0 and a ''maximum_value''
  *         of 59. $
  *
- * clock             & & control          & o &
- *         A control which will have set three variables in its canvas:
+ * clock             & & styled_widget          & o &
+ *         A styled_widget which will have set three variables in its canvas:
  *         @* hour, the same value as the hour integer_selector.
  *         @* minute, the same value as the minute integer_selector.
  *         @* second, the same value as the second integer_selector.
- *         @- the control can then should the time in its own preferred
+ *         @- the styled_widget can then should the time in its own preferred
  *         format(s). $
  * @end{table}
  */
 
 REGISTER_DIALOG(debug_clock)
 
-void tdebug_clock::pre_show(CVideo& /*video*/, twindow& window)
+void debug_clock::pre_show(window& window)
 {
-	hour_percentage_ = find_widget<tprogress_bar>(
+	hour_percentage_ = find_widget<progress_bar>(
 			&window, "hour_percentage", false, false);
-	minute_percentage_ = find_widget<tprogress_bar>(
+	minute_percentage_ = find_widget<progress_bar>(
 			&window, "minute_percentage", false, false);
-	second_percentage_ = find_widget<tprogress_bar>(
+	second_percentage_ = find_widget<progress_bar>(
 			&window, "second_percentage", false, false);
 
-	hour_ = find_widget<tinteger_selector_>(&window, "hour", false, false);
-	if(dynamic_cast<tcontrol*>(hour_)) { //Note that the standard specifies that a dynamic cast of a null pointer is null
-		dynamic_cast<tcontrol*>(hour_)->set_active(false);
+	hour_ = find_widget<integer_selector>(&window, "hour", false, false);
+	if(styled_widget *hour = dynamic_cast<styled_widget*>(hour_)) { //Note that the standard specifies that a dynamic cast of a null pointer is null
+		hour->set_active(false);
 	}
-	minute_ = find_widget<tinteger_selector_>(&window, "minute", false, false);
-	if(dynamic_cast<tcontrol*>(minute_)) {
-		dynamic_cast<tcontrol*>(minute_)->set_active(false);
+	minute_ = find_widget<integer_selector>(&window, "minute", false, false);
+	if(styled_widget *minute = dynamic_cast<styled_widget*>(minute_)) {
+		minute->set_active(false);
 	}
-	second_ = find_widget<tinteger_selector_>(&window, "second", false, false);
-	if(dynamic_cast<tcontrol*>(second_)) {
-		dynamic_cast<tcontrol*>(second_)->set_active(false);
+	second_ = find_widget<integer_selector>(&window, "second", false, false);
+	if(styled_widget *second = dynamic_cast<styled_widget*>(second_)) {
+		second->set_active(false);
 	}
 
-	pane_ = find_widget<tpane>(&window, "pane", false, false);
+	pane_ = find_widget<pane>(&window, "pane", false, false);
 
-	clock_ = find_widget<tcontrol>(&window, "clock", false, false);
+	clock_ = find_widget<styled_widget>(&window, "clock", false, false);
 
-	window_ = &window;
-
-	signal_ = boost::bind(&tdebug_clock::update_time, this, false);
+	signal_ = std::bind(&debug_clock::update_time, this, false);
 	window.connect_signal<event::DRAW>(signal_,
-									   event::tdispatcher::front_child);
+									   event::dispatcher::front_child);
 
 	time_.set_current_time();
 	update_time(true);
 }
 
-void tdebug_clock::post_show(CVideo& /*video*/)
+void debug_clock::post_show(CVideo& /*video*/)
 {
-	window_->disconnect_signal<event::DRAW>(signal_);
+	get_window()->disconnect_signal<event::DRAW>(signal_);
 }
 
-void tdebug_clock::update_time(const bool force)
+void debug_clock::update_time(const bool force)
 {
 	if(!time_.step() && !force) {
 		return;
@@ -148,11 +147,11 @@ void tdebug_clock::update_time(const bool force)
 	}
 
 	if(clock_) {
-		FOREACH(AUTO & canvas, clock_->canvas())
+		for(auto & canvas : clock_->get_canvases())
 		{
-			canvas.set_variable("hour", variant(hour_stamp));
-			canvas.set_variable("minute", variant(minute_stamp));
-			canvas.set_variable("second", variant(second_stamp));
+			canvas.set_variable("hour", wfl::variant(hour_stamp));
+			canvas.set_variable("minute", wfl::variant(minute_stamp));
+			canvas.set_variable("second", wfl::variant(second_stamp));
 		}
 		clock_->set_is_dirty(true);
 	}
@@ -161,21 +160,21 @@ void tdebug_clock::update_time(const bool force)
 	std::map<std::string, string_map> item_data;
 	string_map item;
 
-	item["label"] = str_cast(second_stamp);
-	item_data.insert(std::make_pair("time", item));
+	item["label"] = std::to_string(second_stamp);
+	item_data.emplace("time", item);
 
 	if(pane_) {
 		pane_->create_item(item_data, tags);
 	}
 }
 
-tdebug_clock::ttime::ttime() : hour(0), minute(0), second(0), millisecond(0)
+debug_clock::time::time() : hour(0), minute(0), second(0), millisecond(0)
 {
 }
 
-void tdebug_clock::ttime::set_current_time()
+void debug_clock::time::set_current_time()
 {
-	time_t now = time(NULL);
+	time_t now = ::time(nullptr);
 	tm* stamp = localtime(&now);
 
 	hour = stamp->tm_hour;
@@ -184,7 +183,7 @@ void tdebug_clock::ttime::set_current_time()
 	millisecond = 0;
 }
 
-bool tdebug_clock::ttime::step(const unsigned milliseconds)
+bool debug_clock::time::step(const unsigned milliseconds)
 {
 	millisecond += milliseconds;
 
@@ -214,4 +213,5 @@ bool tdebug_clock::ttime::step(const unsigned milliseconds)
 	return true;
 }
 
+} // namespace dialogs
 } // namespace gui2
