@@ -16,7 +16,7 @@
 #include "gui/dialogs/modal_dialog.hpp"
 #include "hotkey/hotkey_item.hpp"
 
-#include <SDL_keycode.h>
+#include <SDL2/SDL_keycode.h>
 
 #include <string>
 
