@@ -14,29 +14,29 @@
 #pragma once
 
 #include "gui/dialogs/modal_dialog.hpp"
-#include <map>
+
 #include "display_context.hpp"
 #include "tstring.hpp"
 
+#include <map>
+
 namespace gui2
 {
 namespace dialogs
 {
-
-class label_settings : public modal_dialog {
+class label_settings : public modal_dialog
+{
 public:
 	label_settings(display_context& dc);
 
-	/**
-	 * The execute function.
-	 *
-	 * See @ref modal_dialog for more information.
-	 */
-	static bool execute(display_context& dc);
+	/** The execute function. See @ref modal_dialog for more information. */
+	DEFINE_SIMPLE_EXECUTE_WRAPPER(label_settings)
+
 private:
-	std::map<std::string, bool> all_labels;
-	std::map<std::string, t_string> labels_display;
-	display_context& viewer;
+	std::map<std::string, bool> all_labels_;
+	std::map<std::string, t_string> labels_display_;
+
+	display_context& viewer_;
 
 	/** Inherited from modal_dialog, implemented by REGISTER_DIALOG. */
 	virtual const std::string& window_id() const override;
@@ -44,8 +44,11 @@ private:
 	/** Inherited from modal_dialog. */
 	virtual void pre_show(window& window) override;
 
+	/** Inherited from modal_dialog. */
+	virtual void post_show(window& window) override;
+
 	/** Callback for toggling a checkbox state. */
-	void toggle_category(widget& box, std::string category);
+	void toggle_category(widget& box, const std::string& category);
 };
 } // namespace dialogs
 } // namespace gui2
