@@ -26,11 +26,7 @@
 #include "gui/widgets/button.hpp"
 #include "gui/widgets/image.hpp"
 #include "gui/widgets/label.hpp"
-#ifdef GUI2_EXPERIMENTAL_LISTBOX
-#include "gui/widgets/list.hpp"
-#else
 #include "gui/widgets/listbox.hpp"
-#endif
 #include "gui/widgets/menu_button.hpp"
 #include "gui/widgets/minimap.hpp"
 #include "gui/widgets/chatbox.hpp"
@@ -40,6 +36,7 @@
 #include "gui/widgets/toggle_panel.hpp"
 #include "gui/widgets/tree_view_node.hpp"
 
+#include "addon/client.hpp"
 #include "addon/manager_ui.hpp"
 #include "chat_log.hpp"
 #include "font/text_formatting.hpp"
@@ -246,7 +243,11 @@ bool handle_addon_requirements_gui(const std::vector<mp::game_info::required_add
 
 		if(gui2::show_message(e_title, err_msg, message::yes_no_buttons, true) == gui2::retval::OK) {
 			// Begin download session
-			return ad_hoc_addon_fetch_session(needs_download);
+			try {
+				return ad_hoc_addon_fetch_session(needs_download);
+			} catch (const addons_client::user_exit&) {
+			} catch (const addons_client::user_disconnect&) {
+			}
 		}
 	}
 
@@ -303,6 +304,10 @@ void mp_lobby::update_gamelist_diff()
 		const mp::game_info& game = *lobby_info_.games()[i];
 
 		if(game.display_status == mp::game_info::NEW) {
+			// call void do_notify(notify_mode mode, const std::string& sender, const std::string& message)
+			// sender will be the game_info.scenario (std::string) and message will be game_info.name (std::string)
+			do_notify(mp::NOTIFY_GAME_CREATED, game.scenario, game.name);
+
 			LOG_LB << "Adding game to listbox " << game.id << "\n";
 
 			if(list_i != gamelistbox_->get_item_count()) {
@@ -392,14 +397,12 @@ void mp_lobby::update_gamelist_diff()
 
 void mp_lobby::update_gamelist_header()
 {
-#ifndef GUI2_EXPERIMENTAL_LISTBOX
 	const std::string games_string = VGETTEXT("Games: showing $num_shown out of $num_total", {
 		{"num_shown", std::to_string(lobby_info_.games_visibility().count())},
 		{"num_total", std::to_string(lobby_info_.games().size())}
 	});
 
 	find_widget<label>(gamelistbox_, "map", false).set_label(games_string);
-#endif
 }
 
 std::map<std::string, string_map> mp_lobby::make_game_row_data(const mp::game_info& game)
