@@ -34,11 +34,7 @@
 #include "gui/widgets/menu_button.hpp"
 #include "gui/widgets/image.hpp"
 #include "gui/widgets/label.hpp"
-#ifdef GUI2_EXPERIMENTAL_LISTBOX
-#include "gui/widgets/list.hpp"
-#else
 #include "gui/widgets/listbox.hpp"
-#endif
 #include "gui/widgets/settings.hpp"
 #include "gui/widgets/tree_view.hpp"
 #include "gui/widgets/tree_view_node.hpp"
@@ -49,14 +45,12 @@
 #include "utils/scope_exit.hpp"
 #include "wesnothd_connection.hpp"
 
-
 static lg::log_domain log_mp_connect_engine("mp/connect/engine");
 #define DBG_MP LOG_STREAM(debug, log_mp_connect_engine)
 #define LOG_MP LOG_STREAM(info, log_mp_connect_engine)
 #define WRN_MP LOG_STREAM(warn, log_mp_connect_engine)
 #define ERR_MP LOG_STREAM(err, log_mp_connect_engine)
 
-
 namespace gui2
 {
 namespace dialogs
@@ -230,6 +224,7 @@ static std::string generate_user_description(const config& side)
 void mp_join_game::pre_show(window& window)
 {
 	window.set_enter_disabled(true);
+	window.set_escape_disabled(true);
 
 	//
 	// Set title
@@ -456,7 +451,7 @@ void mp_join_game::generate_side_list(window& window)
 				//
 				const auto handler = [this, side_num](bool& handled, bool& halt) {
 					show_flg_select(side_num);
-					// note: this function is called from a std::function object stored in the widget 
+					// note: this function is called from a std::function object stored in the widget
 					//       and show_flg_select which internally calls
 					//       show_dialog -> pump -> ... -> network_handler -> ... -> generate_side_list
 					//       might destroy that std::function object while it is executed, this means that
