@@ -27,11 +27,7 @@
 #include "gui/widgets/drawing.hpp"
 #include "gui/widgets/menu_button.hpp"
 #include "gui/widgets/image.hpp"
-#ifdef GUI2_EXPERIMENTAL_LISTBOX
-#include "gui/widgets/list.hpp"
-#else
 #include "gui/widgets/listbox.hpp"
-#endif
 #include "gui/widgets/label.hpp"
 #include "gui/widgets/settings.hpp"
 #include "gui/widgets/slider.hpp"
@@ -77,6 +73,7 @@ mp_staging::~mp_staging()
 void mp_staging::pre_show(window& window)
 {
 	window.set_enter_disabled(true);
+	window.set_escape_disabled(true);
 
 	//
 	// Set title and status widget states
@@ -86,8 +83,28 @@ void mp_staging::pre_show(window& window)
 
 	update_status_label_and_buttons(window);
 
+	//
+	// Set up teams
+	//
+	for(const ng::connect_engine::team_data_pod& team : connect_engine_.team_data()) {
+		tree_view& tree = find_widget<tree_view>(&window, "side_list", false);
+		static const std::map<std::string, string_map> empty_map;
+
+		std::map<std::string, string_map> tree_data;
+		string_map tree_item;
+
+		tree_item["label"] = (formatter() << _("Team:") << " " << t_string::from_serialized(team.user_team_name)).str();
+		tree_data.emplace("tree_view_node_label", tree_item);
+
+		tree_view_node& team_node = tree.add_node("team_header", tree_data);
+		team_node.add_sibling("side_spacer", empty_map);
+
+		team_tree_map_[team.team_name] = &team_node;
+	}
+
 	//
 	// Set up sides list
+	// This must be after setting up teams because add_side_node() uses team_tree_map_
 	//
 	for(const auto& side : connect_engine_.side_engines()) {
 		if(side->allow_player() || game_config::debug) {
@@ -144,9 +161,6 @@ int mp_staging::get_side_node_position(ng::side_engine_ptr side) const
 
 void mp_staging::add_side_node(window& window, ng::side_engine_ptr side)
 {
-	tree_view& tree = find_widget<tree_view>(&window, "side_list", false);
-	static const std::map<std::string, string_map> empty_map;
-
 	std::map<std::string, string_map> data;
 	string_map item;
 
@@ -160,21 +174,6 @@ void mp_staging::add_side_node(window& window, ng::side_engine_ptr side)
 	item["label"] = "icons/icon-random.png";
 	data.emplace("leader_gender", item);
 
-	// Check to see whether we've added a toplevel tree node for this team. If not, add one
-	if(team_tree_map_.find(side->team_name()) == team_tree_map_.end()) {
-		std::map<std::string, string_map> tree_data;
-		string_map tree_item;
-
-		tree_item["label"] = (formatter() << _("Team:") << " " << side->user_team_name()).str();
-		tree_data.emplace("tree_view_node_label", tree_item);
-
-		tree_view_node& team_node = tree.add_node("team_header", tree_data);
-		team_node.add_sibling("side_spacer", empty_map);
-
-		team_tree_map_[side->team_name()] = &team_node;
-	}
-
-	// Must be *after* the above if block, or the node ptr could be invalid
 	tree_view_node& node = team_tree_map_[side->team_name()]->add_child("side_panel", data, get_side_node_position(side));
 
 	side_tree_map_[side] = &node;
@@ -201,8 +200,14 @@ void mp_staging::add_side_node(window& window, ng::side_engine_ptr side)
 
 	// We use an index-based loop in order to get the index of the selected option
 	std::vector<config> ai_options;
+	// If this is loading a saved game, we add an option at the beginning of the menu.
+	// This results in a mismatch between the indices of ai_options and ai_algorithms_
+	// that we need to account for later.
+	if(saved_game) {
+		ai_options.emplace_back("label", "Keep saved AI");
+	}
 	for(unsigned i = 0; i < ai_algorithms_.size(); ++i) {
-		ai_options.emplace_back(config {"label", ai_algorithms_[i]->text});
+		ai_options.emplace_back("label", ai_algorithms_[i]->text);
 
 		if(ai_algorithms_[i]->id == side->ai_algorithm()) {
 			selection = i;
@@ -214,16 +219,15 @@ void mp_staging::add_side_node(window& window, ng::side_engine_ptr side)
 	ai_selection.set_values(ai_options, selection);
 
 	connect_signal_notify_modified(ai_selection,
-		std::bind(&mp_staging::on_ai_select, this, side, std::ref(ai_selection)));
-
-	on_ai_select(side, ai_selection);
+		std::bind(&mp_staging::on_ai_select, this, side, std::ref(ai_selection), saved_game));
 
+	on_ai_select(side, ai_selection, saved_game);
 	//
 	// Controller
 	//
 	std::vector<config> controller_names;
 	for(const auto& controller : side->controller_options()) {
-		controller_names.emplace_back(config {"label", controller.second});
+		controller_names.emplace_back("label", controller.second);
 	}
 
 	menu_button& controller_selection = find_widget<menu_button>(&row_grid, "controller", false);
@@ -290,10 +294,10 @@ void mp_staging::add_side_node(window& window, ng::side_engine_ptr side)
 	//
 	std::vector<config> color_options;
 	for(const auto& color : side->color_options()) {
-		color_options.emplace_back(config {
+		color_options.emplace_back(
 			"label", font::get_color_string_pango(color),
-			"icon", (formatter() << "misc/status.png~RC(magenta>" << color << ")").str(),
-		});
+			"icon", (formatter() << "misc/status.png~RC(magenta>" << color << ")").str()
+		);
 	}
 
 	menu_button& color_selection = find_widget<menu_button>(&row_grid, "side_color", false);
@@ -362,9 +366,20 @@ void mp_staging::on_controller_select(ng::side_engine_ptr side, grid& row_grid)
 	}
 }
 
-void mp_staging::on_ai_select(ng::side_engine_ptr side, menu_button& ai_menu)
+void mp_staging::on_ai_select(ng::side_engine_ptr side, menu_button& ai_menu, const bool saved_game)
 {
-	side->set_ai_algorithm(ai_algorithms_[ai_menu.get_value()]->id);
+	// If this is a saved game, we need to reduce the index by one, to account for
+	// the "Keep saved AI" option having been added to the computer player menu
+	int i = ai_menu.get_value();
+	if(saved_game) {
+		i--;
+	}
+
+	if(i < 0) {
+		side->set_ai_algorithm("use_saved");
+	} else {
+		side->set_ai_algorithm(ai_algorithms_[i]->id);
+	}
 
 	set_state_changed();
 }
@@ -509,7 +524,7 @@ void mp_staging::network_handler(window& window)
 
 		std::vector<config> controller_names;
 		for(const auto& controller : side->controller_options()) {
-			controller_names.emplace_back(config {"label", controller.second});
+			controller_names.emplace_back("label", controller.second);
 		}
 
 		menu_button& controller_selection = find_widget<menu_button>(&row_grid, "controller", false);
