@@ -49,11 +49,7 @@
 #include "gui/widgets/grid.hpp"
 #include "gui/widgets/image.hpp"
 #include "gui/widgets/label.hpp"
-#ifdef GUI2_EXPERIMENTAL_LISTBOX
-#include "gui/widgets/list.hpp"
-#else
 #include "gui/widgets/listbox.hpp"
-#endif
 #include "gui/widgets/scroll_label.hpp"
 #include "gui/widgets/settings.hpp"
 #include "gui/widgets/slider.hpp"
@@ -145,6 +141,11 @@ preferences_dialog::preferences_dialog(const config& game_cfg, const PREFERENCE_
 	}
 }
 
+void preferences_dialog::on_filtertext_changed(text_box_base* textbox)
+{
+	hotkey_filter_callback(*textbox->get_window());
+}
+
 // Helper function to refresh resolution list
 void preferences_dialog::set_resolution_list(menu_button& res_list, CVideo& video)
 {
@@ -751,10 +752,13 @@ void preferences_dialog::post_build(window& window)
 	hotkey_menu.set_values(hotkey_category_entries);
 
 	connect_signal_notify_modified(hotkey_menu,
-		std::bind(&preferences_dialog::hotkey_type_filter_callback, this, std::ref(window)));
+		std::bind(&preferences_dialog::hotkey_filter_callback, this, std::ref(window)));
 
 	listbox& hotkey_list = setup_hotkey_list(window);
 
+	text_box& filter = find_widget<text_box>(&window, "filter", false);
+	filter.set_text_changed_callback(std::bind(&preferences_dialog::on_filtertext_changed, this, _1));
+
 	// Action column
 	hotkey_list.register_translatable_sorting_option(0, [this](const int i) { return visible_hotkeys_[i]->description.str(); });
 
@@ -842,6 +846,11 @@ listbox& preferences_dialog::setup_hotkey_list(window& window)
 void preferences_dialog::add_hotkey_callback(listbox& hotkeys)
 {
 	int row_number = hotkeys.get_selected_row();
+	if(row_number < 0) {
+		gui2::show_transient_message("", _("No hotkey selected"));
+		return;
+	}
+
 	const hotkey::hotkey_command& hotkey_item = *visible_hotkeys_[row_number];
 
 	gui2::dialogs::hotkey_bind bind_dlg(hotkey_item.command);
@@ -907,39 +916,62 @@ void preferences_dialog::default_hotkey_callback(window& window)
 void preferences_dialog::remove_hotkey_callback(listbox& hotkeys)
 {
 	int row_number = hotkeys.get_selected_row();
+	if(row_number < 0) {
+		gui2::show_transient_message("", _("No hotkey selected"));
+		return;
+	}
+
 	const hotkey::hotkey_command& hotkey_item = *visible_hotkeys_[row_number];
 	hotkey::clear_hotkeys(hotkey_item.command);
 	find_widget<label>(hotkeys.get_row_grid(row_number), "lbl_hotkey", false).set_label(hotkey::get_names(hotkey_item.command));
 }
 
-void preferences_dialog::hotkey_type_filter_callback(window& window) const
+void preferences_dialog::hotkey_filter_callback(window& window) const
 {
 	const multimenu_button& hotkey_menu = find_widget<const multimenu_button>(&window, "hotkey_category_menu", false);
+	const text_box& name_filter = find_widget<const text_box>(&window, "filter", false);
 
 	boost::dynamic_bitset<> toggle_states = hotkey_menu.get_toggle_states();
 	boost::dynamic_bitset<> res(visible_hotkeys_.size());
 
-	if(!toggle_states.none()) {
-		for(size_t h = 0; h < visible_hotkeys_.size(); ++h) {
-			unsigned index = 0;
+	std::string text = name_filter.get_value();
 
-			for(const auto& name : cat_names_) {
-				if(visible_hotkeys_[h]->category == name.first) {
+	if(toggle_states.none()) {
+		// Nothing selected. It means that *all* categories are shown.
+		toggle_states = ~toggle_states;
+	}
+
+	for(std::size_t h = 0; h < visible_hotkeys_.size(); ++h) {
+		unsigned index = 0;
+
+		const std::string description = visible_hotkeys_[h]->description.str();
+
+		// Default to true if there is no filter text
+		bool found = true;
+
+		if(!text.empty()) {
+			for(const auto& word : utils::split(text, ' ')) {
+				found = translation::ci_search(description, word);
+				if(!found) {
 					break;
-				} else {
-					++index;
 				}
 			}
+		}
 
-			if(index < toggle_states.size()) {
-				res[h] = toggle_states[index];
+		// Filter categories
+		for(const auto& name : cat_names_) {
+			if(visible_hotkeys_[h]->category == name.first) {
+				break;
 			} else {
-				res[h] = false;
+				++index;
 			}
 		}
-	} else {
-		// Nothing selected. It means that *all* categories are shown.
-		res = ~res;
+
+		if(index < toggle_states.size() && found) {
+			res[h] = toggle_states[index];
+		} else {
+			res[h] = false;
+		}
 	}
 
 	find_widget<listbox>(&window, "list_hotkeys", false).set_row_shown(res);
