@@ -21,11 +21,7 @@
 #include "gettext.hpp"
 #include "gui/auxiliary/find_widget.hpp"
 #include "gui/widgets/label.hpp"
-#ifdef GUI2_EXPERIMENTAL_LISTBOX
-#include "gui/widgets/list.hpp"
-#else
 #include "gui/widgets/listbox.hpp"
-#endif
 #include "gui/widgets/menu_button.hpp"
 #include "gui/widgets/settings.hpp"
 #include "gui/widgets/window.hpp"
@@ -151,6 +147,9 @@ void statistics_dialog::add_damage_row(
 	str.str("");
 
 	if(show_this_turn) {
+		label& this_turn_header = find_widget<label>(&window, "damage_this_turn_header", false);
+		this_turn_header.set_label(_("This Turn"));
+
 		const long long turn_shifted = ((turn_expected * 20) + shift) / (2 * shift);
 		str << turn_damage << " / "
 			<< static_cast<double>(turn_shifted) * 0.1
@@ -160,6 +159,11 @@ void statistics_dialog::add_damage_row(
 
 		item["label"] = str.str();
 		data.emplace("damage_this_turn", item);
+	} else {
+		// TODO: Setting the label to "" causes "This Turn" not to be drawn when changing back to the current scenraio view, so set the label to " " (a single space) instead.
+		label& this_turn_header = find_widget<label>(&window, "damage_this_turn_header", false);
+		this_turn_header.set_label(" ");
+
 	}
 
 	damage_list.add_row(data);
