@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2014 - 2015 by Ignacio Riquelme Morelle <shadowm2006@gmail.com>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2014 - 2018 by Iris Morelle <shadowm2006@gmail.com>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,20 +12,21 @@
    See the COPYING file for more details.
 */
 
-#ifndef GUI_DIALOGS_THEME_LIST_HPP_INCLUDED
-#define GUI_DIALOGS_THEME_LIST_HPP_INCLUDED
+#pragma once
 
-#include "gui/dialogs/dialog.hpp"
+#include "gui/dialogs/modal_dialog.hpp"
 
 struct theme_info;
 
 namespace gui2
 {
+namespace dialogs
+{
 
-class ttheme_list : public tdialog
+class theme_list : public modal_dialog
 {
 public:
-	explicit ttheme_list(const std::vector<theme_info>& themes,
+	explicit theme_list(const std::vector<theme_info>& themes,
 						 int selection = -1);
 
 	/**
@@ -48,16 +49,14 @@ private:
 
 	std::vector<theme_info> themes_;
 
-	/** Inherited from tdialog, implemented by REGISTER_DIALOG. */
-	virtual const std::string& window_id() const;
+	/** Inherited from modal_dialog, implemented by REGISTER_DIALOG. */
+	virtual const std::string& window_id() const override;
 
-	/** Inherited from tdialog. */
-	void pre_show(CVideo& video, twindow& window);
+	/** Inherited from modal_dialog. */
+	virtual void pre_show(window& window) override;
 
-	/** Inherited from tdialog. */
-	void post_show(twindow& window);
+	/** Inherited from modal_dialog. */
+	virtual void post_show(window& window) override;
 };
-
-}
-
-#endif
+} // namespace dialogs
+} // namespace gui2
