@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2009 - 2015 by Mark de Wever <koraq@xs4all.nl>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2009 - 2018 by Mark de Wever <koraq@xs4all.nl>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,19 +12,20 @@
    See the COPYING file for more details.
 */
 
-#ifndef GUI_DIALOGS_TRANSIENT_MESSAGE_HPP_INCLUDED
-#define GUI_DIALOGS_TRANSIENT_MESSAGE_HPP_INCLUDED
+#pragma once
 
-#include "gui/dialogs/dialog.hpp"
+#include "gui/dialogs/modal_dialog.hpp"
 
 namespace gui2
 {
+namespace dialogs
+{
 
 /** Shows a transient message. */
-class ttransient_message : public tdialog
+class transient_message : public modal_dialog
 {
 public:
-	ttransient_message(const std::string& title,
+	transient_message(const std::string& title,
 					   const bool title_use_markup,
 					   const std::string& message,
 					   const bool message_use_markup,
@@ -34,12 +35,13 @@ private:
 	bool hide_title_;
 	bool hide_image_;
 
-	/** Inherited from tdialog, implemented by REGISTER_DIALOG. */
-	virtual const std::string& window_id() const;
+	/** Inherited from modal_dialog, implemented by REGISTER_DIALOG. */
+	virtual const std::string& window_id() const override;
 
-	/** Inherited from tdialog. */
-	virtual void pre_show(CVideo& video, twindow& window);
+	/** Inherited from modal_dialog. */
+	virtual void pre_show(window& window) override;
 };
+} // namespace dialogs
 
 /**
  * Shows a transient message to the user.
@@ -50,20 +52,20 @@ private:
  * @note The message _should_ be small enough to fit on the window, the text
  * can contain newlines and will wrap when needed.
  *
- * @param video               The video which contains the surface to draw
- *                            upon.
  * @param title               The title of the dialog.
  * @param message             The message to show in the dialog.
  * @param image               An image to show in the dialog.
  * @param message_use_markup  Use markup for the message?
  * @param title_use_markup    Use markup for the title?
+ * @param restore_background  Restore the background to the state it was before
+ * 							  the message appeared
  */
-void show_transient_message(CVideo& video,
-							const std::string& title,
+void show_transient_message(const std::string& title,
 							const std::string& message,
 							const std::string& image = std::string(),
 							const bool message_use_markup = false,
-							const bool title_use_markup = false);
+							const bool title_use_markup = false,
+							const bool restore_background = false);
 
 /**
  * Shows a transient error message to the user.
@@ -71,17 +73,12 @@ void show_transient_message(CVideo& video,
  * This shows a dialog with a short message which can be dismissed with a
  * single click.
  *
- * @param video               The video which contains the surface to draw
- *                            upon.
  * @param message             The message to show in the dialog.
  * @param image               An image to show in the dialog.
  * @param message_use_markup  Use markup for the message?
  */
-void show_transient_error_message(CVideo& video,
-								  const std::string& message,
+void show_transient_error_message(const std::string& message,
 								  const std::string& image = std::string(),
 								  const bool message_use_markup = false);
 
 } // namespace gui2
-
-#endif
