@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2008 - 2015 by Mark de Wever <koraq@xs4all.nl>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2008 - 2018 by Mark de Wever <koraq@xs4all.nl>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,23 +12,21 @@
    See the COPYING file for more details.
 */
 
-#ifndef GUI_WIDGETS_GENERATOR_HPP_INCLUDED
-#define GUI_WIDGETS_GENERATOR_HPP_INCLUDED
+#pragma once
 
 #include "widget.hpp"
-#include "config.hpp"
 
-#include <boost/intrusive_ptr.hpp>
+#include <boost/dynamic_bitset.hpp>
 
-typedef std::map<std::string, t_string> string_map;
+#include <array>
 
 namespace gui2
 {
 
-struct tbuilder_grid;
-typedef boost::intrusive_ptr<const tbuilder_grid> tbuilder_grid_const_ptr;
+struct builder_grid;
+typedef std::shared_ptr<const builder_grid> builder_grid_const_ptr;
 
-class tgrid;
+class grid;
 
 /**
  * Abstract base class for the generator.
@@ -38,20 +36,20 @@ class tgrid;
  * the possible policies is documented in the build() function. This function
  * is the factory to generate the classes as well.
  */
-class tgenerator_ : public twidget
+class generator_base : public widget
 {
-	friend class tdebug_layout_graph;
+	friend class debug_layout_graph;
 
 public:
-	virtual ~tgenerator_()
+	virtual ~generator_base()
 	{
 	}
 
 	/** Determines how the items are placed. */
-	enum tplacement {
+	enum placement {
 		horizontal_list,
 		vertical_list,
-		grid,
+		table,
 		independent
 	};
 
@@ -70,9 +68,9 @@ public:
 	 * @returns                   A pointer to a new object. The caller gets
 	 *                            ownership of the new object.
 	 */
-	static tgenerator_* build(const bool has_minimum,
+	static generator_base* build(const bool has_minimum,
 							  const bool has_maximum,
-							  const tplacement placement,
+							  const placement placement,
 							  const bool select);
 
 	/**
@@ -117,6 +115,17 @@ public:
 	/** Returns whether the item is shown. */
 	virtual bool get_item_shown(const unsigned index) const = 0;
 
+	/** Returns the visibility of all the items as a bit set. */
+	boost::dynamic_bitset<> get_items_shown() const
+	{
+		boost::dynamic_bitset<> items_shown(get_item_count());
+		for (unsigned int i = 0u; i < get_item_count(); ++i)
+		{
+			items_shown[i] = get_item_shown(i);
+		}
+		return items_shown;
+	}
+
 	/** Returns the number of items. */
 	virtual unsigned get_item_count() const = 0;
 
@@ -131,7 +140,7 @@ public:
 	 * Else is goes through all selected items and returns the first one
 	 * selected.
 	 *
-	 * @note tstacked_widget depends on that behavior it always has all items
+	 * @note stacked_widget depends on that behavior it always has all items
 	 * selected and thus shown and by default the last selected item (the top
 	 * one) is active.
 	 *
@@ -140,10 +149,10 @@ public:
 	virtual int get_selected_item() const = 0;
 
 	/** Gets the grid of an item. */
-	virtual tgrid& item(const unsigned index) = 0;
+	virtual grid& item(const unsigned index) = 0;
 
 	/** Gets the grid of an item. */
-	virtual const tgrid& item(const unsigned index) const = 0;
+	virtual const grid& item(const unsigned index) const = 0;
 
 	/***** ***** ***** ***** Create items ***** ***** ***** *****/
 
@@ -164,10 +173,10 @@ public:
 	 *
 	 * @returns                   A reference to the newly created grid.
 	 */
-	virtual tgrid& create_item(const int index,
-							   tbuilder_grid_const_ptr list_builder,
+	virtual grid& create_item(const int index,
+							   builder_grid_const_ptr list_builder,
 							   const string_map& item_data,
-							   const boost::function<void(twidget&)>& callback)
+							   const std::function<void(widget&)>& callback)
 			= 0;
 
 	/**
@@ -187,11 +196,11 @@ public:
 	 *
 	 * @returns                   A reference to the newly created grid.
 	 */
-	virtual tgrid&
+	virtual grid&
 	create_item(const int index,
-				tbuilder_grid_const_ptr list_builder,
+				builder_grid_const_ptr list_builder,
 				const std::map<std::string /* widget id */, string_map>& data,
-				const boost::function<void(twidget&)>& callback) = 0;
+				const std::function<void(widget&)>& callback) = 0;
 
 	/**
 	 * Creates one or more new item(s).
@@ -209,9 +218,9 @@ public:
 	 *                            in the grid is (de)selected.
 	 */
 	virtual void create_items(const int index,
-							  tbuilder_grid_const_ptr list_builder,
+							  builder_grid_const_ptr list_builder,
 							  const std::vector<string_map>& data,
-							  const boost::function<void(twidget&)>& callback)
+							  const std::function<void(widget&)>& callback)
 			= 0;
 
 	/**
@@ -231,10 +240,13 @@ public:
 	 */
 	virtual void create_items(
 			const int index,
-			tbuilder_grid_const_ptr list_builder,
-			const std::vector<std::map<std::string /*widget id*/, string_map> >&
+			builder_grid_const_ptr list_builder,
+			const std::vector<std::map<std::string /*widget id*/, string_map>>&
 					data,
-			const boost::function<void(twidget&)>& callback) = 0;
+			const std::function<void(widget&)>& callback) = 0;
+
+	typedef std::function<bool (unsigned, unsigned)> order_func;
+	virtual void set_order(const order_func& order) = 0;
 
 	/***** ***** ***** ***** Inherited ***** ***** ***** *****/
 
@@ -243,52 +255,49 @@ public:
 	 * become pure virtuals.
 	 */
 
-	/** See @ref twidget::layout_initialise. */
-	virtual void layout_initialise(const bool full_initialisation) OVERRIDE = 0;
+	/** See @ref widget::layout_initialize. */
+	virtual void layout_initialize(const bool full_initialization) override = 0;
 
-	/** See @ref twidget::request_reduce_width. */
-	virtual void request_reduce_width(const unsigned maximum_width) OVERRIDE
+	/** See @ref widget::request_reduce_width. */
+	virtual void request_reduce_width(const unsigned maximum_width) override
 			= 0;
 
-	/** See @ref twidget::request_reduce_height. */
-	virtual void request_reduce_height(const unsigned maximum_height) OVERRIDE
+	/** See @ref widget::request_reduce_height. */
+	virtual void request_reduce_height(const unsigned maximum_height) override
 			= 0;
 
-	/** See @ref twidget::calculate_best_size. */
-	virtual tpoint calculate_best_size() const OVERRIDE = 0;
+	/** See @ref widget::calculate_best_size. */
+	virtual point calculate_best_size() const override = 0;
 
-	/** See @ref twidget::place. */
-	virtual void place(const tpoint& origin, const tpoint& size) OVERRIDE = 0;
+	/** See @ref widget::place. */
+	virtual void place(const point& origin, const point& size) override = 0;
 
-	/** See @ref twidget::set_origin. */
-	virtual void set_origin(const tpoint& origin) OVERRIDE = 0;
+	/** See @ref widget::set_origin. */
+	virtual void set_origin(const point& origin) override = 0;
 
-	/** See @ref twidget::set_visible_rectangle. */
-	virtual void set_visible_rectangle(const SDL_Rect& rectangle) OVERRIDE = 0;
+	/** See @ref widget::set_visible_rectangle. */
+	virtual void set_visible_rectangle(const SDL_Rect& rectangle) override = 0;
 
-	/** See @ref twidget::impl_draw_children. */
-	virtual void impl_draw_children(surface& frame_buffer) OVERRIDE = 0;
-
-	/** See @ref twidget::impl_draw_children. */
+	/** See @ref widget::impl_draw_children. */
 	virtual void impl_draw_children(surface& frame_buffer,
 									int x_offset,
-									int y_offset) OVERRIDE = 0;
+									int y_offset) override = 0;
 
 protected:
-	/** See @ref twidget::child_populate_dirty_list. */
+	/** See @ref widget::child_populate_dirty_list. */
 	virtual void
-	child_populate_dirty_list(twindow& caller,
-							  const std::vector<twidget*>& call_stack) OVERRIDE
+	child_populate_dirty_list(window& caller,
+							  const std::vector<widget*>& call_stack) override
 			= 0;
 
 public:
-	/** See @ref twidget::find_at. */
-	virtual twidget* find_at(const tpoint& coordinate,
-							 const bool must_be_active) OVERRIDE = 0;
+	/** See @ref widget::find_at. */
+	virtual widget* find_at(const point& coordinate,
+							 const bool must_be_active) override = 0;
 
-	/** See @ref twidget::find_at. */
-	virtual const twidget* find_at(const tpoint& coordinate,
-								   const bool must_be_active) const OVERRIDE
+	/** See @ref widget::find_at. */
+	virtual const widget* find_at(const point& coordinate,
+								   const bool must_be_active) const override
 			= 0;
 
 	/***** ***** ***** ***** keyboard functions ***** ***** ***** *****/
@@ -303,7 +312,7 @@ public:
 	 *                            This is used in the keyboard event
 	 *                            changing.
 	 */
-	virtual void handle_key_up_arrow(SDLMod modifier, bool& handled) = 0;
+	virtual void handle_key_up_arrow(SDL_Keymod modifier, bool& handled) = 0;
 
 	/**
 	 * Down arrow key pressed.
@@ -315,7 +324,7 @@ public:
 	 *                            This is used in the keyboard event
 	 *                            changing.
 	 */
-	virtual void handle_key_down_arrow(SDLMod modifier, bool& handled) = 0;
+	virtual void handle_key_down_arrow(SDL_Keymod modifier, bool& handled) = 0;
 
 	/**
 	 * Left arrow key pressed.
@@ -327,7 +336,7 @@ public:
 	 *                            This is used in the keyboard event
 	 *                            changing.
 	 */
-	virtual void handle_key_left_arrow(SDLMod modifier, bool& handled) = 0;
+	virtual void handle_key_left_arrow(SDL_Keymod modifier, bool& handled) = 0;
 
 	/**
 	 * Right arrow key pressed.
@@ -339,7 +348,7 @@ public:
 	 *                            This is used in the keyboard event
 	 *                            changing.
 	 */
-	virtual void handle_key_right_arrow(SDLMod modifier, bool& handled) = 0;
+	virtual void handle_key_right_arrow(SDL_Keymod modifier, bool& handled) = 0;
 
 protected:
 	/**
@@ -355,8 +364,20 @@ protected:
 	 * @param index               The index of a selected item.
 	 */
 	virtual void do_deselect_item(const unsigned index) = 0;
+
+	/** Gets the grid of an item. */
+	virtual grid& item_ordered(const unsigned index) = 0;
+
+	/** Gets the grid of an item. */
+	virtual const grid& item_ordered(const unsigned index) const = 0;
+
+public:
+	virtual unsigned get_ordered_index(unsigned index) const = 0;
+
+	virtual unsigned get_item_at_ordered(unsigned index_ordered) const = 0;
+
 };
 
-} // namespace gui2
+using generator_sort_array = std::array<generator_base::order_func, 2>;
 
-#endif
+} // namespace gui2
