@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2008 - 2015 by Mark de Wever <koraq@xs4all.nl>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2008 - 2018 by Mark de Wever <koraq@xs4all.nl>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,25 +17,26 @@
 #include "gui/widgets/grid_private.hpp"
 
 #include "gui/auxiliary/iterator/walker_grid.hpp"
-#include "gui/auxiliary/log.hpp"
-#include "gui/auxiliary/layout_exception.hpp"
-#include "gui/widgets/control.hpp"
-#include "utils/foreach.tpp"
+#include "gui/core/event/message.hpp"
+#include "gui/core/log.hpp"
+#include "gui/core/layout_exception.hpp"
+#include "gui/widgets/styled_widget.hpp"
+#include "gui/widgets/window.hpp"
 
 #include <numeric>
 
-#define LOG_SCOPE_HEADER "tgrid [" + id() + "] " + __func__
+#define LOG_SCOPE_HEADER "grid [" + id() + "] " + __func__
 #define LOG_HEADER LOG_SCOPE_HEADER + ':'
-#define LOG_IMPL_HEADER "tgrid [" + grid.id() + "] " + __func__ + ':'
+#define LOG_IMPL_HEADER "grid [" + grid.id() + "] " + __func__ + ':'
 
 #define LOG_CHILD_SCOPE_HEADER                                                 \
-	"tgrid::tchild [" + (widget_ ? widget_->id() : "-") + "] " + __func__
+	"grid::child [" + (widget_ ? widget_->id() : "-") + "] " + __func__
 #define LOG_CHILD_HEADER LOG_CHILD_SCOPE_HEADER + ':'
 
 namespace gui2
 {
 
-tgrid::tgrid(const unsigned rows, const unsigned cols)
+grid::grid(const unsigned rows, const unsigned cols)
 	: rows_(rows)
 	, cols_(cols)
 	, row_height_()
@@ -44,19 +45,17 @@ tgrid::tgrid(const unsigned rows, const unsigned cols)
 	, col_grow_factor_(cols)
 	, children_(rows * cols)
 {
+	connect_signal<event::REQUEST_PLACEMENT>(
+		std::bind(&grid::request_placement, this,
+			std::placeholders::_1, std::placeholders::_2, std::placeholders::_3, std::placeholders::_4),
+		event::dispatcher::back_pre_child);
 }
 
-tgrid::~tgrid()
+grid::~grid()
 {
-	// Delete the children in this destructor since resizing a vector copies the
-	// children and thus frees the child prematurely.
-	FOREACH(AUTO & child, children_)
-	{
-		delete child.widget();
-	}
 }
 
-unsigned tgrid::add_row(const unsigned count)
+unsigned grid::add_row(const unsigned count)
 {
 	assert(count);
 
@@ -67,7 +66,7 @@ unsigned tgrid::add_row(const unsigned count)
 	return result;
 }
 
-void tgrid::set_child(twidget* widget,
+void grid::set_child(widget* widget,
 					  const unsigned row,
 					  const unsigned col,
 					  const unsigned flags,
@@ -77,43 +76,42 @@ void tgrid::set_child(twidget* widget,
 	assert(flags & VERTICAL_MASK);
 	assert(flags & HORIZONTAL_MASK);
 
-	tchild& cell = child(row, col);
+	child& cell = get_child(row, col);
 
 	// clear old child if any
-	if(cell.widget()) {
+	if(cell.get_widget()) {
 		// free a child when overwriting it
 		WRN_GUI_G << LOG_HEADER << " child '" << cell.id() << "' at cell '"
 				  << row << ',' << col << "' will be replaced.\n";
-		delete cell.widget();
 	}
 
 	// copy data
 	cell.set_flags(flags);
 	cell.set_border_size(border_size);
 	cell.set_widget(widget);
-	if(cell.widget()) {
+	if(cell.get_widget()) {
 		// make sure the new child is valid before deferring
-		cell.widget()->set_parent(this);
+		cell.get_widget()->set_parent(this);
 	}
 }
 
-twidget* tgrid::swap_child(const std::string& id,
-						   twidget* widget,
+std::unique_ptr<widget> grid::swap_child(const std::string& id,
+						   widget* w,
 						   const bool recurse,
-						   twidget* new_parent)
+						   widget* new_parent)
 {
-	assert(widget);
+	assert(w);
 
-	FOREACH(AUTO & child, children_)
+	for(auto & child : children_)
 	{
 		if(child.id() != id) {
 
 			if(recurse) {
 				// decent in the nested grids.
-				tgrid* grid = dynamic_cast<tgrid*>(child.widget());
-				if(grid) {
+				grid* g = dynamic_cast<grid*>(child.get_widget());
+				if(g) {
 
-					twidget* old = grid->swap_child(id, widget, true);
+					std::unique_ptr<widget> old = g->swap_child(id, w, true);
 					if(old) {
 						return old;
 					}
@@ -123,40 +121,36 @@ twidget* tgrid::swap_child(const std::string& id,
 			continue;
 		}
 
-		// When find the widget there should be a widget.
-		twidget* old = child.widget();
+		// Free widget from cell and validate.
+		std::unique_ptr<widget> old = child.free_widget();
 		assert(old);
+
 		old->set_parent(new_parent);
 
-		widget->set_parent(this);
-		child.set_widget(widget);
+		w->set_parent(this);
+		w->set_visible(old->get_visible());
 
+		child.set_widget(w);
 		return old;
 	}
 
-	return NULL;
+	return nullptr;
 }
 
-void tgrid::remove_child(const unsigned row, const unsigned col)
+void grid::remove_child(const unsigned row, const unsigned col)
 {
 	assert(row < rows_ && col < cols_);
 
-	tchild& cell = child(row, col);
-
-	if(cell.widget()) {
-		delete cell.widget();
-	}
-	cell.set_widget(NULL);
+	child& cell = get_child(row, col);
+	cell.set_widget(nullptr);
 }
 
-void tgrid::remove_child(const std::string& id, const bool find_all)
+void grid::remove_child(const std::string& id, const bool find_all)
 {
-	FOREACH(AUTO & child, children_)
+	for(auto & child : children_)
 	{
-
 		if(child.id() == id) {
-			delete child.widget();
-			child.set_widget(NULL);
+			child.set_widget(nullptr);
 
 			if(!find_all) {
 				break;
@@ -165,49 +159,49 @@ void tgrid::remove_child(const std::string& id, const bool find_all)
 	}
 }
 
-void tgrid::set_active(const bool active)
+void grid::set_active(const bool active)
 {
-	FOREACH(AUTO & child, children_)
+	for(auto & child : children_)
 	{
 
-		twidget* widget = child.widget();
+		widget* widget = child.get_widget();
 		if(!widget) {
 			continue;
 		}
 
-		tgrid* grid = dynamic_cast<tgrid*>(widget);
-		if(grid) {
-			grid->set_active(active);
+		grid* g = dynamic_cast<grid*>(widget);
+		if(g) {
+			g->set_active(active);
 			continue;
 		}
 
-		tcontrol* control = dynamic_cast<tcontrol*>(widget);
+		styled_widget* control = dynamic_cast<styled_widget*>(widget);
 		if(control) {
 			control->set_active(active);
 		}
 	}
 }
 
-void tgrid::layout_initialise(const bool full_initialisation)
+void grid::layout_initialize(const bool full_initialization)
 {
 	// Inherited.
-	twidget::layout_initialise(full_initialisation);
+	widget::layout_initialize(full_initialization);
 
 	// Clear child caches.
-	FOREACH(AUTO & child, children_)
+	for(auto & child : children_)
 	{
 
-		child.layout_initialise(full_initialisation);
+		child.layout_initialize(full_initialization);
 	}
 }
 
-void tgrid::reduce_width(const unsigned maximum_width)
+void grid::reduce_width(const unsigned maximum_width)
 {
 	/***** ***** ***** ***** INIT ***** ***** ***** *****/
 	log_scope2(log_gui_layout, LOG_SCOPE_HEADER);
 	DBG_GUI_L << LOG_HEADER << " maximum width " << maximum_width << ".\n";
 
-	tpoint size = get_best_size();
+	point size = get_best_size();
 	if(size.x <= static_cast<int>(maximum_width)) {
 		DBG_GUI_L << LOG_HEADER << " Already fits.\n";
 		return;
@@ -227,16 +221,16 @@ void tgrid::reduce_width(const unsigned maximum_width)
 
 	/** @todo Implement. */
 
-	/***** ***** ***** ***** Acknowlegde failure ***** ***** ***** *****/
+	/***** ***** ***** ***** Acknowledge failure ***** ***** ***** *****/
 
 	DBG_GUI_L << LOG_HEADER << " Resizing failed.\n";
 
-	throw tlayout_exception_width_resize_failed();
+	throw layout_exception_width_resize_failed();
 }
 
-void tgrid::request_reduce_width(const unsigned maximum_width)
+void grid::request_reduce_width(const unsigned maximum_width)
 {
-	tpoint size = get_best_size();
+	point size = get_best_size();
 	if(size.x <= static_cast<int>(maximum_width)) {
 		/** @todo this point shouldn't be reached, find out why it does. */
 		return;
@@ -253,15 +247,17 @@ void tgrid::request_reduce_width(const unsigned maximum_width)
 
 		const unsigned wanted_width = col_width_[col] - (too_wide - reduced);
 		const unsigned width
-				= tgrid_implementation::column_request_reduce_width(
+				= grid_implementation::column_request_reduce_width(
 						*this, col, wanted_width);
 
 		if(width < col_width_[col]) {
-			DBG_GUI_L << LOG_HEADER << " reduced " << col_width_[col] - width
+			unsigned reduction = col_width_[col] - width;
+
+			DBG_GUI_L << LOG_HEADER << " reduced " << reduction
 					  << " pixels for column " << col << ".\n";
 
-			size.x -= col_width_[col] - width;
-			col_width_[col] = width;
+			size.x -= reduction;
+			reduced += reduction;
 		}
 
 		if(size.x <= static_cast<int>(maximum_width)) {
@@ -272,18 +268,18 @@ void tgrid::request_reduce_width(const unsigned maximum_width)
 	set_layout_size(calculate_best_size());
 }
 
-void tgrid::demand_reduce_width(const unsigned /*maximum_width*/)
+void grid::demand_reduce_width(const unsigned /*maximum_width*/)
 {
 	/** @todo Implement. */
 }
 
-void tgrid::reduce_height(const unsigned maximum_height)
+void grid::reduce_height(const unsigned maximum_height)
 {
 	/***** ***** ***** ***** INIT ***** ***** ***** *****/
 	log_scope2(log_gui_layout, LOG_SCOPE_HEADER);
 	DBG_GUI_L << LOG_HEADER << " maximum height " << maximum_height << ".\n";
 
-	tpoint size = get_best_size();
+	point size = get_best_size();
 	if(size.y <= static_cast<int>(maximum_height)) {
 		DBG_GUI_L << LOG_HEADER << " Already fits.\n";
 		return;
@@ -303,16 +299,16 @@ void tgrid::reduce_height(const unsigned maximum_height)
 
 	/** @todo Implement. */
 
-	/***** ***** ***** ***** Acknowlegde failure ***** ***** ***** *****/
+	/***** ***** ***** ***** Acknowledge failure ***** ***** ***** *****/
 
 	DBG_GUI_L << LOG_HEADER << " Resizing failed.\n";
 
-	throw tlayout_exception_height_resize_failed();
+	throw layout_exception_height_resize_failed();
 }
 
-void tgrid::request_reduce_height(const unsigned maximum_height)
+void grid::request_reduce_height(const unsigned maximum_height)
 {
-	tpoint size = get_best_size();
+	point size = get_best_size();
 	if(size.y <= static_cast<int>(maximum_height)) {
 		/** @todo this point shouldn't be reached, find out why it does. */
 		return;
@@ -337,17 +333,24 @@ void tgrid::request_reduce_height(const unsigned maximum_height)
 			wanted_height = 1;
 		}
 
-		const unsigned height = tgrid_implementation::row_request_reduce_height(
+		/* Reducing the height of a widget causes the widget to save its new size
+		in widget::layout_size_. After that, get_best_size() will return that
+		size and not the originally calculated optimal size.
+		Thus, it's perfectly correct that grid::calculate_best_size() that we
+		call later calls get_best_size() for child widgets as if size reduction
+		had never happened. */
+		const unsigned height = grid_implementation::row_request_reduce_height(
 				*this, row, wanted_height);
 
 		if(height < row_height_[row]) {
+			unsigned reduction = row_height_[row] - height;
+
 			DBG_GUI_L << LOG_HEADER << " row " << row << " height "
 					  << row_height_[row] << " want to reduce " << too_high
-					  << " reduced " << row_height_[row] - height
-					  << " pixels.\n";
+					  << " reduced " << reduction << " pixels.\n";
 
-			size.y -= row_height_[row] - height;
-			row_height_[row] = height;
+			size.y -= reduction;
+			reduced += reduction;
 		}
 
 		if(size.y <= static_cast<int>(maximum_height)) {
@@ -363,19 +366,60 @@ void tgrid::request_reduce_height(const unsigned maximum_height)
 	set_layout_size(size);
 }
 
-void tgrid::demand_reduce_height(const unsigned /*maximum_height*/)
+void grid::demand_reduce_height(const unsigned /*maximum_height*/)
 {
 	/** @todo Implement. */
 }
 
-tpoint tgrid::recalculate_best_size()
+void grid::request_placement(dispatcher&, const event::ui_event, bool& handled, bool&)
 {
-	tpoint best_size = calculate_best_size();
+	if (get_window()->invalidate_layout_blocked()) {
+		handled = true;
+		return;
+	}
+
+	point size = get_size();
+	point best_size = calculate_best_size();
+	if(size.x >= best_size.x && size.y >= best_size.y) {
+		place(get_origin(), size);
+		handled = true;
+		return;
+	}
+
+	recalculate_best_size();
+
+	if(size.y >= best_size.y) {
+		// We have enough space in the Y direction, but not in the X direction.
+		// Try wrapping the content.
+		request_reduce_width(size.x);
+		best_size = get_best_size();
+
+		if(size.x >= best_size.x && size.y >= best_size.y) {
+			// Wrapping succeeded, we still fit vertically.
+			place(get_origin(), size);
+			handled = true;
+			return;
+		} else {
+			// Wrapping failed, we no longer fit.
+			// Reset the sizes of child widgets.
+			layout_initialize(true);
+		}
+	}
+
+	/*
+	Not enough space.
+	Let the event flow higher up.
+	This is a pre-event handler, so the event flows upwards. */
+}
+
+point grid::recalculate_best_size()
+{
+	point best_size = calculate_best_size();
 	set_layout_size(best_size);
 	return best_size;
 }
 
-tpoint tgrid::calculate_best_size() const
+point grid::calculate_best_size() const
 {
 	log_scope2(log_gui_layout, LOG_SCOPE_HEADER);
 
@@ -389,7 +433,7 @@ tpoint tgrid::calculate_best_size() const
 	for(unsigned row = 0; row < rows_; ++row) {
 		for(unsigned col = 0; col < cols_; ++col) {
 
-			const tpoint size = child(row, col).get_best_size();
+			const point size = get_child(row, col).get_best_size();
 
 			if(size.x > static_cast<int>(col_width_[col])) {
 				col_width_[col] = size.x;
@@ -411,7 +455,7 @@ tpoint tgrid::calculate_best_size() const
 				  << " will be " << col_width_[col] << ".\n";
 	}
 
-	const tpoint result(
+	const point result(
 			std::accumulate(col_width_.begin(), col_width_.end(), 0),
 			std::accumulate(row_height_.begin(), row_height_.end(), 0));
 
@@ -419,9 +463,9 @@ tpoint tgrid::calculate_best_size() const
 	return result;
 }
 
-bool tgrid::can_wrap() const
+bool grid::can_wrap() const
 {
-	FOREACH(const AUTO & child, children_)
+	for(const auto & child : children_)
 	{
 		if(child.can_wrap()) {
 			return true;
@@ -429,23 +473,23 @@ bool tgrid::can_wrap() const
 	}
 
 	// Inherited.
-	return twidget::can_wrap();
+	return widget::can_wrap();
 }
 
-void tgrid::place(const tpoint& origin, const tpoint& size)
+void grid::place(const point& origin, const point& size)
 {
 	log_scope2(log_gui_layout, LOG_SCOPE_HEADER);
 
 	/***** INIT *****/
 
-	twidget::place(origin, size);
+	widget::place(origin, size);
 
 	if(!rows_ || !cols_) {
 		return;
 	}
 
 	// call the calculate so the size cache gets updated.
-	const tpoint best_size = calculate_best_size();
+	const point best_size = calculate_best_size();
 
 	assert(row_height_.size() == rows_);
 	assert(col_width_.size() == cols_);
@@ -462,178 +506,187 @@ void tgrid::place(const tpoint& origin, const tpoint& size)
 		return;
 	}
 
-	/***** GROW *****/
-	if(best_size.x <= size.x && best_size.y <= size.y) {
-
-		// expand it.
-		if(size.x > best_size.x) {
-			const unsigned w = size.x - best_size.x;
-			unsigned w_size = std::accumulate(
-					col_grow_factor_.begin(), col_grow_factor_.end(), 0);
-
-			DBG_GUI_L << LOG_HEADER << " extra width " << w
-					  << " will be divided amount " << w_size << " units in "
-					  << cols_ << " columns.\n";
-
-			if(w_size == 0) {
-				// If all sizes are 0 reset them to 1
-				FOREACH(AUTO & val, col_grow_factor_)
-				{
-					val = 1;
-				}
-				w_size = cols_;
-			}
-			// We might have a bit 'extra' if the division doesn't fix exactly
-			// but we ignore that part for now.
-			const unsigned w_normal = w / w_size;
-			for(unsigned i = 0; i < cols_; ++i) {
-				col_width_[i] += w_normal * col_grow_factor_[i];
-				DBG_GUI_L << LOG_HEADER << " column " << i
-						  << " with grow factor " << col_grow_factor_[i]
-						  << " set width to " << col_width_[i] << ".\n";
-			}
+	if(best_size.x > size.x || best_size.y > size.y) {
+		// The assertion below fails quite often so try to give as much information as possible.
+		std::stringstream out;
+		out << " Failed to place a grid, we have " << size << " space but we need " << best_size << " space.";
+		out << " This happened at a grid with the id '" << id() << "'";
+		widget* pw = parent();
+		while(pw != nullptr) {
+			out << " in a '" << typeid(*pw).name() << "' with the id '" << pw->id() << "'";
+			pw = pw->parent();
 		}
+		ERR_GUI_L << LOG_HEADER << out.str() << ".\n";
 
-		if(size.y > best_size.y) {
-			const unsigned h = size.y - best_size.y;
-			unsigned h_size = std::accumulate(
-					row_grow_factor_.begin(), row_grow_factor_.end(), 0);
-			DBG_GUI_L << LOG_HEADER << " extra height " << h
-					  << " will be divided amount " << h_size << " units in "
-					  << rows_ << " rows.\n";
-
-			if(h_size == 0) {
-				// If all sizes are 0 reset them to 1
-				FOREACH(AUTO & val, row_grow_factor_)
-				{
-					val = 1;
-				}
-				h_size = rows_;
-			}
-			// We might have a bit 'extra' if the division doesn't fix exactly
-			// but we ignore that part for now.
-			const unsigned h_normal = h / h_size;
-			for(unsigned i = 0; i < rows_; ++i) {
-				row_height_[i] += h_normal * row_grow_factor_[i];
-				DBG_GUI_L << LOG_HEADER << " row " << i << " with grow factor "
-						  << row_grow_factor_[i] << " set height to "
-						  << row_height_[i] << ".\n";
-			}
-		}
-
-		layout(origin);
 		return;
 	}
 
-	// This shouldn't be possible...
-	assert(false);
+	/***** GROW *****/
+
+	// expand it.
+	if(size.x > best_size.x) {
+		const unsigned w = size.x - best_size.x;
+		unsigned w_size = std::accumulate(
+			col_grow_factor_.begin(), col_grow_factor_.end(), 0);
+
+		DBG_GUI_L << LOG_HEADER << " extra width " << w
+			<< " will be divided amount " << w_size << " units in "
+			<< cols_ << " columns.\n";
+
+		if(w_size == 0) {
+			// If all sizes are 0 reset them to 1
+			for(auto & val : col_grow_factor_)
+			{
+				val = 1;
+			}
+			w_size = cols_;
+		}
+		// We might have a bit 'extra' if the division doesn't fix exactly
+		// but we ignore that part for now.
+		const unsigned w_normal = w / w_size;
+		for(unsigned i = 0; i < cols_; ++i) {
+			col_width_[i] += w_normal * col_grow_factor_[i];
+			DBG_GUI_L << LOG_HEADER << " column " << i
+				<< " with grow factor " << col_grow_factor_[i]
+			<< " set width to " << col_width_[i] << ".\n";
+		}
+	}
+
+	if(size.y > best_size.y) {
+		const unsigned h = size.y - best_size.y;
+		unsigned h_size = std::accumulate(
+			row_grow_factor_.begin(), row_grow_factor_.end(), 0);
+		DBG_GUI_L << LOG_HEADER << " extra height " << h
+			<< " will be divided amount " << h_size << " units in "
+			<< rows_ << " rows.\n";
+
+		if(h_size == 0) {
+			// If all sizes are 0 reset them to 1
+			for(auto & val : row_grow_factor_)
+			{
+				val = 1;
+			}
+			h_size = rows_;
+		}
+		// We might have a bit 'extra' if the division doesn't fix exactly
+		// but we ignore that part for now.
+		const unsigned h_normal = h / h_size;
+		for(unsigned i = 0; i < rows_; ++i) {
+			row_height_[i] += h_normal * row_grow_factor_[i];
+			DBG_GUI_L << LOG_HEADER << " row " << i << " with grow factor "
+				<< row_grow_factor_[i] << " set height to "
+				<< row_height_[i] << ".\n";
+		}
+	}
+
+	layout(origin);
+	return;
 }
 
-void tgrid::set_origin(const tpoint& origin)
+void grid::set_origin(const point& origin)
 {
-	const tpoint movement = tpoint(origin.x - get_x(), origin.y - get_y());
+	const point movement {origin.x - get_x(), origin.y - get_y()};
 
 	// Inherited.
-	twidget::set_origin(origin);
+	widget::set_origin(origin);
 
-	FOREACH(AUTO & child, children_)
+	for(auto & child : children_)
 	{
 
-		twidget* widget = child.widget();
+		widget* widget = child.get_widget();
 		assert(widget);
 
-		widget->set_origin(tpoint(widget->get_x() + movement.x,
-								  widget->get_y() + movement.y));
+		widget->set_origin(point(widget->get_x() + movement.x, widget->get_y() + movement.y));
 	}
 }
 
-void tgrid::set_visible_rectangle(const SDL_Rect& rectangle)
+void grid::set_visible_rectangle(const SDL_Rect& rectangle)
 {
 	// Inherited.
-	twidget::set_visible_rectangle(rectangle);
+	widget::set_visible_rectangle(rectangle);
 
-	FOREACH(AUTO & child, children_)
+	for(auto & child : children_)
 	{
 
-		twidget* widget = child.widget();
+		widget* widget = child.get_widget();
 		assert(widget);
 
 		widget->set_visible_rectangle(rectangle);
 	}
 }
 
-void tgrid::layout_children()
+void grid::layout_children()
 {
-	FOREACH(AUTO & child, children_)
+	for(auto & child : children_)
 	{
-		assert(child.widget());
-		child.widget()->layout_children();
+		assert(child.get_widget());
+		child.get_widget()->layout_children();
 	}
 }
 
-void tgrid::child_populate_dirty_list(twindow& caller,
-									  const std::vector<twidget*>& call_stack)
+void grid::child_populate_dirty_list(window& caller,
+									  const std::vector<widget*>& call_stack)
 {
 	assert(!call_stack.empty() && call_stack.back() == this);
 
-	FOREACH(AUTO & child, children_)
+	for(auto & child : children_)
 	{
 
-		assert(child.widget());
+		assert(child.get_widget());
 
-		std::vector<twidget*> child_call_stack = call_stack;
-		child.widget()->populate_dirty_list(caller, child_call_stack);
+		std::vector<widget*> child_call_stack = call_stack;
+		child.get_widget()->populate_dirty_list(caller, child_call_stack);
 	}
 }
 
-twidget* tgrid::find_at(const tpoint& coordinate, const bool must_be_active)
+widget* grid::find_at(const point& coordinate, const bool must_be_active)
 {
-	return tgrid_implementation::find_at<twidget>(
+	return grid_implementation::find_at<widget>(
 			*this, coordinate, must_be_active);
 }
 
-const twidget* tgrid::find_at(const tpoint& coordinate,
+const widget* grid::find_at(const point& coordinate,
 							  const bool must_be_active) const
 {
-	return tgrid_implementation::find_at<const twidget>(
+	return grid_implementation::find_at<const widget>(
 			*this, coordinate, must_be_active);
 }
 
-twidget* tgrid::find(const std::string& id, const bool must_be_active)
+widget* grid::find(const std::string& id, const bool must_be_active)
 {
-	return tgrid_implementation::find<twidget>(*this, id, must_be_active);
+	return grid_implementation::find<widget>(*this, id, must_be_active);
 }
 
-const twidget* tgrid::find(const std::string& id, const bool must_be_active)
+const widget* grid::find(const std::string& id, const bool must_be_active)
 		const
 {
-	return tgrid_implementation::find<const twidget>(*this, id, must_be_active);
+	return grid_implementation::find<const widget>(*this, id, must_be_active);
 }
 
-bool tgrid::has_widget(const twidget& widget) const
+bool grid::has_widget(const widget& widget) const
 {
-	if(twidget::has_widget(widget)) {
+	if(widget::has_widget(widget)) {
 		return true;
 	}
 
-	FOREACH(const AUTO & child, children_)
+	for(const auto & child : children_)
 	{
-		if(child.widget()->has_widget(widget)) {
+		if(child.get_widget()->has_widget(widget)) {
 			return true;
 		}
 	}
 	return false;
 }
 
-bool tgrid::disable_click_dismiss() const
+bool grid::disable_click_dismiss() const
 {
-	if(get_visible() != twidget::tvisible::visible) {
+	if(get_visible() != widget::visibility::visible) {
 		return false;
 	}
 
-	FOREACH(const AUTO & child, children_)
+	for(const auto & child : children_)
 	{
-		const twidget* widget = child.widget();
+		const widget* widget = child.get_widget();
 		assert(widget);
 
 		if(widget->disable_click_dismiss()) {
@@ -643,12 +696,12 @@ bool tgrid::disable_click_dismiss() const
 	return false;
 }
 
-iterator::twalker_* tgrid::create_walker()
+iteration::walker_base* grid::create_walker()
 {
-	return new gui2::iterator::tgrid(*this);
+	return new gui2::iteration::grid(*this);
 }
 
-void tgrid::set_rows(const unsigned rows)
+void grid::set_rows(const unsigned rows)
 {
 	if(rows == rows_) {
 		return;
@@ -657,7 +710,7 @@ void tgrid::set_rows(const unsigned rows)
 	set_rows_cols(rows, cols_);
 }
 
-void tgrid::set_cols(const unsigned cols)
+void grid::set_cols(const unsigned cols)
 {
 	if(cols == cols_) {
 		return;
@@ -666,7 +719,7 @@ void tgrid::set_cols(const unsigned cols)
 	set_rows_cols(rows_, cols);
 }
 
-void tgrid::set_rows_cols(const unsigned rows, const unsigned cols)
+void grid::set_rows_cols(const unsigned rows, const unsigned cols)
 {
 	if(rows == rows_ && cols == cols_) {
 		return;
@@ -684,7 +737,7 @@ void tgrid::set_rows_cols(const unsigned rows, const unsigned cols)
 	children_.resize(rows_ * cols_);
 }
 
-tpoint tgrid::tchild::get_best_size() const
+point grid::child::get_best_size() const
 {
 	log_scope2(log_gui_layout, LOG_CHILD_SCOPE_HEADER)
 
@@ -694,14 +747,14 @@ tpoint tgrid::tchild::get_best_size() const
 		return border_space();
 	}
 
-	if(widget_->get_visible() == twidget::tvisible::invisible) {
+	if(widget_->get_visible() == widget::visibility::invisible) {
 		DBG_GUI_L << LOG_CHILD_HEADER << " has widget " << true
 				  << " widget visible " << false << " returning 0,0"
 				  << ".\n";
-		return tpoint(0, 0);
+		return point();
 	}
 
-	const tpoint best_size = widget_->get_best_size() + border_space();
+	const point best_size = widget_->get_best_size() + border_space();
 
 	DBG_GUI_L << LOG_CHILD_HEADER << " has widget " << true
 			  << " widget visible " << true << " returning " << best_size
@@ -709,10 +762,10 @@ tpoint tgrid::tchild::get_best_size() const
 	return best_size;
 }
 
-void tgrid::tchild::place(tpoint origin, tpoint size)
+void grid::child::place(point origin, point size)
 {
-	assert(widget());
-	if(widget()->get_visible() == twidget::tvisible::invisible) {
+	assert(get_widget());
+	if(get_widget()->get_visible() == widget::visibility::invisible) {
 		return;
 	}
 
@@ -736,37 +789,36 @@ void tgrid::tchild::place(tpoint origin, tpoint size)
 
 	// If size smaller or equal to best size set that size.
 	// No need to check > min size since this is what we got.
-	const tpoint best_size = widget()->get_best_size();
+	const point best_size = get_widget()->get_best_size();
 	if(size <= best_size) {
 		DBG_GUI_L << LOG_CHILD_HEADER
 				  << " in best size range setting widget to " << origin << " x "
 				  << size << ".\n";
 
-		widget()->place(origin, size);
+		get_widget()->place(origin, size);
 		return;
 	}
 
-	const tcontrol* control = dynamic_cast<const tcontrol*>(widget());
-	const tpoint maximum_size = control ? control->get_config_maximum_size()
-										: tpoint(0, 0);
+	const styled_widget* control = dynamic_cast<const styled_widget*>(get_widget());
+	const point maximum_size = control ? control->get_config_maximum_size()
+										: point();
 
 	if((flags_ & (HORIZONTAL_MASK | VERTICAL_MASK))
 	   == (HORIZONTAL_GROW_SEND_TO_CLIENT | VERTICAL_GROW_SEND_TO_CLIENT)) {
 
-		if(maximum_size == tpoint(0, 0) || size <= maximum_size) {
+		if(maximum_size == point() || size <= maximum_size) {
 
 			DBG_GUI_L << LOG_CHILD_HEADER
 					  << " in maximum size range setting widget to " << origin
 					  << " x " << size << ".\n";
 
-			widget()->place(origin, size);
+			get_widget()->place(origin, size);
 			return;
 		}
 	}
 
-	tpoint widget_size = tpoint(std::min(size.x, best_size.x),
-								std::min(size.y, best_size.y));
-	tpoint widget_orig = origin;
+	point widget_size = point(std::min(size.x, best_size.x), std::min(size.y, best_size.y));
+	point widget_orig = origin;
 
 	const unsigned v_flag = flags_ & VERTICAL_MASK;
 
@@ -835,27 +887,27 @@ void tgrid::tchild::place(tpoint origin, tpoint size)
 	DBG_GUI_L << LOG_CHILD_HEADER << " resize widget to " << widget_orig
 			  << " x " << widget_size << ".\n";
 
-	widget()->place(widget_orig, widget_size);
+	get_widget()->place(widget_orig, widget_size);
 }
 
-void tgrid::tchild::layout_initialise(const bool full_initialisation)
+void grid::child::layout_initialize(const bool full_initialization)
 {
 	assert(widget_);
 
-	if(widget_->get_visible() != twidget::tvisible::invisible) {
-		widget_->layout_initialise(full_initialisation);
+	if(widget_->get_visible() != widget::visibility::invisible) {
+		widget_->layout_initialize(full_initialization);
 	}
 }
 
-const std::string& tgrid::tchild::id() const
+const std::string& grid::child::id() const
 {
 	assert(widget_);
 	return widget_->id();
 }
 
-tpoint tgrid::tchild::border_space() const
+point grid::child::border_space() const
 {
-	tpoint result(0, 0);
+	point result(0, 0);
 
 	if(border_size_) {
 
@@ -873,19 +925,62 @@ tpoint tgrid::tchild::border_space() const
 	return result;
 }
 
-void tgrid::layout(const tpoint& origin)
+grid::child* grid::get_child(widget* w)
 {
-	tpoint orig = origin;
+	if(!w) {
+		return nullptr;
+	}
+
+	for(auto& child : children_) {
+		if(w == child.get_widget()) {
+			return &child;
+		}
+	}
+
+	return nullptr;
+}
+
+void grid::set_child_alignment(widget* widget, unsigned set_flag, unsigned mode_mask)
+{
+	grid::child* cell = get_child(widget);
+	if(!cell) {
+		return;
+	}
+
+	unsigned flags = cell->get_flags();
+
+	if((flags & mode_mask) == HORIZONTAL_GROW_SEND_TO_CLIENT) {
+		ERR_GUI_G << "Cannot set horizontal alignment (grid cell specifies dynamic growth)" << std::endl;
+		return;
+	}
+
+	if((flags & mode_mask) == VERTICAL_GROW_SEND_TO_CLIENT) {
+		ERR_GUI_G << "Cannot set vertical alignment (grid cell specifies dynamic growth)" << std::endl;
+		return;
+	}
+
+	flags &= ~mode_mask;
+	flags |= set_flag;
+
+	cell->set_flags(flags);
+
+	event::message message;
+	fire(event::REQUEST_PLACEMENT, *this, message);
+}
+
+void grid::layout(const point& origin)
+{
+	point orig = origin;
 	for(unsigned row = 0; row < rows_; ++row) {
 		for(unsigned col = 0; col < cols_; ++col) {
 
-			const tpoint size(col_width_[col], row_height_[row]);
+			const point size(col_width_[col], row_height_[row]);
 			DBG_GUI_L << LOG_HEADER << " set widget at " << row << ',' << col
 					  << " at origin " << orig << " with size " << size
 					  << ".\n";
 
-			if(child(row, col).widget()) {
-				child(row, col).place(orig, size);
+			if(get_child(row, col).get_widget()) {
+				get_child(row, col).place(orig, size);
 			}
 
 			orig.x += col_width_[col];
@@ -895,7 +990,7 @@ void tgrid::layout(const tpoint& origin)
 	}
 }
 
-void tgrid::impl_draw_children(surface& frame_buffer)
+void grid::impl_draw_children(surface& frame_buffer, int x_offset, int y_offset)
 {
 	/*
 	 * The call to SDL_PumpEvents seems a bit like black magic.
@@ -906,60 +1001,21 @@ void tgrid::impl_draw_children(surface& frame_buffer)
 	 * Without the call when resizing larger a black area of remains, this is
 	 * the area not used for resizing the screen, this call `fixes' that.
 	 */
-	SDL_PumpEvents();
 
-	assert(get_visible() == twidget::tvisible::visible);
+	assert(get_visible() == widget::visibility::visible);
 	set_is_dirty(false);
 
-	FOREACH(AUTO & child, children_)
+	for(auto & child : children_)
 	{
 
-		twidget* widget = child.widget();
+		widget* widget = child.get_widget();
 		assert(widget);
 
-		if(widget->get_visible() != twidget::tvisible::visible) {
+		if(widget->get_visible() != widget::visibility::visible) {
 			continue;
 		}
 
-		if(widget->get_drawing_action() == twidget::tredraw_action::none) {
-			continue;
-		}
-
-		widget->draw_background(frame_buffer);
-		widget->draw_children(frame_buffer);
-		widget->draw_foreground(frame_buffer);
-		widget->set_is_dirty(false);
-	}
-}
-
-void
-tgrid::impl_draw_children(surface& frame_buffer, int x_offset, int y_offset)
-{
-	/*
-	 * The call to SDL_PumpEvents seems a bit like black magic.
-	 * With the call the resizing doesn't seem to lose resize events.
-	 * But when added the queue still only contains one resize event and the
-	 * internal SDL queue doesn't seem to overflow (rarely more than 50 pending
-	 * events).
-	 * Without the call when resizing larger a black area of remains, this is
-	 * the area not used for resizing the screen, this call `fixes' that.
-	 */
-	SDL_PumpEvents();
-
-	assert(get_visible() == twidget::tvisible::visible);
-	set_is_dirty(false);
-
-	FOREACH(AUTO & child, children_)
-	{
-
-		twidget* widget = child.widget();
-		assert(widget);
-
-		if(widget->get_visible() != twidget::tvisible::visible) {
-			continue;
-		}
-
-		if(widget->get_drawing_action() == twidget::tredraw_action::none) {
+		if(widget->get_drawing_action() == widget::redraw_action::none) {
 			continue;
 		}
 
@@ -970,17 +1026,17 @@ tgrid::impl_draw_children(surface& frame_buffer, int x_offset, int y_offset)
 	}
 }
 
-unsigned tgrid_implementation::row_request_reduce_height(
-		tgrid& grid, const unsigned row, const unsigned maximum_height)
+unsigned grid_implementation::row_request_reduce_height(
+		grid& grid, const unsigned row, const unsigned maximum_height)
 {
 	// The minimum height required.
 	unsigned required_height = 0;
 
 	for(size_t x = 0; x < grid.cols_; ++x) {
-		tgrid::tchild& cell = grid.child(row, x);
+		grid::child& cell = grid.get_child(row, x);
 		cell_request_reduce_height(cell, maximum_height);
 
-		const tpoint size(cell.get_best_size());
+		const point size(cell.get_best_size());
 
 		if(required_height == 0 || static_cast<size_t>(size.y)
 								   > required_height) {
@@ -995,17 +1051,17 @@ unsigned tgrid_implementation::row_request_reduce_height(
 	return required_height;
 }
 
-unsigned tgrid_implementation::column_request_reduce_width(
-		tgrid& grid, const unsigned column, const unsigned maximum_width)
+unsigned grid_implementation::column_request_reduce_width(
+		grid& grid, const unsigned column, const unsigned maximum_width)
 {
 	// The minimum width required.
 	unsigned required_width = 0;
 
 	for(size_t y = 0; y < grid.rows_; ++y) {
-		tgrid::tchild& cell = grid.child(y, column);
+		grid::child& cell = grid.get_child(y, column);
 		cell_request_reduce_width(cell, maximum_width);
 
-		const tpoint size(cell.get_best_size());
+		const point size(cell.get_best_size());
 
 		if(required_width == 0 || static_cast<size_t>(size.x)
 								  > required_width) {
@@ -1021,12 +1077,12 @@ unsigned tgrid_implementation::column_request_reduce_width(
 }
 
 void
-tgrid_implementation::cell_request_reduce_height(tgrid::tchild& child,
+grid_implementation::cell_request_reduce_height(grid::child& child,
 												 const unsigned maximum_height)
 {
 	assert(child.widget_);
 
-	if(child.widget_->get_visible() == twidget::tvisible::invisible) {
+	if(child.widget_->get_visible() == widget::visibility::invisible) {
 		return;
 	}
 
@@ -1035,26 +1091,26 @@ tgrid_implementation::cell_request_reduce_height(tgrid::tchild& child,
 }
 
 void
-tgrid_implementation::cell_request_reduce_width(tgrid::tchild& child,
+grid_implementation::cell_request_reduce_width(grid::child& child,
 												const unsigned maximum_width)
 {
 	assert(child.widget_);
 
-	if(child.widget_->get_visible() == twidget::tvisible::invisible) {
+	if(child.widget_->get_visible() == widget::visibility::invisible) {
 		return;
 	}
 
 	child.widget_->request_reduce_width(maximum_width - child.border_space().x);
 }
 
-void set_single_child(tgrid& grid, twidget* widget)
+void set_single_child(grid& grid, widget* widget)
 {
 	grid.set_rows_cols(1, 1);
 	grid.set_child(widget,
 				   0,
 				   0,
-				   tgrid::HORIZONTAL_GROW_SEND_TO_CLIENT
-				   | tgrid::VERTICAL_GROW_SEND_TO_CLIENT,
+				   grid::HORIZONTAL_GROW_SEND_TO_CLIENT
+				   | grid::VERTICAL_GROW_SEND_TO_CLIENT,
 				   0);
 }
 
@@ -1098,8 +1154,7 @@ void set_single_child(tgrid& grid, twidget* widget)
  *
  * * determine the extra size
  * * determine the sum of the grow factors
- * * if this sum is 0 set the grow factor for every item to 1 and sum to sum of
- *   items.
+ * * if this sum is 0 set the grow factor for every item to 1 and sum to sum of items.
  * * divide the extra size with the sum of grow factors
  * * for every item multiply the grow factor with the division value
  *
@@ -1149,9 +1204,9 @@ void set_single_child(tgrid& grid, twidget* widget)
  *  4.1 - 1.1 spacer
  *  4.1 - 1.2 spacer
  *  4.1 - 1.3 button : remove addon
- *  4.2 - 2.1 spacer
- *  4.2 - 2.2 button : connect
- *  4.2 - 2.3 button : cancel
+ *  4.1 - 2.1 spacer
+ *  4.1 - 2.2 button : connect
+ *  4.1 - 2.3 button : cancel
  *
  *
  *  |---------------------------------------|
@@ -1179,9 +1234,9 @@ void set_single_child(tgrid& grid, twidget* widget)
  *  3.1 - 1.2 text box : server to connect to
  *  4.1 - 1.1 spacer
  *  4.1 - 1.2 button : remove addon
- *  5.2 - 1.1 spacer
- *  5.2 - 1.2 button : connect
- *  5.2 - 1.3 button : cancel
+ *  5.1 - 1.1 spacer
+ *  5.1 - 1.2 button : connect
+ *  5.1 - 1.3 button : cancel
  *
  * = Praxis =
  *
