@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2008 - 2015 by Mark de Wever <koraq@xs4all.nl>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2008 - 2018 by Mark de Wever <koraq@xs4all.nl>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,11 +12,12 @@
    See the COPYING file for more details.
 */
 
-#ifndef GUI_WIDGETS_GRID_HPP_INCLUDED
-#define GUI_WIDGETS_GRID_HPP_INCLUDED
+#pragma once
 
 #include "gui/widgets/widget.hpp"
 
+#include <cassert>
+
 namespace gui2
 {
 
@@ -26,38 +27,42 @@ namespace gui2
  * This class holds a number of widgets and their wanted layout parameters. It
  * also layouts the items in the grid and handles their drawing.
  */
-class tgrid : public twidget
+class grid : public widget
 {
-	friend class tdebug_layout_graph;
-	friend struct tgrid_implementation;
+	friend class debug_layout_graph;
+	friend struct grid_implementation;
 
 public:
-	explicit tgrid(const unsigned rows = 0, const unsigned cols = 0);
+	explicit grid(const unsigned rows = 0, const unsigned cols = 0);
 
-	virtual ~tgrid();
+	/** Delete the copy constructor. */
+	grid(const grid&) = delete;
+
+	/** Delete the move assignment operator. */
+	grid& operator=(const grid&) = delete;
+
+	virtual ~grid();
 
 	/***** ***** ***** ***** LAYOUT FLAGS ***** ***** ***** *****/
-	static const unsigned VERTICAL_SHIFT = 0;
-	static const unsigned VERTICAL_GROW_SEND_TO_CLIENT = 1 << VERTICAL_SHIFT;
-	static const unsigned VERTICAL_ALIGN_TOP = 2 << VERTICAL_SHIFT;
-	static const unsigned VERTICAL_ALIGN_CENTER = 3 << VERTICAL_SHIFT;
-	static const unsigned VERTICAL_ALIGN_BOTTOM = 4 << VERTICAL_SHIFT;
-	static const unsigned VERTICAL_MASK = 7 << VERTICAL_SHIFT;
+	static const unsigned VERTICAL_SHIFT                 = 0;
+	static const unsigned VERTICAL_GROW_SEND_TO_CLIENT   = 1 << VERTICAL_SHIFT;
+	static const unsigned VERTICAL_ALIGN_TOP             = 2 << VERTICAL_SHIFT;
+	static const unsigned VERTICAL_ALIGN_CENTER          = 3 << VERTICAL_SHIFT;
+	static const unsigned VERTICAL_ALIGN_BOTTOM          = 4 << VERTICAL_SHIFT;
+	static const unsigned VERTICAL_MASK                  = 7 << VERTICAL_SHIFT;
 
-	static const unsigned HORIZONTAL_SHIFT = 3;
-	static const unsigned HORIZONTAL_GROW_SEND_TO_CLIENT = 1
-														   << HORIZONTAL_SHIFT;
-	static const unsigned HORIZONTAL_ALIGN_LEFT = 2 << HORIZONTAL_SHIFT;
-	static const unsigned HORIZONTAL_ALIGN_CENTER = 3 << HORIZONTAL_SHIFT;
-	static const unsigned HORIZONTAL_ALIGN_RIGHT = 4 << HORIZONTAL_SHIFT;
-	static const unsigned HORIZONTAL_MASK = 7 << HORIZONTAL_SHIFT;
+	static const unsigned HORIZONTAL_SHIFT               = 3;
+	static const unsigned HORIZONTAL_GROW_SEND_TO_CLIENT = 1 << HORIZONTAL_SHIFT;
+	static const unsigned HORIZONTAL_ALIGN_LEFT          = 2 << HORIZONTAL_SHIFT;
+	static const unsigned HORIZONTAL_ALIGN_CENTER        = 3 << HORIZONTAL_SHIFT;
+	static const unsigned HORIZONTAL_ALIGN_RIGHT         = 4 << HORIZONTAL_SHIFT;
+	static const unsigned HORIZONTAL_MASK                = 7 << HORIZONTAL_SHIFT;
 
-	static const unsigned BORDER_TOP = 1 << 6;
-	static const unsigned BORDER_BOTTOM = 1 << 7;
-	static const unsigned BORDER_LEFT = 1 << 8;
-	static const unsigned BORDER_RIGHT = 1 << 9;
-	static const unsigned BORDER_ALL = BORDER_TOP | BORDER_BOTTOM | BORDER_LEFT
-									   | BORDER_RIGHT;
+	static const unsigned BORDER_TOP                     = 1 << 6;
+	static const unsigned BORDER_BOTTOM                  = 1 << 7;
+	static const unsigned BORDER_LEFT                    = 1 << 8;
+	static const unsigned BORDER_RIGHT                   = 1 << 9;
+	static const unsigned BORDER_ALL = BORDER_TOP | BORDER_BOTTOM | BORDER_LEFT | BORDER_RIGHT;
 
 	/***** ***** ***** ***** ROW COLUMN MANIPULATION ***** ***** ***** *****/
 
@@ -112,12 +117,12 @@ public:
 	 *
 	 * @param widget              The widget to put in the grid.
 	 * @param row                 The row of the cell.
-	 * @param col                 The columnof the cell.
+	 * @param col                 The column of the cell.
 	 * @param flags               The flags for the widget in the cell.
 	 * @param border_size         The size of the border for the cell, how the
 	 *                            border is applied depends on the flags.
 	 */
-	void set_child(twidget* widget,
+	void set_child(widget* widget,
 				   const unsigned row,
 				   const unsigned col,
 				   const unsigned flags,
@@ -130,24 +135,24 @@ public:
 	 * touch the other settings of the child.
 	 *
 	 * @param id                  The id of the widget to free.
-	 * @param widget              The widget to put in the grid.
+	 * @param w                   The widget to put in the grid.
 	 * @param recurse             Do we want to decent into the child grids.
 	 * @param new_parent          The new parent for the swapped out widget.
 	 *
 	 * returns                    The widget which got removed (the parent of
 	 *                            the widget is cleared). If no widget found
-	 *                            and thus not replace NULL will returned.
+	 *                            and thus not replace nullptr will returned.
 	 */
-	twidget* swap_child(const std::string& id,
-						twidget* widget,
+	std::unique_ptr<widget> swap_child(const std::string& id,
+						widget* w,
 						const bool recurse,
-						twidget* new_parent = NULL);
+						widget* new_parent = nullptr);
 
 	/**
 	 * Removes and frees a widget in a cell.
 	 *
 	 * @param row                 The row of the cell.
-	 * @param col                 The columnof the cell.
+	 * @param col                 The column of the cell.
 	 */
 	void remove_child(const unsigned row, const unsigned col);
 
@@ -164,30 +169,30 @@ public:
 	/**
 	 * Activates all children.
 	 *
-	 * If a child inherits from tcontrol or is a tgrid it will call
+	 * If a child inherits from styled_widget or is a grid it will call
 	 * set_active() for the child otherwise it ignores the widget.
 	 *
 	 * @param active              Parameter for set_active.
 	 */
 	void set_active(const bool active);
 
-
 	/** Returns the widget in the selected cell. */
-	const twidget* widget(const unsigned row, const unsigned col) const
+	const widget* get_widget(const unsigned row, const unsigned col) const
 	{
-		return child(row, col).widget();
+		return get_child(row, col).get_widget();
 	}
 
 	/** Returns the widget in the selected cell. */
-	twidget* widget(const unsigned row, const unsigned col)
+	widget* get_widget(const unsigned row, const unsigned col)
 	{
-		return child(row, col).widget();
+		return get_child(row, col).get_widget();
 	}
 
+	virtual bool can_mouse_focus() const override { return false; }
 	/***** ***** ***** ***** layout functions ***** ***** ***** *****/
 
-	/** See @ref twidget::layout_initialise. */
-	virtual void layout_initialise(const bool full_initialisation) OVERRIDE;
+	/** See @ref widget::layout_initialize. */
+	virtual void layout_initialize(const bool full_initialization) override;
 
 	/**
 	 * Tries to reduce the width of a container.
@@ -198,11 +203,11 @@ public:
 	 */
 	void reduce_width(const unsigned maximum_width);
 
-	/** See @ref twidget::request_reduce_width. */
-	virtual void request_reduce_width(const unsigned maximum_width) OVERRIDE;
+	/** See @ref widget::request_reduce_width. */
+	virtual void request_reduce_width(const unsigned maximum_width) override;
 
-	/** See @ref twidget::demand_reduce_width. */
-	virtual void demand_reduce_width(const unsigned maximum_width) OVERRIDE;
+	/** See @ref widget::demand_reduce_width. */
+	virtual void demand_reduce_width(const unsigned maximum_width) override;
 
 	/**
 	 * Tries to reduce the height of a container.
@@ -213,11 +218,11 @@ public:
 	 */
 	void reduce_height(const unsigned maximum_height);
 
-	/** See @ref twidget::request_reduce_height. */
-	virtual void request_reduce_height(const unsigned maximum_height) OVERRIDE;
+	/** See @ref widget::request_reduce_height. */
+	virtual void request_reduce_height(const unsigned maximum_height) override;
 
-	/** See @ref twidget::demand_reduce_height. */
-	virtual void demand_reduce_height(const unsigned maximum_height) OVERRIDE;
+	/** See @ref widget::demand_reduce_height. */
+	virtual void demand_reduce_height(const unsigned maximum_height) override;
 
 	/**
 	 * Recalculates the best size.
@@ -227,59 +232,74 @@ public:
 	 *
 	 * @returns                   The newly calculated size.
 	 */
-	tpoint recalculate_best_size();
+	point recalculate_best_size();
+
+	/**
+	 * Modifies the widget alignment data of a child cell containing a specific widget.
+	 *
+	 * @param widget              The widget whose cell to modify.
+	 * @param set_flag            The alignment flag to set.
+	 * @param mode_mask           Whether to affect horizontal or vertical alignment.
+	 *                            Use either HORIZONTAL_MASK or VERTICAL_MASK
+	 */
+	void set_child_alignment(widget* widget, unsigned set_flag, unsigned mode_mask);
 
 private:
-	/** See @ref twidget::calculate_best_size. */
-	virtual tpoint calculate_best_size() const OVERRIDE;
+	/** See @ref widget::calculate_best_size. */
+	virtual point calculate_best_size() const override;
+
+	/**
+	* Attempts to lay out the grid without laying out the entire window.
+	*/
+	void request_placement(dispatcher& dispatcher, const event::ui_event event, bool& handled, bool& halt);
 
 public:
-	/** See @ref twidget::can_wrap. */
-	virtual bool can_wrap() const OVERRIDE;
+	/** See @ref widget::can_wrap. */
+	virtual bool can_wrap() const override;
 
 public:
-	/** See @ref twidget::place. */
-	virtual void place(const tpoint& origin, const tpoint& size) OVERRIDE;
+	/** See @ref widget::place. */
+	virtual void place(const point& origin, const point& size) override;
 
 	/***** ***** ***** ***** Inherited ***** ***** ***** *****/
 
-	/** See @ref twidget::set_origin. */
-	virtual void set_origin(const tpoint& origin) OVERRIDE;
+	/** See @ref widget::set_origin. */
+	virtual void set_origin(const point& origin) override;
 
-	/** See @ref twidget::set_visible_rectangle. */
-	virtual void set_visible_rectangle(const SDL_Rect& rectangle) OVERRIDE;
+	/** See @ref widget::set_visible_rectangle. */
+	virtual void set_visible_rectangle(const SDL_Rect& rectangle) override;
 
-	/** See @ref twidget::layout_children. */
-	virtual void layout_children() OVERRIDE;
+	/** See @ref widget::layout_children. */
+	virtual void layout_children() override;
 
-	/** See @ref twidget::child_populate_dirty_list. */
+	/** See @ref widget::child_populate_dirty_list. */
 	virtual void
-	child_populate_dirty_list(twindow& caller,
-							  const std::vector<twidget*>& call_stack) OVERRIDE;
+	child_populate_dirty_list(window& caller,
+							  const std::vector<widget*>& call_stack) override;
 
-	/** See @ref twidget::find_at. */
-	virtual twidget* find_at(const tpoint& coordinate,
-							 const bool must_be_active) OVERRIDE;
+	/** See @ref widget::find_at. */
+	virtual widget* find_at(const point& coordinate,
+							 const bool must_be_active) override;
 
-	/** See @ref twidget::find_at. */
-	virtual const twidget* find_at(const tpoint& coordinate,
-								   const bool must_be_active) const OVERRIDE;
+	/** See @ref widget::find_at. */
+	virtual const widget* find_at(const point& coordinate,
+								   const bool must_be_active) const override;
 
-	/** See @ref twidget::find. */
-	twidget* find(const std::string& id, const bool must_be_active) OVERRIDE;
+	/** See @ref widget::find. */
+	widget* find(const std::string& id, const bool must_be_active) override;
 
-	/** See @ref twidget::find. */
-	const twidget* find(const std::string& id,
-						const bool must_be_active) const OVERRIDE;
+	/** See @ref widget::find. */
+	const widget* find(const std::string& id,
+						const bool must_be_active) const override;
 
-	/** See @ref twidget::has_widget. */
-	virtual bool has_widget(const twidget& widget) const OVERRIDE;
+	/** See @ref widget::has_widget. */
+	virtual bool has_widget(const widget& widget) const override;
 
-	/** See @ref twidget::disable_click_dismiss. */
-	bool disable_click_dismiss() const OVERRIDE;
+	/** See @ref widget::disable_click_dismiss. */
+	bool disable_click_dismiss() const override;
 
-	/** See @ref twidget::create_walker. */
-	virtual iterator::twalker_* create_walker() OVERRIDE;
+	/** See @ref widget::create_walker. */
+	virtual iteration::walker_base* create_walker() override;
 
 	/***** ***** ***** setters / getters for members ***** ****** *****/
 
@@ -305,20 +325,37 @@ public:
 
 private:
 	/** Child item of the grid. */
-	class tchild
+	class child
 	{
-		friend struct tgrid_implementation;
+		friend struct grid_implementation;
 
 	public:
-		tchild() : flags_(0), border_size_(0), widget_(NULL)
-
 		// Fixme make a class where we can store some properties in the cache
 		// regarding size etc.
+		child() : flags_(0), border_size_(0), widget_(nullptr)
 		{
 		}
 
+		/**
+		 * Move constructor.
+		 *
+		 * This is necessary in order that the child objects be moved instead
+		 * of copied when the grid's child vector is resized. std::vector will
+		 * utilize a move constructor as long as a non-throwing one is provided.
+		 */
+#if defined(_MSC_VER) && _MSC_VER <= 1800 // MSVC 2013
+		child(child&& c) NOEXCEPT
+			: flags_(c.flags_)
+			, border_size_(c.border_size_)
+			, widget_(std::move(c.widget_))
+		{
+		}
+#else
+		child(child&&) NOEXCEPT = default;
+#endif
+
 		/** Returns the best size for the cell. */
-		tpoint get_best_size() const;
+		point get_best_size() const;
 
 		/**
 		 * Places the widget in the cell.
@@ -326,10 +363,10 @@ private:
 		 * @param origin          The origin (x, y) for the widget.
 		 * @param size            The size for the widget.
 		 */
-		void place(tpoint origin, tpoint size);
+		void place(point origin, point size);
 
-		/** Forwards @ref tgrid::layout_initialise to the cell. */
-		void layout_initialise(const bool full_initialisation);
+		/** Forwards @ref grid::layout_initialize to the cell. */
+		void layout_initialize(const bool full_initialization);
 
 		/** Returns the can_wrap for the cell. */
 		bool can_wrap() const
@@ -344,6 +381,7 @@ private:
 		{
 			return flags_;
 		}
+
 		void set_flags(const unsigned flags)
 		{
 			flags_ = flags;
@@ -353,23 +391,37 @@ private:
 		{
 			return border_size_;
 		}
+
 		void set_border_size(const unsigned border_size)
 		{
 			border_size_ = border_size;
 		}
 
-		const twidget* widget() const
+		const widget* get_widget() const
 		{
-			return widget_;
-		}
-		twidget* widget()
-		{
-			return widget_;
+			return widget_.get();
 		}
 
-		void set_widget(twidget* widget)
+		widget* get_widget()
 		{
-			widget_ = widget;
+			return widget_.get();
+		}
+
+		void set_widget(widget* widget)
+		{
+			widget_.reset(widget);
+		}
+
+		/**
+		 * Releases widget from ownership by this child and returns it in the
+		 * form of a new unique_ptr. widget_ will be null after this is called.
+		 */
+		std::unique_ptr<widget> free_widget()
+		{
+			std::unique_ptr<widget> temp(nullptr);
+			widget_.swap(temp);
+
+			return temp;
 		}
 
 	private:
@@ -385,23 +437,23 @@ private:
 		/**
 		 * Pointer to the widget.
 		 *
-		 * Once the widget is assigned to the grid we own the widget and are
-		 * responsible for it's destruction.
+		 * Once the widget is assigned to the grid we own the widget and it
+		 * will be destroyed with the grid or @ref free_widget is called.
 		 */
-		twidget* widget_;
+		std::unique_ptr<widget> widget_;
 
 		/** Returns the space needed for the border. */
-		tpoint border_space() const;
+		point border_space() const;
 
-	}; // class tchild
+	}; // class child
 
 public:
-	/** Iterator for the tchild items. */
+	/** Iterator for the child items. */
 	class iterator
 	{
 
 	public:
-		iterator(std::vector<tchild>::iterator itor) : itor_(itor)
+		iterator(std::vector<child>::iterator itor) : itor_(itor)
 		{
 		}
 
@@ -413,13 +465,13 @@ public:
 		{
 			return iterator(--itor_);
 		}
-		twidget* operator->()
+		widget* operator->()
 		{
-			return itor_->widget();
+			return itor_->get_widget();
 		}
-		twidget* operator*()
+		widget* operator*()
 		{
-			return itor_->widget();
+			return itor_->get_widget();
 		}
 
 		bool operator==(const iterator& i) const
@@ -433,7 +485,7 @@ public:
 		}
 
 	private:
-		std::vector<tchild>::iterator itor_;
+		std::vector<child>::iterator itor_;
 	};
 
 	iterator begin()
@@ -472,26 +524,51 @@ private:
 	 * All children are stored in a 1D vector and the formula to access a cell
 	 * is: rows_ * col + row. All other vectors use the same access formula.
 	 */
-	std::vector<tchild> children_;
-	const tchild& child(const unsigned row, const unsigned col) const
+	std::vector<child> children_;
+
+	/**
+	 * Gets the grid child in the specified cell.
+	 *
+	 * @param row                 The row of the cell.
+	 * @param col                 The column of the cell.
+	 *
+	 * @returns                   A const reference to the specified grid child.
+	 */
+	const grid::child& get_child(const unsigned row, const unsigned col) const
 	{
 		return children_[rows_ * col + row];
 	}
-	tchild& child(const unsigned row, const unsigned col)
+
+	/**
+	 * Gets the grid child in the specified cell.
+	 *
+	 * @param row                 The row of the cell.
+	 * @param col                 The column of the cell.
+	 *
+	 * @returns                   A const reference to the specified grid child.
+	 */
+	grid::child& get_child(const unsigned row, const unsigned col)
 	{
 		return children_[rows_ * col + row];
 	}
 
+	/**
+	 * Gets the grid child containing the specified widget.
+	 *
+	 * @param w                   The widget to search for.
+	 *
+	 * @returns                   A pointer to the relevant grid child, or nullptr
+	 *                            if no grid cell 'owns' the given widget.
+	 */
+	grid::child* get_child(widget* w);
+
 	/** Layouts the children in the grid. */
-	void layout(const tpoint& origin);
+	void layout(const point& origin);
 
-	/** See @ref twidget::impl_draw_children. */
-	virtual void impl_draw_children(surface& frame_buffer) OVERRIDE;
-
-	/** See @ref twidget::impl_draw_children. */
+	/** See @ref widget::impl_draw_children. */
 	virtual void impl_draw_children(surface& frame_buffer,
 									int x_offset,
-									int y_offset) OVERRIDE;
+									int y_offset) override;
 };
 
 /**
@@ -503,8 +580,6 @@ private:
  * @param grid                    The grid to add the child to.
  * @param widget                  The widget to add as child to the grid.
  */
-void set_single_child(tgrid& grid, twidget* widget);
+void set_single_child(grid& grid, widget* widget);
 
 } // namespace gui2
-
-#endif
