@@ -14,8 +14,6 @@
 
 #pragma once
 
-#ifndef GUI2_EXPERIMENTAL_LISTBOX
-
 #include "gui/widgets/generator.hpp"
 #include "gui/widgets/scrollbar_container.hpp"
 
@@ -417,6 +415,11 @@ private:
 	/** Inherited from scrollbar_container. */
 	virtual void set_content_size(const point& origin, const point& size) override;
 
+public:
+	/** Static type getter that does not rely on the widget being constructed. */
+	static const std::string& type();
+
+private:
 	/** Inherited from styled_widget, implemented by REGISTER_WIDGET. */
 	virtual const std::string& get_control_type() const override;
 
@@ -521,5 +524,3 @@ struct builder_grid_listbox : public builder_styled_widget
 // }------------ END --------------
 
 } // namespace gui2
-
-#endif
