@@ -28,7 +28,7 @@ namespace gui2
 REGISTER_WIDGET(size_lock)
 
 size_lock::size_lock(const implementation::builder_size_lock& builder)
-	: container_base(builder, get_control_type())
+	: container_base(builder, type())
 	, width_(builder.width_)
 	, height_(builder.height_)
 	, widget_(nullptr)
