@@ -57,7 +57,7 @@ struct stacked_widget_implementation
 };
 
 stacked_widget::stacked_widget(const implementation::builder_stacked_widget& builder)
-	: container_base(builder, get_control_type())
+	: container_base(builder, type())
 	, generator_(generator_base::build(false, false, generator_base::independent, false))
 	, selected_layer_(-1)
 	, find_in_all_layers_(false)
