@@ -34,7 +34,7 @@
 #include <iostream>                     // for operator<<, basic_ostream, etc
 #include <map>                          // for map, etc
 #include <set>
-#include <SDL.h>
+#include <SDL2/SDL.h>
 
 static lg::log_domain log_help("help");
 #define WRN_HP LOG_STREAM(warn, log_help)
@@ -505,20 +505,42 @@ std::string unit_topic_generator::operator()() const {
 
 	// Print some basic information such as HP and movement points.
 	// TODO: Make this info update according to musthave traits, similar to movetype below.
-	ss << _("HP: ") << type_.hitpoints() << jump(30)
-		<< _("Moves: ") << type_.movement() << jump(30);
+
+	// TRANSLATORS: This string is used in the help page of a single unit.  If the translation
+	// uses spaces, use non-breaking spaces as appropriate for the target language to prevent
+	// unpleasant line breaks (issue #3256).
+	ss << _("HP:") << font::nbsp << type_.hitpoints() << jump(30)
+		// TRANSLATORS: This string is used in the help page of a single unit.  If the translation
+		// uses spaces, use non-breaking spaces as appropriate for the target language to prevent
+		// unpleasant line breaks (issue #3256).
+		<< _("Moves:") << font::nbsp << type_.movement() << jump(30);
 	if (type_.vision() != type_.movement()) {
-		ss << _("Vision: ") << type_.vision() << jump(30);
+		// TRANSLATORS: This string is used in the help page of a single unit.  If the translation
+		// uses spaces, use non-breaking spaces as appropriate for the target language to prevent
+		// unpleasant line breaks (issue #3256).
+		ss << _("Vision:") << font::nbsp << type_.vision() << jump(30);
 	}
 	if (type_.jamming() > 0) {
-		ss << _("Jamming: ") << type_.jamming() << jump(30);
+		// TRANSLATORS: This string is used in the help page of a single unit.  If the translation
+		// uses spaces, use non-breaking spaces as appropriate for the target language to prevent
+		// unpleasant line breaks (issue #3256).
+		ss << _("Jamming:") << font::nbsp << type_.jamming() << jump(30);
 	}
-	ss << _("Cost: ") << type_.cost() << jump(30)
-		<< _("Alignment: ")
+	// TRANSLATORS: This string is used in the help page of a single unit.  If the translation
+	// uses spaces, use non-breaking spaces as appropriate for the target language to prevent
+	// unpleasant line breaks (issue #3256).
+	ss << _("Cost:") << font::nbsp << type_.cost() << jump(30)
+		// TRANSLATORS: This string is used in the help page of a single unit.  If the translation
+		// uses spaces, use non-breaking spaces as appropriate for the target language to prevent
+		// unpleasant line breaks (issue #3256).
+		<< _("Alignment:") << font::nbsp
 		<< make_link(type_.alignment_description(type_.alignment(), type_.genders().front()), "time_of_day")
 		<< jump(30);
 	if (type_.can_advance()) {
-		ss << _("Required XP: ") << type_.experience_needed();
+		// TRANSLATORS: This string is used in the help page of a single unit.  It uses
+		// non-breaking spaces to prevent unpleasant line breaks (issue #3256).  In the
+		// translation use non-breaking spaces as appropriate for the target language.
+		ss << _("Required\u00a0XP:") << font::nbsp << type_.experience_needed();
 	}
 
 	// Print the detailed description about the unit.
@@ -672,7 +694,7 @@ std::string unit_topic_generator::operator()() const {
 			}
 
 			if (info.union_type().size() == 1 && info.union_type()[0] == info.number() && info.is_nonnull()) {
-				terrain_movement_info movement_info = 
+				terrain_movement_info movement_info =
 				{
 					info.name(),
 					info.id(),
@@ -818,7 +840,7 @@ std::string unit_topic_generator::operator()() const {
 
 			table.push_back(row);
 		}
-		
+
 		ss << generate_table(table);
 	} else {
 		WRN_HP << "When building unit help topics, the display object was null and we couldn't get the terrain info we need.\n";
