@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2003 - 2015 by David White <dave@whitevine.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2003 - 2018 by David White <dave@whitevine.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,9 +12,7 @@
    See the COPYING file for more details.
 */
 
-#ifndef HOTKEY_MANAGER_HPP_INCLUDED
-#define HOTKEY_MANAGER_HPP_INCLUDED
-
+#pragma once
 
 /* The hotkey system allows hotkey definitions to be loaded from
  * configuration objects, and then detect if a keyboard event
@@ -33,5 +31,3 @@ public:
 };
 
 }
-
-#endif
