@@ -278,7 +278,7 @@ surface adjust_alpha_modification::operator()(const surface & src) const
 
 	wfl::formula new_alpha(formula_);
 
-	surface nsurf(make_neutral_surface(src));
+	surface nsurf = src.clone();
 
 	if(nsurf == nullptr) {
 		std::cerr << "could not make neutral surface...\n";
@@ -325,7 +325,7 @@ surface adjust_channels_modification::operator()(const surface & src) const
 	wfl::formula new_blue(formulas_[2]);
 	wfl::formula new_alpha(formulas_[3]);
 
-	surface nsurf(make_neutral_surface(src));
+	surface nsurf = src.clone();
 
 	if(nsurf == nullptr) {
 		std::cerr << "could not make neutral surface...\n";
@@ -383,8 +383,7 @@ surface crop_modification::operator()(const surface& src) const
 	 * Since it seems to work for most cases, rather change this caller instead
 	 * of the function signature. (The issue was discovered in bug #20876).
 	 */
-	surface temp = cut_surface(make_neutral_surface(src), area);
-	return temp;
+	return cut_surface(src, area);
 }
 
 surface blit_modification::operator()(const surface& src) const
@@ -407,28 +406,25 @@ surface blit_modification::operator()(const surface& src) const
 		throw imod_exception(sstr);
 	}
 
-	if(surf_->w + x_ > src->w) {
+	if(surf_->w + x_ < 0) {
 		std::stringstream sstr;
 		sstr << "~BLIT(): offset and width '"
-			<< x_ + surf_->w << "' larger than destination image's width '"
-			<< src->w << "' no blitting performed.\n";
+			<< x_ + surf_->w << "' less than zero no blitting performed.\n";
 
 		throw imod_exception(sstr);
 	}
 
-	if(surf_->h + y_ > src->h) {
+	if(surf_->h + y_ < 0) {
 		std::stringstream sstr;
 		sstr << "~BLIT(): offset and height '"
-			<< y_ + surf_->h << "' larger than destination image's height '"
-			<< src->h << "' no blitting performed.\n";
+			<< y_ + surf_->h << "' less than zero no blitting performed.\n";
 
 		throw imod_exception(sstr);
 	}
 
-	surface nsrc = make_neutral_surface(src);
-	surface nsurf = make_neutral_surface(surf_);
+	surface nsrc = src.clone();
 	SDL_Rect r {x_, y_, 0, 0};
-	sdl_blit(nsurf, nullptr, nsrc, &r);
+	sdl_blit(surf_, nullptr, nsrc, &r);
 	return nsrc;
 }
 
@@ -439,7 +435,7 @@ surface mask_modification::operator()(const surface& src) const
 	}
 
 	SDL_Rect r {x_, y_, 0, 0};
-	surface new_mask = create_neutral_surface(src->w, src->h);
+	surface new_mask(src->w, src->h);
 	sdl_blit(mask_, nullptr, new_mask, &r);
 	return mask_surface(src, new_mask);
 }
@@ -452,7 +448,7 @@ surface light_modification::operator()(const surface& src) const {
 	if(surf_->w != src->w || surf_->h != src->h) {
 		nsurf = scale_surface(surf_, src->w, src->h);
 	} else {
-		nsurf = make_neutral_surface(surf_);
+		nsurf = surf_;
 	}
 
 	return light_surface(src, nsurf);
@@ -534,7 +530,7 @@ surface xbrz_modification::operator()(const surface& src) const
  */
 surface o_modification::operator()(const surface& src) const
 {
-	surface nsurf(make_neutral_surface(src));
+	surface nsurf = src.clone();
 
 	if(nsurf == nullptr) {
 		std::cerr << "could not make neutral surface...\n";
@@ -557,7 +553,7 @@ surface o_modification::operator()(const surface& src) const
 				g = (*beg) >> 8;
 				b = (*beg);
 
-				alpha = std::min<unsigned>(unsigned(fxpmult(alpha,amount)), 255);
+				alpha = std::min<unsigned>(static_cast<unsigned>(fxpmult(alpha,amount)), 255);
 				*beg = (alpha << 24) + (r << 16) + (g << 8) + b;
 			}
 
@@ -588,11 +584,10 @@ surface bl_modification::operator()(const surface& src) const
 
 surface background_modification::operator()(const surface &src) const
 {
-	surface ret = make_neutral_surface(src);
+	surface ret = src.clone();
 	SDL_FillRect(ret, nullptr, SDL_MapRGBA(ret->format, color_.r, color_.g,
 					    color_.b, color_.a));
-	surface temp = src;
-	sdl_blit(temp, nullptr, ret, nullptr);
+	sdl_blit(src, nullptr, ret, nullptr);
 	return ret;
 }
 
@@ -1016,6 +1011,11 @@ REGISTER_MOD_PARSER(BLIT, args)
 		return nullptr;
 	}
 
+	if(s > 3){
+		ERR_DP << "too many arguments passed to the ~BLIT() function" << std::endl;
+		return nullptr;
+	}
+
 	int x = 0, y = 0;
 
 	if(s == 3) {
@@ -1023,11 +1023,6 @@ REGISTER_MOD_PARSER(BLIT, args)
 		y = lexical_cast_default<int>(param[2]);
 	}
 
-	if(x < 0 || y < 0) {
-		ERR_DP << "negative position arguments in ~BLIT() function" << std::endl;
-		return nullptr;
-	}
-
 	const image::locator img(param[0]);
 	std::stringstream message;
 	message << "~BLIT():";
