@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2011 - 2015 by Fabian Mueller
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2011 - 2018 by Fabian Mueller
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,8 +13,10 @@
 */
 
 #include "joystick.hpp"
-#include "preferences.hpp"
+#include "preferences/general.hpp"
 #include "log.hpp"
+#include "sdl/surface.hpp"
+#include "utils/math.hpp"
 #include <boost/math/constants/constants.hpp>
 using namespace boost::math::constants;
 
@@ -35,13 +37,12 @@ joystick_manager::~joystick_manager() {
 	close();
 }
 
-#if SDL_VERSION_ATLEAST(2,0,0)
 
 static bool attached(
 		  const std::vector<SDL_Joystick*>& joysticks
 		, const size_t index)
 {
-	return SDL_JoystickGetAttached(joysticks[index]);
+	return SDL_JoystickGetAttached(joysticks[index]) == SDL_TRUE;
 }
 
 static const char* name(
@@ -51,19 +52,6 @@ static const char* name(
 	return SDL_JoystickName(joysticks[index]);
 }
 
-#else
-
-static bool attached(const std::vector<SDL_Joystick*>&, const size_t index)
-{
-	return SDL_JoystickOpened(index);
-}
-
-static const char* name(const std::vector<SDL_Joystick*>&, const size_t index)
-{
-	return SDL_JoystickName(index);
-}
-
-#endif
 
 bool joystick_manager::close() {
 	if(SDL_WasInit(SDL_INIT_JOYSTICK) == 0)
@@ -153,7 +141,7 @@ std::pair<double, double> joystick_manager::get_mouse_axis_pair() {
 		return std::make_pair(0.0, 0.0);
 
 	// TODO do some math to normalize over the value - deadzone.
-	//const double relation = abs( (double)values.first / (double)values.second );
+	//const double relation = std::abs( (double)values.first / (double)values.second );
 	//const int range_x = values.first - round_double(relation * deadzone);
 	//const int range_y = values.second - ((1.0 - relation) * deadzone);
 	//double x_value = ((double)(values.first - deadzone) / (double)(32768 - deadzone)) *
@@ -296,9 +284,8 @@ bool joystick_manager::update_highlighted_hex(map_location& highlighted_hex, con
 	//const bool greater_deadzone = radius > deadzone;
 	//const bool greater_threshold2 = radius > threshold2;
 
-	int x = selected_hex.x + round_double(x_axis / 3200);
-	int y = selected_hex.y + round_double(y_axis / 3200);
-	highlighted_hex = map_location(x,y);
+	highlighted_hex = selected_hex;
+	highlighted_hex.add(round_double(x_axis / 3200), round_double(y_axis / 3200));
 
 	//if (!greater_threshold) {
 	//	counter_ = 0;
@@ -357,20 +344,19 @@ bool joystick_manager::update_highlighted_hex(map_location& highlighted_hex) {
 	return true;
 }
 
-const map_location joystick_manager::get_direction(const map_location& loc, joystick_manager::DIRECTION direction) {
-
-	int x = loc.x;
-	int y = loc.y;
+const map_location joystick_manager::get_direction(const map_location& loc, joystick_manager::DIRECTION direction)
+{
+	map_location l = loc;
 
 	switch(direction) {
-		case NORTH:      return map_location(x, y - 1);
-		case SOUTH:      return map_location(x, y + 1);
-		case SOUTH_EAST: return map_location(x + 1, y + (1+is_odd(x))/2 );
-		case SOUTH_WEST: return map_location(x - 1, y + (1+is_odd(x))/2 );
-		case NORTH_EAST: return map_location(x + 1, y - (1+is_even(x))/2 );
-		case NORTH_WEST: return map_location(x - 1, y - (1+is_even(x))/2 );
-		case WEST:       return map_location(x - 1, y);
-		case EAST:       return map_location(x + 1, y);
+		case NORTH:      return l.get_direction(map_location::NORTH);
+		case SOUTH:      return l.get_direction(map_location::SOUTH);
+		case SOUTH_EAST: return l.get_direction(map_location::SOUTH_EAST);
+		case SOUTH_WEST: return l.get_direction(map_location::SOUTH_WEST);
+		case NORTH_EAST: return l.get_direction(map_location::NORTH_EAST);
+		case NORTH_WEST: return l.get_direction(map_location::NORTH_WEST);
+		case WEST:       l.add(-1, 0); return l;
+		case EAST:       l.add(1, 0); return l;
 		default:
 			assert(false);
 			return map_location();
@@ -400,7 +386,7 @@ double joystick_manager::get_angle() {
 
 const map_location joystick_manager::get_next_hex(int x_axis, int y_axis, map_location loc)  {
 
-	map_location new_loc = map_location::null_location;
+	map_location new_loc = map_location::null_location();
 
 	if (x_axis == 0) return (y_axis > 0) ? get_direction(loc, SOUTH) : get_direction(loc, NORTH);
 	if (y_axis == 0) return (x_axis > 0) ? get_direction(loc, EAST) : get_direction(loc, WEST);
@@ -434,4 +420,3 @@ const map_location joystick_manager::get_next_hex(int x_axis, int y_axis, map_lo
 
 	return new_loc;
 }
-
