@@ -17,7 +17,7 @@
 #include <vector>
 #include "map/location.hpp"
 
-#include <SDL.h>
+#include <SDL2/SDL.h>
 
 class joystick_manager {
 
