@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2011 - 2015 by Mark de Wever <koraq@xs4all.nl>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2011 - 2018 by Mark de Wever <koraq@xs4all.nl>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,30 +15,29 @@
 #include "lua_jailbreak_exception.hpp"
 
 #include <cassert>
-#include <cstring> // Needed for NULL.
 
-tlua_jailbreak_exception *tlua_jailbreak_exception::jailbreak_exception = NULL;
+lua_jailbreak_exception *lua_jailbreak_exception::jailbreak_exception = nullptr;
 
-void tlua_jailbreak_exception::store() const throw()
+void lua_jailbreak_exception::store() const NOEXCEPT
 {
 	/*
 	 * It should not be  possible to call this function with an exception still
 	 * pending. It could happen if the code doesn't call
-	 * tlua_jailbreak_exception::rethrow() or a logic error in the code.
+	 * lua_jailbreak_exception::rethrow() or a logic error in the code.
 	 */
 	assert(!jailbreak_exception);
 
 	jailbreak_exception = this->clone();
 }
 
-void tlua_jailbreak_exception::rethrow()
+void lua_jailbreak_exception::rethrow()
 {
 	if(!jailbreak_exception) {
 		return;
 	}
 
 	/*
-	 * We need to call tlua_jailbreak_exception::clear() after the exception
+	 * We need to call lua_jailbreak_exception::clear() after the exception
 	 * is thrown. The most straightforward approach would be a small helper
 	 * class calling clear in its destructor, but alas g++ then complains about
 	 * an unused variable. Since we're sure there will be something thrown use
@@ -55,9 +54,8 @@ void tlua_jailbreak_exception::rethrow()
 	assert(false);
 }
 
-void tlua_jailbreak_exception::clear() throw()
+void lua_jailbreak_exception::clear() NOEXCEPT
 {
 	delete jailbreak_exception;
-	jailbreak_exception = NULL;
+	jailbreak_exception = nullptr;
 }
-
