@@ -19,7 +19,7 @@
 #include "map/location.hpp"
 #include "tstring.hpp"
 
-#include <SDL_rect.h>
+#include <SDL2/SDL_rect.h>
 #include <map>
 #include <string>
 
