@@ -88,10 +88,10 @@ static lg::log_domain log_engine("engine");
 
 namespace events
 {
-menu_handler::menu_handler(game_display* gui, play_controller& pc, const config& game_config)
+menu_handler::menu_handler(game_display* gui, play_controller& pc)
 	: gui_(gui)
 	, pc_(pc)
-	, game_config_(game_config)
+	, game_config_(game_config_manager::get()->game_config())
 	, textbox_info_()
 	, last_search_()
 	, last_search_hit_()
@@ -159,10 +159,10 @@ void menu_handler::unit_list()
 
 void menu_handler::status_table()
 {
-	int selected_index;
+	int selected_side;
 
-	if(gui2::dialogs::game_stats::execute(board(), gui_->viewing_team(), selected_index)) {
-		gui_->scroll_to_leader(teams()[selected_index].side());
+	if(gui2::dialogs::game_stats::execute(board(), gui_->viewing_team(), selected_side)) {
+		gui_->scroll_to_leader(selected_side);
 	}
 }
 
@@ -275,11 +275,14 @@ void menu_handler::recruit(int side_num, const map_location& last_hex)
 
 	gui2::dialogs::unit_recruit dlg(sample_units, board().get_team(side_num));
 
-	dlg.show();
-
-	if(dlg.get_retval() == gui2::retval::OK) {
+	if(dlg.show()) {
 		map_location recruit_hex = last_hex;
-		do_recruit(sample_units[dlg.get_selected_index()]->id(), side_num, recruit_hex);
+		int index = dlg.get_selected_index();
+		if (index < 0) {
+			gui2::show_transient_message("", _("No unit recruited"));
+			return;
+		}
+		do_recruit(sample_units[index]->id(), side_num, recruit_hex);
 	}
 }
 
@@ -373,9 +376,7 @@ void menu_handler::recall(int side_num, const map_location& last_hex)
 
 	gui2::dialogs::unit_recall dlg(recall_list_team, current_team);
 
-	dlg.show();
-
-	if(dlg.get_retval() != gui2::retval::OK) {
+	if(!dlg.show()) {
 		return;
 	}
 
@@ -438,6 +439,9 @@ void menu_handler::show_enemy_moves(bool ignore_units, int side_num)
 {
 	wb::future_map future; // use unit positions as if all planned actions were executed
 
+	mouse_handler& mh = pc_.get_mouse_handler_base();
+	const map_location& hex_under_mouse = mh.hovered_hex();
+
 	gui_->unhighlight_reach();
 
 	// Compute enemy movement positions
@@ -450,14 +454,15 @@ void menu_handler::show_enemy_moves(bool ignore_units, int side_num)
 			const pathfind::paths& path
 					= pathfind::paths(u, false, true, teams()[gui_->viewing_team()], 0, false, ignore_units);
 
-			gui_->highlight_another_reach(path);
+			gui_->highlight_another_reach(path, hex_under_mouse);
 		}
+
+		// Need to recompute ellipses for highlighted enemy units
+		gui_->invalidate(u.get_location());
 	}
 
 	// Find possible unit (no matter whether friend or foe) under the
 	// mouse cursor.
-	mouse_handler& mh = pc_.get_mouse_handler_base();
-	const map_location& hex_under_mouse = mh.hovered_hex();
 	const bool selected_hex_has_unit = mh.hex_hosts_unit(hex_under_mouse);
 
 	if(selected_hex_has_unit) {
@@ -639,13 +644,14 @@ void menu_handler::rename_unit()
 unit_map::iterator menu_handler::current_unit()
 {
 	const mouse_handler& mousehandler = pc_.get_mouse_handler_base();
+	const bool see_all = gui_->show_everything() || (pc_.is_replay() && pc_.get_replay_controller()->see_all());
 
-	unit_map::iterator res = board().find_visible_unit(mousehandler.get_last_hex(), teams()[gui_->viewing_team()]);
+	unit_map::iterator res = board().find_visible_unit(mousehandler.get_last_hex(), teams()[gui_->viewing_team()], see_all);
 	if(res != units().end()) {
 		return res;
 	}
 
-	return board().find_visible_unit(mousehandler.get_selected_hex(), teams()[gui_->viewing_team()]);
+	return board().find_visible_unit(mousehandler.get_selected_hex(), teams()[gui_->viewing_team()], see_all);
 }
 
 // Helpers for create_unit()
@@ -788,7 +794,7 @@ void menu_handler::label_terrain(mouse_handler& mousehandler, bool team_only)
 		if(team_only) {
 			team_name = gui_->labels().team_name();
 		} else {
-			color = team::get_side_rgb(gui_->viewing_side());
+			color = team::get_side_color(gui_->viewing_side());
 		}
 		const terrain_label* res = gui_->labels().set_label(loc, label, gui_->viewing_team(), team_name, color);
 		if(res) {
@@ -955,7 +961,7 @@ void menu_handler::execute_gotos(mouse_handler& mousehandler, int side)
 void menu_handler::toggle_ellipses()
 {
 	preferences::set_ellipses(!preferences::ellipses());
-	gui_->invalidate_all();
+	gui_->invalidate_all(); // TODO can fewer tiles be invalidated?
 }
 
 void menu_handler::toggle_grid()
@@ -1177,9 +1183,15 @@ protected:
 
 		register_command("refresh", &console_handler::do_refresh, _("Refresh gui."));
 		register_command("droid", &console_handler::do_droid, _("Switch a side to/from AI control."),
-				_("do not translate the on/off^[<side> [on/off]]"));
+				// TRANSLATORS: These are the arguments accepted by the "droid" command,
+				// which must be a side-number and then optionally one of "on", "off" or "full".
+				// As with the command's name, "on" and "off" are hardcoded, and shouldn't change in the translation.
+				_("[<side> [on/off]]\n“on” = enable control by the AI, “off” = side is controlled by the player"));
 		register_command("idle", &console_handler::do_idle, _("Switch a side to/from idle state."),
-				_("do not translate the on/off^[<side> [on/off]]"));
+				// TRANSLATORS: These are the arguments accepted by the "idle" command,
+				// which must be a side-number and then optionally "on" or "off".
+				// As with the command's name, "on" and "off" are hardcoded, and shouldn't change in the translation.
+				_("command_idle^[<side> [on/off]]"));
 		register_command("theme", &console_handler::do_theme);
 		register_command("control", &console_handler::do_control,
 				_("Assign control of a side to a different player or observer."), _("<side> <nickname>"), "N");
@@ -1189,7 +1201,7 @@ protected:
 		register_command("foreground", &console_handler::do_foreground, _("Debug foreground terrain."), "", "D");
 		register_command(
 				"layers", &console_handler::do_layers, _("Debug layers from terrain under the mouse."), "", "D");
-		register_command("fps", &console_handler::do_fps, _("Show fps."));
+		register_command("fps", &console_handler::do_fps, _("Show fps (Frames Per Second)."));
 		register_command("benchmark", &console_handler::do_benchmark);
 		register_command("save", &console_handler::do_save, _("Save game."));
 		register_alias("save", "w");
@@ -1672,14 +1684,17 @@ void console_handler::do_choose_level()
 	} else {
 		// find scenarios of multiplayer campaigns
 		// (assumes that scenarios are ordered properly in the game_config)
-		std::string scenario = menu_handler_.pc_.get_mp_settings().mp_scenario;
-		for(const config& mp : menu_handler_.game_config_.child_range("multiplayer")) {
-			if(mp["id"] == scenario) {
-				const std::string& id = mp["id"];
-				options.push_back(id);
-				if(id == menu_handler_.gamedata().next_scenario())
-					next = id;
-				scenario = mp["next_scenario"].str();
+		std::string scenario_id = menu_handler_.pc_.get_mp_settings().mp_scenario;
+		if(const config& this_scenario = menu_handler_.game_config_.find_child(tag, "id", scenario_id)) {
+			std::string addon_id = this_scenario["addon_id"].str();
+			for(const config& sc : menu_handler_.game_config_.child_range(tag)) {
+				if(sc["addon_id"] == addon_id) {
+					std::string id = sc["id"];
+					options.push_back(id);
+					if(id == menu_handler_.gamedata().next_scenario()) {
+						next = id;
+					}
+				}
 			}
 		}
 	}
