@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2010 - 2015 by Fabian Mueller <fabianmueller5@gmx.de>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2010 - 2018 by Fabian Mueller <fabianmueller5@gmx.de>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2
@@ -11,13 +11,10 @@
    See the COPYING file for more details.
 */
 
-#ifndef TELEPORT_H_INCLUDED
-#define TELEPORT_H_INCLUDED
+#pragma once
 
 #include "config.hpp"
-#include "map_location.hpp"
-#include "savegame_config.hpp"
-
+#include "map/location.hpp"
 
 class team;
 class unit;
@@ -26,13 +23,14 @@ class vconfig;
 
 namespace pathfind {
 
-typedef std::pair<std::set<map_location>, std::set<map_location> >
+typedef std::pair<std::set<map_location>, std::set<map_location>>
 		teleport_pair;
 
 /*
  * Represents the tunnel wml tag.
  */
-class teleport_group: public savegame::savegame_config {
+class teleport_group
+{
 public:
 	/*
 	 * Constructs the object from a saved file.
@@ -71,6 +69,16 @@ public:
 	 */
 	bool always_visible() const;
 
+	/*
+	 * Returns whether allied units on the exit hex can be passed.
+	 */
+	bool pass_allied_units() const;
+
+	/*
+	 * Returns whether vision through tunnels is possible.
+	 */
+	bool allow_vision() const;
+
 	/** Inherited from savegame_config. */
 	config to_config() const;
 
@@ -90,13 +98,15 @@ public:
 	 * @param viewing_team
 	 * @param see_all
 	 * @param ignore_units
+	 * @param check_vision
 	 */
 	teleport_map(
 			  const std::vector<teleport_group>& teleport_groups
 			, const unit& u
 			, const team &viewing_team
 			, const bool see_all
-			, const bool ignore_units);
+			, const bool ignore_units
+			, const bool check_vision);
 
 	/*
 	 * Constructs an empty teleport map.
@@ -126,9 +136,9 @@ public:
 	}
 
 private:
-	std::map<map_location, std::set<std::string> > teleport_map_;
-	std::map<std::string, std::set<map_location> > sources_;
-	std::map<std::string, std::set<map_location> > targets_;
+	std::map<map_location, std::set<std::string>> teleport_map_;
+	std::map<std::string, std::set<map_location>> sources_;
+	std::map<std::string, std::set<map_location>> targets_;
 };
 
 /*
@@ -136,12 +146,14 @@ private:
  * @param viewing_team		The team the player belongs to
  * @param see_all			Whether the teleport can be seen below shroud
  * @param ignore_units		Whether to ignore zoc and blocking by units
+ * @param check_vision		Whether to check vision as opposed to movement range
  * @returns a teleport_map
  */
 const teleport_map get_teleport_locations(const unit &u, const team &viewing_team,
-		bool see_all = false, bool ignore_units = false);
+		bool see_all = false, bool ignore_units = false, bool check_vision = false);
 
-class manager: public savegame::savegame_config {
+class manager
+{
 public:
 	manager(const config &cfg);
 
@@ -173,5 +185,3 @@ private:
 };
 
 }
-
-#endif /* TELEPORT_H_INCLUDED */
