@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2010 - 2015 by Jody Northup
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2010 - 2018 by Jody Northup
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,12 +12,10 @@
    See the COPYING file for more details.
 */
 
-#ifndef PERSIST_VAR_H_INCLUDED
-#define PERSIST_VAR_H_INCLUDED
+#pragma once
 
 class vconfig;
 
 void verify_and_set_global_variable(const vconfig &pcfg);
 void verify_and_get_global_variable(const vconfig &pcfg);
 void verify_and_clear_global_variable(const vconfig &pcfg);
-#endif
