@@ -18,7 +18,7 @@
 #include "terrain/translation.hpp"
 #include "game_config.hpp"
 
-#include <SDL.h>
+#include <SDL2/SDL.h>
 #include <unordered_map>
 
 class surface;
@@ -42,7 +42,6 @@ namespace image {
 		void parse_arguments();
 		struct value {
 			value();
-			value(const value &a);
 			value(const char *filename);
 			value(const std::string& filename);
 			value(const std::string& filename, const std::string& modifications);
@@ -174,10 +173,6 @@ namespace image {
 
 	const std::vector<std::string>& get_team_colors();
 
-	///sets the pixel format used by the images. Is called every time the
-	///video mode changes. Invalidates all images.
-	void set_pixel_format(SDL_PixelFormat* format);
-
 	///sets the amount scaled images should be scaled. Invalidates all
 	///scaled images.
 	void set_zoom(unsigned int zoom);
