@@ -39,10 +39,10 @@ static lg::log_domain log_engine("engine");
 #define LOG_NG LOG_STREAM(info, log_engine)
 
 playmp_controller::playmp_controller(const config& level,
-		saved_game& state_of_game, const config& game_config,
+		saved_game& state_of_game,
 		const ter_data_cache & tdata,
 		mp_campaign_info* mp_info)
-	: playsingle_controller(level, state_of_game, game_config, tdata, mp_info && mp_info->skip_replay)
+	: playsingle_controller(level, state_of_game, tdata, mp_info && mp_info->skip_replay)
 	, network_processing_stopped_(false)
 	, blindfold_(*gui_, mp_info && mp_info->skip_replay_blindfolded)
 	, mp_info_(mp_info)
@@ -301,7 +301,7 @@ void playmp_controller::wait_for_upload()
 void playmp_controller::after_human_turn(){
 	if(saved_game_.mp_settings().mp_countdown)
 	{
-		//time_left + turn_bonus + (action_bouns * number of actions done)
+		//time_left + turn_bonus + (action_bonus * number of actions done)
 		const int new_time_in_secs = (current_team().countdown_time() / 1000)
 			+ saved_game_.mp_settings().mp_countdown_turn_bonus
 			+ saved_game_.mp_settings().mp_countdown_action_bonus * current_team().action_bonus_count();
