@@ -92,6 +92,20 @@ static std::string flush(std::ostringstream &s)
 	return r;
 }
 
+static const time_of_day get_visible_time_of_day_at(reports::context & rc, const map_location & hex)
+{
+	const team &viewing_team = rc.teams()[rc.screen().viewing_team()];
+	if (viewing_team.shrouded(hex)) {
+		// Don't show time on shrouded tiles.
+		return rc.tod().get_time_of_day();
+	} else if (viewing_team.fogged(hex)) {
+		// Don't show illuminated time on fogged tiles.
+		return rc.tod().get_time_of_day(hex);
+	} else {
+		return rc.tod().get_illuminated_time_of_day(rc.units(), rc.map(), hex);
+	}
+}
+
 typedef std::map<std::string, reports::generator_function> static_report_generators;
 static static_report_generators static_generators;
 
@@ -216,8 +230,12 @@ static config unit_side(reports::context & rc, const unit* u)
 	std::stringstream text;
 	text << " " << u->side();
 
-	add_image(report, flag_icon + mods, u_team.side_name(), "");
-	add_text(report, text.str(), "", "");
+	std::ostringstream tooltip;
+	if (!u_team.side_name().empty()) {
+		tooltip << _("Side:") << " <b>" <<  u_team.side_name() << "</b>";
+	}
+	add_image(report, flag_icon + mods, tooltip.str(), "");
+	add_text(report, text.str(), tooltip.str(), "");
 	return report;
 }
 REPORT_GENERATOR(unit_side, rc)
@@ -237,12 +255,25 @@ static config unit_level(const unit* u)
 	std::ostringstream str, tooltip;
 	str << u->level();
 	tooltip << _("Level: ") << "<b>" << u->level() << "</b>\n";
-	const std::vector<std::string> &adv_to = u->advances_to_translated();
-	if (adv_to.empty())
+	const std::vector<std::string> &adv_to_types = u->advances_to_translated();
+	const std::vector<config> &adv_to_mods = u->get_modification_advances();
+	const bool has_advancements = !adv_to_types.empty() || !adv_to_mods.empty();
+	if(has_advancements) {
+		tooltip << _("Advancements:") << "\n<b>\t";
+		if(!adv_to_types.empty())
+			tooltip << utils::join(adv_to_types, "\n\t");
+		if(!adv_to_mods.empty()) {
+			if(!adv_to_types.empty())
+				tooltip << "\n\t";
+			std::vector<std::string> descriptions;
+			for(const config& adv : adv_to_mods)
+				descriptions.push_back(adv["description"].str());
+			tooltip << utils::join(descriptions, "\n\t");
+		}
+		tooltip << "</b>";
+	} else {
 		tooltip << _("No advancement");
-	else
-		tooltip << _("Advances to:") << "\n<b>\t"
-			<< utils::join(adv_to, "\n\t") << "</b>";
+	}
 	return text_report(str.str(), tooltip.str());
 }
 REPORT_GENERATOR(unit_level, rc)
@@ -332,14 +363,14 @@ REPORT_GENERATOR(selected_unit_status, rc)
 	return unit_status(rc, u);
 }
 
-static config unit_alignment(reports::context & rc, const unit* u)
+static config unit_alignment(reports::context & rc, const unit* u, const map_location& hex)
 {
 	if (!u) return config();
 	std::ostringstream str, tooltip;
 	const std::string align = unit_type::alignment_description(u->alignment(), u->gender());
 	const std::string align_id = u->alignment().to_string();
-	int cm = combat_modifier(rc.units(), rc.map(), rc.screen().displayed_unit_hex(), u->alignment(),
-			u->is_fearless());
+	const time_of_day effective_tod = get_visible_time_of_day_at(rc, hex);
+	int cm = combat_modifier(effective_tod, u->alignment(), u->is_fearless());
 
 	color_t color = font::weapon_color;
 	if (cm != 0)
@@ -356,24 +387,29 @@ static config unit_alignment(reports::context & rc, const unit* u)
 REPORT_GENERATOR(unit_alignment, rc)
 {
 	const unit *u = get_visible_unit(rc);
-	return unit_alignment(rc, u);
+	const map_location& mouseover_hex = rc.screen().mouseover_hex();
+	const map_location& displayed_unit_hex = rc.screen().displayed_unit_hex();
+	const map_location& hex = mouseover_hex.valid() ? mouseover_hex : displayed_unit_hex;
+	return unit_alignment(rc, u, hex);
 }
 REPORT_GENERATOR(selected_unit_alignment, rc)
 {
 	const unit *u = get_selected_unit(rc);
-	return unit_alignment(rc, u);
+	const map_location& attack_indicator_src = game_display::get_singleton()->get_attack_indicator_src();
+	const map_location& hex_to_show_alignment_at =
+		attack_indicator_src.valid() ? attack_indicator_src : u->get_location();
+	return unit_alignment(rc, u, hex_to_show_alignment_at);
 }
 
-
-static config unit_abilities(const unit* u)
+static config unit_abilities(const unit* u, const map_location& loc)
 {
 	if (!u) return config();
 	config res;
 
 	boost::dynamic_bitset<> active;
-	const std::vector<std::tuple<std::string, t_string,t_string,t_string>> &abilities = u->ability_tooltips(&active);
-	const size_t abilities_size = abilities.size();
-	for ( size_t i = 0; i != abilities_size; ++i )
+	const std::vector<std::tuple<std::string, t_string,t_string,t_string>> &abilities = u->ability_tooltips(active, loc);
+	const std::size_t abilities_size = abilities.size();
+	for ( std::size_t i = 0; i != abilities_size; ++i )
 	{
 		// Aliases for readability:
 		const std::string& id        = std::get<0>(abilities[i]);
@@ -402,12 +438,20 @@ static config unit_abilities(const unit* u)
 REPORT_GENERATOR(unit_abilities, rc)
 {
 	const unit *u = get_visible_unit(rc);
-	return unit_abilities(u);
+	const map_location& mouseover_hex = rc.screen().mouseover_hex();
+
+	return unit_abilities(u, mouseover_hex);
 }
 REPORT_GENERATOR(selected_unit_abilities, rc)
 {
 	const unit *u = get_selected_unit(rc);
-	return unit_abilities(u);
+
+	const map_location& mouseover_hex = rc.screen().mouseover_hex();
+	const unit *visible_unit = get_visible_unit(rc);
+	if(visible_unit && u && visible_unit->id() != u->id() && mouseover_hex.valid())
+		return unit_abilities(u, mouseover_hex);
+	else
+		return unit_abilities(u, u->get_location());
 }
 
 
@@ -571,10 +615,17 @@ static config unit_vision(const unit* u)
 	if (!u) return config();
 
 	// TODO
-	std::ostringstream str;
+	std::ostringstream str, tooltip;
 	if (u->vision() != u->total_movement()) {
-		str << _("vision: ") << u->vision(); }
-	return text_report(str.str());
+		str << _("vision:") << ' ' << u->vision();
+		tooltip << _("vision:") << ' ' << u->vision() << '\n';
+	}
+	if (u->jamming() != 0) {
+		if (static_cast<std::streamoff>(str.tellp()) == 0)
+			str << _("jamming:") << ' ' << u->jamming();
+		tooltip << _("jamming:") << ' ' << u->jamming() << '\n';
+	}
+	return text_report(str.str(), tooltip.str());
 }
 REPORT_GENERATOR(unit_vision, rc)
 {
@@ -596,7 +647,7 @@ static config unit_moves(reports::context & rc, const unit* u)
 	std::set<terrain_movement> terrain_moves;
 
 	if (u->side() == rc.screen().playing_side()) {
-		movement_frac = double(u->movement_left()) / std::max<int>(1, u->total_movement());
+		movement_frac = static_cast<double>(u->movement_left()) / std::max<int>(1, u->total_movement());
 		if (movement_frac > 1.0)
 			movement_frac = 1.0;
 	}
@@ -615,7 +666,7 @@ static config unit_moves(reports::context & rc, const unit* u)
 
 	for (const terrain_movement& tm : terrain_moves) {
 		tooltip << tm.name << ": ";
-		
+
 		std::string color;
 		//movement  -  range: 1 .. 5, movetype::UNREACHABLE=impassable
 		const bool cannot_move = tm.moves > u->total_movement();
@@ -636,7 +687,7 @@ static config unit_moves(reports::context & rc, const unit* u)
 		tooltip << naps << '\n';
 	}
 
-	int grey = 128 + int((255 - 128) * movement_frac);
+	int grey = 128 + static_cast<int>((255 - 128) * movement_frac);
 	color_t c = color_t(grey, grey, grey);
 	str << span_color(c) << u->movement_left() << '/' << u->total_movement() << naps;
 	return text_report(str.str(), tooltip.str());
@@ -660,19 +711,19 @@ static inline const color_t attack_info_percent_color(int resistance)
 	return font::YELLOW_COLOR;
 }
 
-static int attack_info(reports::context & rc, const attack_type &at, config &res, const unit &u, const map_location &displayed_unit_hex)
+static int attack_info(reports::context & rc, const attack_type &at, config &res, const unit &u, const map_location &hex)
 {
 	std::ostringstream str, tooltip;
 	int damage = 0;
 
 	{
-		auto ctx = at.specials_context(unit_const_ptr(&u), displayed_unit_hex, u.side() == rc.screen().playing_side());
+		auto ctx = at.specials_context(unit_const_ptr(&u), hex, u.side() == rc.screen().playing_side());
 		int base_damage = at.damage();
 		int specials_damage = at.modified_damage(false);
 		int damage_multiplier = 100;
-		int tod_bonus = combat_modifier(rc.units(), rc.map(), displayed_unit_hex, u.alignment(), u.is_fearless());
+		int tod_bonus = combat_modifier(get_visible_time_of_day_at(rc, hex), u.alignment(), u.is_fearless());
 		damage_multiplier += tod_bonus;
-		int leader_bonus = under_leadership(rc.units(), displayed_unit_hex).first;
+		int leader_bonus = under_leadership(u, hex);
 		if (leader_bonus != 0)
 			damage_multiplier += leader_bonus;
 
@@ -732,7 +783,7 @@ static int attack_info(reports::context & rc, const attack_type &at, config &res
 				// specials are calculated, but for an unusual case, simple brevity
 				// trumps complexities.
 				if ( max_attacks != base_attacks ) {
-					int attack_diff = int(max_attacks) - int(base_attacks);
+					int attack_diff = static_cast<int>(max_attacks) - static_cast<int>(base_attacks);
 					tooltip << '\t' << _("Specials: ") << utils::signed_value(attack_diff) << '\n';
 				}
 			}
@@ -821,7 +872,7 @@ static int attack_info(reports::context & rc, const attack_type &at, config &res
 	}
 
 	{
-		auto ctx = at.specials_context_for_listing();
+		auto ctx = at.specials_context_for_listing(u.side() == rc.screen().playing_side());
 		boost::dynamic_bitset<> active;
 		const std::vector<std::pair<t_string, t_string>> &specials = at.special_tooltips(&active);
 		const size_t specials_size = specials.size();
@@ -881,7 +932,7 @@ static config unit_weapons(reports::context & rc, const unit *attacker, const ma
 		// skip weapons with attack_weight=0
 		if (attacker->attacks()[i].attack_weight() > 0) {
 			battle_context weapon(rc.units(), attacker_pos, defender->get_location(), i, -1, 0.0, nullptr, attacker);
-			weapons.push_back(weapon);
+			weapons.emplace_back(std::move(weapon));
 		}
 	}
 
@@ -984,12 +1035,14 @@ static config unit_weapons(reports::context & rc, const unit *attacker, const ma
 	return res;
 }
 
-static config unit_weapons(reports::context & rc, const unit *u)
+/*
+ * Display the attacks of the displayed unit against the unit passed as argument.
+ * 'hex' is the location the attacker will be at during combat.
+ */
+static config unit_weapons(reports::context & rc, const unit *u, const map_location &hex)
 {
 	config res = config();
 	if ((u != nullptr) && (!u->attacks().empty())) {
-		map_location displayed_unit_hex = rc.screen().displayed_unit_hex();
-
 		const std::string attack_headline = _n("Attack", "Attacks", u->attacks().size());
 
 		add_text(res,  span_color(font::weapon_details_color)
@@ -997,7 +1050,7 @@ static config unit_weapons(reports::context & rc, const unit *u)
 
 		for (const attack_type &at : u->attacks())
 		{
-			attack_info(rc, at, res, *u, displayed_unit_hex);
+			attack_info(rc, at, res, *u, hex);
 		}
 	}
 	return res;
@@ -1005,9 +1058,12 @@ static config unit_weapons(reports::context & rc, const unit *u)
 REPORT_GENERATOR(unit_weapons, rc)
 {
 	const unit *u = get_visible_unit(rc);
+	const map_location& mouseover_hex = rc.screen().mouseover_hex();
+	const map_location& displayed_unit_hex = rc.screen().displayed_unit_hex();
+	const map_location& hex = mouseover_hex.valid() ? mouseover_hex : displayed_unit_hex;
 	if (!u) return config();
 
-	return unit_weapons(rc, u);
+	return unit_weapons(rc, u, hex);
 }
 REPORT_GENERATOR(highlighted_unit_weapons, rc)
 {
@@ -1015,7 +1071,7 @@ REPORT_GENERATOR(highlighted_unit_weapons, rc)
 	const unit *sec_u = get_visible_unit(rc);
 
 	if (!u) return config();
-	if (!sec_u || u == sec_u) return unit_weapons(rc, sec_u);
+	if (!sec_u || u == sec_u) return unit_weapons(rc, sec_u, rc.screen().mouseover_hex());
 
 	map_location highlighted_hex = rc.screen().displayed_unit_hex();
 	map_location attack_loc;
@@ -1023,7 +1079,7 @@ REPORT_GENERATOR(highlighted_unit_weapons, rc)
 		attack_loc = rc.mhb()->current_unit_attacks_from(highlighted_hex);
 
 	if (!attack_loc.valid())
-		return unit_weapons(rc, sec_u);
+		return unit_weapons(rc, sec_u, rc.screen().mouseover_hex());
 
 	return unit_weapons(rc, u, attack_loc, sec_u, false);
 }
@@ -1033,7 +1089,7 @@ REPORT_GENERATOR(selected_unit_weapons, rc)
 	const unit *sec_u = get_visible_unit(rc);
 
 	if (!u) return config();
-	if (!sec_u || u == sec_u) return unit_weapons(rc, u);
+	if (!sec_u || u == sec_u) return unit_weapons(rc, u, u->get_location());
 
 	map_location highlighted_hex = rc.screen().displayed_unit_hex();
 	map_location attack_loc;
@@ -1041,7 +1097,7 @@ REPORT_GENERATOR(selected_unit_weapons, rc)
 		attack_loc = rc.mhb()->current_unit_attacks_from(highlighted_hex);
 
 	if (!attack_loc.valid())
-		return unit_weapons(rc, u);
+		return unit_weapons(rc, u, u->get_location());
 
 	return unit_weapons(rc, u, attack_loc, sec_u, true);
 }
@@ -1082,9 +1138,11 @@ REPORT_GENERATOR(tod_stats, rc)
 
 	const map_location& hex = mouseover_hex.valid() ? mouseover_hex : selected_hex;
 
-	const std::vector<time_of_day>& schedule = rc.tod().times(hex);
+	const map_location& tod_schedule_hex = display::get_singleton()->shrouded(hex) ? map_location::null_location() : hex;
+	const std::vector<time_of_day>& schedule = rc.tod().times(tod_schedule_hex);
 
-	int current = rc.tod().get_current_time(hex);
+	tooltip << _("Time of day schedule:") << " \n";
+	int current = rc.tod().get_current_time(tod_schedule_hex);
 	int i = 0;
 	for (const time_of_day& tod : schedule) {
 		if (i == current) tooltip << "<big><b>";
@@ -1102,17 +1160,7 @@ REPORT_GENERATOR(tod_stats, rc)
 static config time_of_day_at(reports::context & rc, const map_location& mouseover_hex)
 {
 	std::ostringstream tooltip;
-	time_of_day tod;
-	const team &viewing_team = rc.teams()[rc.screen().viewing_team()];
-	if (viewing_team.shrouded(mouseover_hex)) {
-		// Don't show time on shrouded tiles.
-		tod = rc.tod().get_time_of_day();
-	} else if (viewing_team.fogged(mouseover_hex)) {
-		// Don't show illuminated time on fogged tiles.
-		tod = rc.tod().get_time_of_day(mouseover_hex);
-	} else {
-		tod = rc.tod().get_illuminated_time_of_day(rc.units(), rc.map(), mouseover_hex);
-	}
+	time_of_day tod = get_visible_time_of_day_at(rc, mouseover_hex);
 
 	int b = tod.lawful_bonus;
 
@@ -1125,7 +1173,7 @@ static config time_of_day_at(reports::context & rc, const map_location& mouseove
 		chaotic_color = (b < 0) ? "green" : "red";
 		liminal_color = "red";
 	}
-	tooltip << tod.name << '\n'
+	tooltip << _("Time of day:") << " <b>" << tod.name << "</b>\n"
 		<< _("Lawful units: ") << "<span foreground=\"" << lawful_color  << "\">"
 		<< utils::signed_percent(b)  << "</span>\n"
 		<< _("Neutral units: ") << utils::signed_percent(0)  << '\n'
@@ -1153,18 +1201,8 @@ REPORT_GENERATOR(time_of_day, rc)
 static config unit_box_at(reports::context & rc, const map_location& mouseover_hex)
 {
 	std::ostringstream tooltip;
-	time_of_day local_tod;
 	time_of_day global_tod = rc.tod().get_time_of_day();
-	const team &viewing_team = rc.teams()[rc.screen().viewing_team()];
-	if (viewing_team.shrouded(mouseover_hex)) {
-		// Don't show time on shrouded tiles.
-		local_tod = global_tod;
-	} else if (viewing_team.fogged(mouseover_hex)) {
-		// Don't show illuminated time on fogged tiles.
-		local_tod = rc.tod().get_time_of_day(mouseover_hex);
-	} else {
-		local_tod = rc.tod().get_illuminated_time_of_day(rc.units(), rc.map(),mouseover_hex);
-	}
+	time_of_day local_tod = get_visible_time_of_day_at(rc, mouseover_hex);
 
 	int bonus = local_tod.lawful_bonus;
 
@@ -1301,16 +1339,16 @@ REPORT_GENERATOR(upkeep, rc)
 	std::ostringstream str;
 	int viewing_side = rc.screen().viewing_side();
 	const team &viewing_team = rc.dc().get_team(viewing_side);
-	team_data td = rc.dc().calculate_team_data(viewing_team);
+	team_data td(rc.dc(), viewing_team);
 	str << td.expenses << " (" << td.upkeep << ")";
-	return gray_inactive(rc,str.str(), _("Upkeep") + "\n\n" + _("The expenses incurred at the end of every turn to maintain your army. The first number is the amount of gold that will be deducted. The second is the total cost of upkeep, including that covered by villages — in other words, the amount of gold that would be deducted if you lost all villages."));
+	return gray_inactive(rc,str.str(), _("Upkeep") + "\n\n" + _("The expenses incurred at the end of every turn to maintain your army. The first number is the amount of gold that will be deducted. It is equal to the number of unit levels not supported by villages. The second is the total cost of upkeep, including that covered by villages — in other words, the amount of gold that would be deducted if you lost all villages."));
 }
 
 REPORT_GENERATOR(expenses, rc)
 {
 	int viewing_side = rc.screen().viewing_side();
 	const team &viewing_team = rc.dc().get_team(viewing_side);
-	team_data td = rc.dc().calculate_team_data(viewing_team);
+	team_data td(rc.dc(), viewing_team);
 	return gray_inactive(rc,std::to_string(td.expenses));
 }
 
@@ -1319,7 +1357,7 @@ REPORT_GENERATOR(income, rc)
 	std::ostringstream str;
 	int viewing_side = rc.screen().viewing_side();
 	const team &viewing_team = rc.dc().get_team(viewing_side);
-	team_data td = rc.dc().calculate_team_data(viewing_team);
+	team_data td(rc.dc(), viewing_team);
 	char const *end = naps;
 	if (viewing_side != rc.screen().playing_side()) {
 		if (td.net_income < 0) {
@@ -1340,7 +1378,7 @@ REPORT_GENERATOR(income, rc)
 		end = "";
 	}
 	str << td.net_income << end;
-	return text_report(str.str(), _("Income") + "\n\n" + _("The amount of gold you gain each turn from your controlled villages, or the amount of gold you will lose each turn for unit upkeep."));
+	return text_report(str.str(), _("Net Income") + "\n\n" + _("The net amount of gold you gain or lose each turn, taking into account income from controlled villages and payment of upkeep."));
 }
 
 namespace {
@@ -1560,10 +1598,8 @@ REPORT_GENERATOR(battery, /*rc*/)
 {
 	config report;
 
-	if(desktop::battery_info::does_device_have_battery()) {
-		add_image(report, game_config::images::battery_icon, "");
-		add_text(report, (boost::format("%.0f %%") % desktop::battery_info::get_battery_percentage()).str(), _("Battery"));
-	}
+	add_image(report, game_config::images::battery_icon, "");
+	add_text(report, (boost::format("%.0f %%") % desktop::battery_info::get_battery_percentage()).str(), _("Battery"));
 
 	return report;
 }
