@@ -41,6 +41,7 @@
 
 #include "formula/string_utils.hpp"
 #include "serialization/string_utils.hpp"
+#include "serialization/parser.hpp"
 #include "utils/functional.hpp"
 #include "utils/name_generator.hpp"
 #include "utils/markov_generator.hpp"
@@ -274,8 +275,8 @@ static int intf_name_generator(lua_State *L)
 static int intf_random(lua_State *L)
 {
 	if (lua_isnoneornil(L, 1)) {
-		double r = double(randomness::generator->next_random());
-		double r_max = double(std::numeric_limits<uint32_t>::max());
+		double r = static_cast<double>(randomness::generator->next_random());
+		double r_max = static_cast<double>(std::numeric_limits<uint32_t>::max());
 		lua_push(L, r / (r_max + 1));
 		return 1;
 	}
@@ -314,7 +315,7 @@ static int intf_wml_matches_filter(lua_State* L)
 static int intf_log(lua_State *L) {
 	const std::string& logger = lua_isstring(L, 2) ? luaL_checkstring(L, 1) : "";
 	std::string msg = lua_isstring(L, 2) ? luaL_checkstring(L, 2) : luaL_checkstring(L, 1);
-	if(msg.empty() || msg[msg.size() - 1] != '\n') {
+	if(msg.empty() || msg.back() != '\n') {
 		msg += '\n';
 	}
 
@@ -406,10 +407,11 @@ static int intf_format_list(lua_State* L)
 * - Arg 1: wml table or vconfig userdata
 * - Ret 1: string
 */
-static int intf_debug(lua_State* L) {
+static int intf_wml_tostring(lua_State* L) {
 	const config& arg = luaW_checkconfig(L, 1);
-	const std::string& result = arg.debug();
-	lua_pushstring(L, result.c_str());
+	std::ostringstream stream;
+	write(stream, arg);
+	lua_pushstring(L, stream.str().c_str());
 	return 1;
 }
 
@@ -508,7 +510,7 @@ lua_kernel_base::lua_kernel_base()
 
 	static luaL_Reg const callbacks[] {
 		{ "compare_versions",         &intf_compare_versions         		},
-		{ "debug",                    &intf_debug                           },
+		{ "debug",                    &intf_wml_tostring                           },
 		{ "deprecated_message",       &intf_deprecated_message              },
 		{ "have_file",                &lua_fileops::intf_have_file          },
 		{ "read_file",                &lua_fileops::intf_read_file          },
