@@ -17,7 +17,7 @@
 
 #include "sdl/exception.hpp"
 
-#include <SDL_render.h>
+#include <SDL2/SDL_render.h>
 
 namespace sdl
 {
