@@ -480,7 +480,7 @@ std::string urlencode(const std::string &str)
 
 		res << '%';
 		res.width(2);
-		res << int(c);
+		res << static_cast<int>(c);
 	}
 
 	return res.str();
@@ -524,20 +524,9 @@ std::string half_signed_value(int val)
 
 static void si_string_impl_stream_write(std::stringstream &ss, double input) {
 	std::streamsize oldprec = ss.precision();
-#ifdef _MSC_VER
-	// Visual C++ makes 'precision' set the number of decimal places.
-	// Other platforms make it set the number of significant figures
 	ss.precision(1);
 	ss << std::fixed
 	   << input;
-#else
-	// Workaround to display 1023 KiB instead of 1.02e3 KiB
-	if (input >= 1000)
-		ss.precision(4);
-	else
-		ss.precision(3);
-	ss << input;
-#endif
 	ss.precision(oldprec);
 }
 
