@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2003 - 2015 by David White <dave@whitevine.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2003 - 2018 by David White <dave@whitevine.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,18 +12,17 @@
    See the COPYING file for more details.
 */
 
-#ifndef SERIALIZATION_UCS4_CONVERT_IMPL_HPP_INCLUDED
-#define SERIALIZATION_UCS4_CONVERT_IMPL_HPP_INCLUDED
+#pragma once
 
 #include "unicode_types.hpp"
-#include "util.hpp"
+#include "utils/math.hpp"
 #include <cassert>
 
 namespace ucs4_convert_impl
 {
 	struct utf8_impl
 	{
-		static const char* get_name()  { return "utf8"; };
+		static const char* get_name()  { return "utf8"; }
 		static size_t byte_size_from_ucs4_codepoint(ucs4::char_t ch)
 		{
 			if(ch < (1u << 7))
@@ -48,22 +47,24 @@ namespace ucs4_convert_impl
 				return 1;  // US-ASCII character, 1 byte
 			}
 			/* first bit set: character not in US-ASCII, multiple bytes
-			* number of set bits at the beginning = bytes per character
-			* e.g. 11110xxx indicates a 4-byte character */
+			 * number of set bits at the beginning = bytes per character
+			 * e.g. 11110xxx indicates a 4-byte character */
 			int count = count_leading_ones(ch);
 			if (count == 1 || count > 6) {		// count > 4 after RFC 3629
 				throw utf8::invalid_utf8_exception(); // Stop on invalid characters
 			}
 			return count;
-		};
+		}
 
 		/**
-			@param out an object to write utf8::char_t. required operations are:
-				1) push(utf8::char_t) to write a single character
-				2) can_push(size_t n) to check whether there is still enough space
-					for n characters.
-			@param ch the ucs4 chracter to write to the stream.
-		*/
+		 * Writes a UCS-4 character to a UTF-8 stream.
+		 *
+		 * @param out  An object to write utf8::char_t. Required operations:
+		 *             1) push(utf8::char_t) to write a single character
+		 *             2) can_push(size_t n) to check whether there is still
+		 *                enough space for n characters.
+		 * @param ch   The UCS-4 character to write to the stream.
+		 */
 		template<typename writer>
 		static inline void write(writer out, ucs4::char_t ch)
 		{
@@ -81,12 +82,15 @@ namespace ucs4_convert_impl
 					out.push(c);
 				}
 			}
-		}	
+		}
 		/**
-			reads an ucs4 character from an utf8 stream
-			@param input an iterator pointing to the first character of a utf8 sequence to read
-			@param end an iterator poinint to the end of teh utf8 sequence to read.
-		*/
+		 * Reads a UCS-4 character from a UTF-8 stream
+		 *
+		 * @param input  An iterator pointing to the first character of a UTF-8
+		 *               sequence to read.
+		 * @param end    An iterator pointing to the end of the UTF-8 sequence
+		 *               to read.
+		 */
 		template<typename iitor_t>
 		static inline ucs4::char_t read(iitor_t& input, const iitor_t& end)
 		{
@@ -122,10 +126,10 @@ namespace ucs4_convert_impl
 			return current_char;
 		}
 	};
-	
+
 	struct utf16_impl
 	{
-		static const char* get_name()  { return "utf16"; };
+		static const char* get_name()  { return "utf16"; }
 		template<typename writer>
 		static inline void write(writer out, ucs4::char_t ch)
 		{
@@ -136,7 +140,7 @@ namespace ucs4_convert_impl
 				assert(out.can_push(1));
 				out.push(static_cast<utf16::char_t>(ch));
 			}
-			else 
+			else
 			{
 				assert(out.can_push(2));
 				const ucs4::char_t char20 = ch - bit17;
@@ -187,10 +191,10 @@ namespace ucs4_convert_impl
 			return current_char;
 		}
 	};
-	
+
 	struct utf32_impl
 	{
-		static const char* get_name()  { return "UCS4"; };
+		static const char* get_name()  { return "UCS4"; }
 		template<typename writer>
 		static inline void write(writer out, ucs4::char_t ch)
 		{
@@ -216,18 +220,16 @@ namespace ucs4_convert_impl
 	{
 		typedef utf8_impl type;
 	};
-	
+
 	template<>
 	struct convert_impl<utf16::char_t>
 	{
 		typedef utf16_impl type;
 	};
-	
+
 	template<>
 	struct convert_impl<ucs4::char_t>
 	{
 		typedef utf32_impl type;
 	};
 }
-
-#endif
