@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2003 - 2015 by David White <dave@whitevine.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2003 - 2018 by David White <dave@whitevine.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,35 +12,39 @@
    See the COPYING file for more details.
 */
 
-#ifndef SERIALIZATION_UNICODE_TYPES_HPP_INCLUDED
-#define SERIALIZATION_UNICODE_TYPES_HPP_INCLUDED
+#pragma once
 
 #include <string>
 #include <vector>
 #include <exception>
-#include <boost/cstdint.hpp>
+#include <cstdint>
 
 namespace ucs4 {
-	typedef boost::uint32_t char_t;
+	typedef uint32_t char_t;
 	typedef std::vector<char_t> string;
 }
 
 namespace utf8 {
 	typedef char char_t;
 	typedef std::string string;
-	
-	/** also used for invalid utf16 or ucs4 strings */
+
+	/**
+	 * Thrown by operations encountering invalid UTF-8 data.
+	 *
+	 * Also used for invalid UTF-16 and UCS-4 data.
+	 *
+	 * @todo FIXME: This clearly needs a better name for that reason.
+	 */
 	class invalid_utf8_exception : public std::exception {};
 }
 
 /**
- * For win32 API.
- * On windows, wchar_t is defined as Uint16
- * Wide strings are expected to be UTF-16
+ * For Win32 API.
+ *
+ * On windows, wchar_t is defined as uint16_t.
+ * Wide strings are expected to be UTF-16.
  */
 namespace utf16 {
 	typedef wchar_t char_t;
 	typedef std::vector<char_t> string;
 }
-
-#endif
