@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2008 - 2015 by Pauli Nieminen <paniemin@cc.hut.fi>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2008 - 2018 by Pauli Nieminen <paniemin@cc.hut.fi>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,8 +12,8 @@
    See the COPYING file for more details.
 */
 
-#ifndef SERVER_GAME_HPP_INCLUDED
-#define SERVER_GAME_HPP_INCLUDED
+#pragma once
+
 #include "exceptions.hpp"
 
 #include <set>
@@ -22,8 +22,6 @@
 #include <queue>
 #include <ctime>
 
-#include <boost/shared_ptr.hpp>
-
 class config;
 
 namespace wesnothd {
@@ -32,7 +30,7 @@ namespace wesnothd {
 
 	std::ostream& operator<<(std::ostream& o, const banned& n);
 
-	typedef boost::shared_ptr<banned> banned_ptr;
+	typedef std::shared_ptr<banned> banned_ptr;
 
 	/** We want to move the lowest value to the top. */
 	struct banned_compare {
@@ -115,8 +113,8 @@ namespace wesnothd {
 
 		bool operator>(const banned& b) const;
 
-		struct error : public game::error {
-			error(const std::string& message) : game::error(message) {}
+		struct error : public ::game::error {
+			error(const std::string& message) : ::game::error(message) {}
 		};
 	};
 
@@ -137,6 +135,10 @@ namespace wesnothd {
 		{ return c - '0'; }
 
 		void init_ban_help();
+		void check_ban_times(time_t time_now);
+		inline void expire_bans() {
+			check_ban_times(time(nullptr));
+		}
 	public:
 		ban_manager();
 		~ban_manager();
@@ -153,16 +155,14 @@ namespace wesnothd {
 		bool parse_time(const std::string& duration, time_t* time) const;
 
 		std::string ban(const std::string&, const time_t&, const std::string&, const std::string&, const std::string&, const std::string& = "");
-		void unban(std::ostringstream& os, const std::string& ip);
+		void unban(std::ostringstream& os, const std::string& ip, bool immediate_write=true);
 		void unban_group(std::ostringstream& os, const std::string& group);
 
 
-		void check_ban_times(time_t time_now);
-
 		void list_deleted_bans(std::ostringstream& out, const std::string& mask = "*") const;
-		void list_bans(std::ostringstream& out, const std::string& mask = "*") const;
+		void list_bans(std::ostringstream& out, const std::string& mask = "*");
 
-		std::string is_ip_banned(const std::string& ip) const;
+		std::string is_ip_banned(const std::string& ip);
 
 		const std::string& get_ban_help() const
 		{ return ban_help_; }
@@ -171,5 +171,3 @@ namespace wesnothd {
 
 	};
 }
-
-#endif
