@@ -123,6 +123,7 @@ game::game(player_connections& player_connections,
 	, replay_save_path_(replay_save_path)
 	, rng_()
 	, last_choice_request_id_(-1) /* or maybe 0 ? it shouldn't matter*/
+	, player_versions_(boost::none)
 {
 	assert(owner_);
 	players_.push_back(owner_);
@@ -299,6 +300,8 @@ void game::start_game(const socket_ptr& starter)
 	DBG_GAME << debug_sides_info() << std::endl;
 	DBG_GAME << "****" << std::endl;
 
+	// If the game was already started we're actually advancing.
+	const bool advance = started_;
 	started_ = true;
 	// Prevent inserting empty keys when reading.
 	const simple_wml::node& multiplayer = get_multiplayer(level_.root());
@@ -306,7 +309,7 @@ void game::start_game(const socket_ptr& starter)
 	const bool save = multiplayer["savegame"].to_bool();
 	LOG_GAME
 		<< client_address(starter) << "\t" << player_connections_.find(starter)->name() << "\t"
-		<< "started" << (save ? " reloaded" : "") << " game:\t\"" << name_ << "\" (" << id_
+		<< (advance ? "advanced" : "started") << (save ? " reloaded" : "") << " game:\t\"" << name_ << "\" (" << id_
 		// << ") with: " << list_users(players_, __func__) << ". Settings: map: " << s["id"]
 		<< ") with: " << list_users(players_, __func__)
 		<< ". Settings: map: " << multiplayer["mp_scenario"]
@@ -452,6 +455,7 @@ void game::reset_sides()
 
 void game::update_side_data()
 {
+	player_versions_ = boost::none;
 	// Added by iceiceice: since level_ will now reflect how an observer views the replay start
 	// position and not the current position, the sides_, side_controllers_, players_ info should
 	// not be updated from the level_ after the game has started. Controller changes are now stored
@@ -524,6 +528,7 @@ void game::update_side_data()
 
 void game::transfer_side_control(const socket_ptr& sock, const simple_wml::node& cfg)
 {
+	player_versions_ = boost::none;
 	DBG_GAME << "transfer_side_control...\n";
 
 	if(!is_player(sock) && sock != owner_) {
@@ -583,7 +588,7 @@ void game::transfer_side_control(const socket_ptr& sock, const simple_wml::node&
 
 	if(newplayer == old_player) {
 		std::stringstream msg;
-		msg << "That's already " << newplayer_name << "'s side, silly.";
+		msg << "Side " << side_num << " is already controlled by " << newplayer_name << ".";
 		send_server_message(msg.str(), sock);
 		return;
 	}
@@ -621,6 +626,7 @@ void game::transfer_side_control(const socket_ptr& sock, const simple_wml::node&
 void game::change_controller(
 		const size_t side_index, const socket_ptr& sock, const std::string& player_name, const bool player_left)
 {
+	player_versions_ = boost::none;
 	DBG_GAME << __func__ << "...\n";
 
 	const std::string& side = lexical_cast_default<std::string, size_t>(side_index + 1);
@@ -1274,6 +1280,12 @@ void game::process_whiteboard(simple_wml::document& data, const socket_ptr& user
 	if(!started_ || !is_player(user)) {
 		return;
 	}
+	// Out of sync erros were observed when processing whiteboard data on older clients, see #3717.
+	// Lets hope his will be fixed in 1.14.6 .
+	static version_info min_ver_wb("1.14.6");
+	if(get_player_versions().oldest < min_ver_wb) {
+		return;
+	}
 
 	const simple_wml::node& wb_node = *data.child("whiteboard");
 
@@ -1377,6 +1389,7 @@ void game::update_turn_data()
 //      maybe return a string with an error message.
 bool game::add_player(const socket_ptr& player, bool observer)
 {
+	player_versions_ = boost::none;
 	if(is_member(player)) {
 		ERR_GAME << "ERROR: Player is already in this game. (socket: " << player << ")\n";
 		return false;
@@ -1461,6 +1474,7 @@ bool game::add_player(const socket_ptr& player, bool observer)
 
 bool game::remove_player(const socket_ptr& player, const bool disconnect, const bool destruct)
 {
+	player_versions_ = boost::none;
 	if(!is_member(player)) {
 		ERR_GAME << "ERROR: User is not in this game. (socket: " << player << ")\n";
 		return false;
@@ -1817,6 +1831,16 @@ static bool is_invalid_filename_char(char c)
 	);
 }
 
+std::string game::get_replay_filename()
+{
+	std::stringstream name;
+	name << (*starting_pos(level_.root()))["name"] << " Turn " << current_turn() << " (" << id_ << ").bz2";
+	std::string filename(name.str());
+	std::replace(filename.begin(), filename.end(), ' ', '_');
+	filename.erase(std::remove_if(filename.begin(), filename.end(), is_invalid_filename_char), filename.end());
+	return filename;
+}
+
 void game::save_replay()
 {
 	if(!save_replays_ || !started_ || history_.empty()) {
@@ -1834,9 +1858,6 @@ void game::save_replay()
 
 	history_.clear();
 
-	std::stringstream name;
-	name << (*starting_pos(level_.root()))["name"] << " Turn " << current_turn();
-
 	std::stringstream replay_data;
 	try {
 		// level_.set_attr_dup("label", name.str().c_str());
@@ -1859,16 +1880,10 @@ void game::save_replay()
 			<< (has_old_replay ? "" : "\t[command]\n\t\t[start]\n\t\t[/start]\n\t[/command]\n")
 			<< replay_commands << "[/replay]\n";
 
-		name << " (" << id_ << ").bz2";
-
 		std::string replay_data_str = replay_data.str();
 		simple_wml::document replay(replay_data_str.c_str(), simple_wml::INIT_STATIC);
 
-		std::string filename(name.str());
-
-		std::replace(filename.begin(), filename.end(), ' ', '_');
-		filename.erase(std::remove_if(filename.begin(), filename.end(), is_invalid_filename_char), filename.end());
-
+		std::string filename = get_replay_filename();
 		DBG_GAME << "saving replay: " << filename << std::endl;
 
 		filesystem::scoped_ostream os(filesystem::ostream_file(replay_save_path_ + filename));
@@ -2037,4 +2052,24 @@ void game::send_server_message(const char* message, const socket_ptr& sock, simp
 		send_to_player(sock, doc);
 	}
 }
+const game::version_range& game::get_player_versions() const
+{
+	if(!player_versions_) {
+		for(const socket_ptr& user_ptr : all_game_users()) {
+			const auto pl = player_connections_.find(user_ptr);
+			if(pl != player_connections_.end()) {
+				version_info ver(pl->info().version());
+				if(player_versions_) {
+					player_versions_->oldest = std::min(player_versions_->oldest, ver);
+					player_versions_->newest = std::max(player_versions_->newest, ver);
+				}
+				else {
+					player_versions_ = version_range{ver, ver};
+				}
+			}
+		}
+	}
+	assert(player_versions_);
+	return *player_versions_;
+}
 } // namespace wesnothd
