@@ -213,7 +213,7 @@ const std::string help_msg =
 	" k[ick]ban <mask> <time> <reason>, help, games, metrics,"
 	" netstats [all], [lobby]msg <message>, motd [<message>],"
 	" pm|privatemsg <nickname> <message>, requests, sample, searchlog <mask>,"
-	" signout, stats, status [<mask>], unban <ipmask>\n"
+	" signout, stats, status [<mask>], stopgame <nick> [<reason>], unban <ipmask>\n"
 	"Specific strings (those not in between <> like the command names)"
 	" are case insensitive.";
 
@@ -230,6 +230,7 @@ server::server(int port,
 #ifndef _WIN32
 	, input_path_()
 #endif
+	, uuid_("")
 	, config_file_(config_file)
 	, cfg_(read_config())
 	, accepted_versions_()
@@ -406,6 +407,7 @@ void server::setup_handlers()
 	SETUP_HANDLER("sl", &server::searchlog_handler);
 	SETUP_HANDLER("dul", &server::dul_handler);
 	SETUP_HANDLER("deny_unregistered_login", &server::dul_handler);
+	SETUP_HANDLER("stopgame", &server::stopgame);
 
 #undef SETUP_HANDLER
 }
@@ -473,6 +475,7 @@ void server::load_config()
 		disallowed_names_.push_back("computer");
 		disallowed_names_.push_back("ai");
 		disallowed_names_.push_back("ai?");
+		disallowed_names_.push_back("*moderator*");
 	} else {
 		disallowed_names_ = utils::split(cfg_["disallow_names"]);
 	}
@@ -536,6 +539,7 @@ void server::load_config()
 		// from the config file
 		if(user_handler_) {
 			user_handler_->init_mailer(cfg_.child("mail"));
+			uuid_ = user_handler_->get_uuid();
 		}
 	}
 }
@@ -723,16 +727,19 @@ bool server::is_login_allowed(socket_ptr socket, const simple_wml::node* const l
 	}
 
 	const bool is_moderator = user_handler_ && user_handler_->user_is_moderator(username);
-	const user_handler::BAN_TYPE auth_ban = user_handler_
-		? user_handler_->user_is_banned(username, client_address(socket))
-		: user_handler::BAN_NONE;
+	user_handler::ban_info auth_ban;
 
-	if(auth_ban) {
+	if(user_handler_) {
+		auth_ban = user_handler_->user_is_banned(username, client_address(socket));
+	}
+
+	if(auth_ban.type) {
 		std::string ban_type_desc;
 		std::string ban_reason;
 		const char* msg_numeric;
+		std::string ban_duration = std::to_string(auth_ban.duration);
 
-		switch(auth_ban) {
+		switch(auth_ban.type) {
 		case user_handler::BAN_USER:
 			ban_type_desc = "account";
 			msg_numeric = MP_NAME_AUTH_BAN_USER_ERROR;
@@ -754,10 +761,18 @@ bool server::is_login_allowed(socket_ptr socket, const simple_wml::node* const l
 			ban_reason = ban_type_desc;
 		}
 
+		ban_reason += " (" + ban_duration + ")";
+
 		if(!is_moderator) {
 			LOG_SERVER << client_address(socket) << "\t" << username << "\tis banned by user_handler (" << ban_type_desc
 					   << ")\n";
-			async_send_error(socket, "You are banned from this server: " + ban_reason, msg_numeric);
+			if(auth_ban.duration) {
+				// Temporary ban
+				async_send_error(socket, "You are banned from this server: " + ban_reason, msg_numeric, {{"duration", ban_duration}});
+			} else {
+				// Permanent ban
+				async_send_error(socket, "You are banned from this server: " + ban_reason, msg_numeric);
+			}
 			return false;
 		} else {
 			LOG_SERVER << client_address(socket) << "\t" << username << "\tis banned by user_handler (" << ban_type_desc
@@ -792,6 +807,18 @@ bool server::is_login_allowed(socket_ptr socket, const simple_wml::node* const l
 	LOG_SERVER << client_address(socket) << "\t" << username << "\thas logged on"
 			   << (registered ? " to a registered account" : "") << "\n";
 
+	std::shared_ptr<game> last_sent;
+	for(const auto& record : player_connections_.get<game_t>()) {
+		auto g_ptr { record.get_game() };
+		if(g_ptr != last_sent) {
+			// Note: This string is parsed by the client to identify lobby join messages!
+			if(g_ptr->started()) {
+				g_ptr->send_server_message_to_all(username + " has logged into the lobby");
+			}
+			last_sent = g_ptr;
+		}
+	}
+
 	if(is_moderator) {
 		LOG_SERVER << "Admin automatically recognized: IP: " << client_address(socket) << "\tnick: " << username
 				   << std::endl;
@@ -802,7 +829,7 @@ bool server::is_login_allowed(socket_ptr socket, const simple_wml::node* const l
 			"If you no longer want to be automatically authenticated use '/query signout'.");
 	}
 
-	if(auth_ban) {
+	if(auth_ban.type) {
 		send_server_message(socket, "You are currently banned by the forum administration.");
 	}
 
@@ -851,7 +878,7 @@ bool server::authenticate(
 			// This name is registered and no password provided
 			if(password.empty()) {
 				if(!name_taken) {
-					send_password_request(socket, "The nickname '" + username + "' is registered on this server.",  
+					send_password_request(socket, "The nickname '" + username + "' is registered on this server.",
 						username, version, MP_PASSWORD_REQUEST);
 				} else {
 					send_password_request(socket,
@@ -909,7 +936,7 @@ bool server::authenticate(
 						"You have made too many failed login attempts.", MP_TOO_MANY_ATTEMPTS_ERROR);
 				} else {
 					send_password_request(socket,
-						"The password you provided for the nickname '" + username + "' was incorrect.", username,version, 
+						"The password you provided for the nickname '" + username + "' was incorrect.", username,version,
 						MP_INCORRECT_PASSWORD_ERROR);
 				}
 
@@ -1384,12 +1411,20 @@ void server::create_game(player_record& host_record, simple_wml::node& create_ga
 	}
 
 	create_game.copy_into(g.level().root());
+
+	if(user_handler_) {
+		user_handler_->db_insert_game_info(uuid_, g.id(), game_config::wesnoth_version.str(), g.name());
+	}
 }
 
 void server::cleanup_game(game* game_ptr)
 {
 	metrics_.game_terminated(game_ptr->termination_reason());
 
+	if(user_handler_){
+		user_handler_->db_update_game_end(uuid_, game_ptr->id(), game_ptr->get_replay_filename());
+	}
+
 	simple_wml::node* const gamelist = games_and_users_list_.child("gamelist");
 	assert(gamelist != nullptr);
 
@@ -1701,6 +1736,24 @@ void server::handle_player_in_game(socket_ptr socket, std::shared_ptr<simple_wml
 		g.send_data(data, socket);
 		g.start_game(socket);
 
+		if(user_handler_) {
+			const simple_wml::node& multiplayer = *g.level().root().child("multiplayer");
+			user_handler_->db_update_game_start(uuid_, g.id(), multiplayer["mp_scenario"].to_string(), multiplayer["mp_era"].to_string());
+
+			const simple_wml::node::child_list& sides = g.get_sides_list();
+			for(unsigned side_index = 0; side_index < sides.size(); ++side_index) {
+				const simple_wml::node& side = *sides[side_index];
+				user_handler_->db_insert_game_player_info(uuid_, g.id(), side["player_id"].to_string(), side["side"].to_int(), side["is_host"].to_string(), side["faction"].to_string());
+			}
+
+			const std::string mods = multiplayer["active_mods"].to_string();
+			if(mods != "") {
+				for(const std::string mod : utils::split(mods, ',')){
+					user_handler_->db_insert_modification_info(uuid_, g.id(), mod);
+				}
+			}
+		}
+
 		// update the game having changed in the lobby
 		update_game_in_lobby(g);
 		return;
@@ -1825,6 +1878,9 @@ void server::handle_player_in_game(socket_ptr socket, std::shared_ptr<simple_wml
 			g.set_termination_reason((*info)["condition"].to_string());
 			if((*info)["condition"].to_string() == "out of sync") {
 				g.send_server_message_to_all(player.name() + " reports out of sync errors.");
+				if(user_handler_){
+					user_handler_->db_set_oos_flag(uuid_, g.id());
+				}
 			}
 		}
 
@@ -2890,8 +2946,29 @@ void server::dul_handler(const std::string& /*issuer_name*/,
 				   << std::endl;
 	}
 }
+void server::stopgame(const std::string& /*issuer_name*/,
+		const std::string& /*query*/,
+		std::string& parameters,
+		std::ostringstream* out)
+{
+	const std::string nick = parameters.substr(0, parameters.find(' '));
+	const std::string reason = parameters.length() > nick.length()+1 ? parameters.substr(nick.length()+1) : "";
+	auto player = player_connections_.get<name_t>().find(nick);
 
-void server::delete_game(int gameid)
+	if(player != player_connections_.get<name_t>().end()){
+		std::shared_ptr<game> g = player->get_game();
+		if(g){
+			*out << "Player '" << nick << "' is in game with id '" << g->id() << "' named '" << g->name() << "'.  Ending game for reason: '" << reason << "'...";
+			delete_game(g->id(), reason);
+		} else {
+			*out << "Player '" << nick << "' is not currently in a game.";
+		}
+	} else {
+		*out << "Player '" << nick << "' is not currently logged in.";
+	}
+}
+
+void server::delete_game(int gameid, const std::string& reason)
 {
 	// Set the availability status for all quitting users.
 	auto range_pair = player_connections_.get<game_t>().equal_range(gameid);
@@ -2923,7 +3000,13 @@ void server::delete_game(int gameid)
 	static simple_wml::document leave_game_doc("[leave_game]\n[/leave_game]\n", simple_wml::INIT_COMPRESSED);
 
 	for(const auto& it : range_vctor) {
-		send_to_player(it->socket(), leave_game_doc);
+		if(reason != "") {
+			simple_wml::document leave_game_doc_reason("[leave_game]\n[/leave_game]\n", simple_wml::INIT_STATIC);
+			leave_game_doc_reason.child("leave_game")->set_attr_dup("reason", reason.c_str());
+			send_to_player(it->socket(), leave_game_doc_reason);
+		} else {
+			send_to_player(it->socket(), leave_game_doc);
+		}
 		send_to_player(it->socket(), games_and_users_list_);
 	}
 }
