@@ -124,6 +124,8 @@ private:
 	std::string input_path_;
 #endif
 
+	std::string uuid_;
+
 	const std::string config_file_;
 	config cfg_;
 
@@ -180,7 +182,7 @@ private:
 	/** Process commands from admins and users. */
 	std::string process_command(std::string cmd, std::string issuer_name);
 
-	void delete_game(int);
+	void delete_game(int, const std::string& reason="");
 
 	void update_game_in_lobby(const wesnothd::game& g, const socket_ptr& exclude=socket_ptr());
 
@@ -222,6 +224,7 @@ private:
 	void motd_handler(const std::string &, const std::string &, std::string &, std::ostringstream *);
 	void searchlog_handler(const std::string &, const std::string &, std::string &, std::ostringstream *);
 	void dul_handler(const std::string &, const std::string &, std::string &, std::ostringstream *);
+	void stopgame(const std::string &, const std::string &, std::string &, std::ostringstream *);
 
 #ifndef _WIN32
 	void handle_sighup(const boost::system::error_code& error, int signal_number);
