@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2008 - 2015 by Thomas Baumhauer <thomas.baumhauer@NOSPAMgmail.com>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2008 - 2018 by Thomas Baumhauer <thomas.baumhauer@NOSPAMgmail.com>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,11 +12,20 @@
    See the COPYING file for more details.
 */
 
-#include "user_handler.hpp"
-#include "../config.hpp"
-#include "serialization/string_utils.hpp"
+#include "server/user_handler.hpp"
+#include "config.hpp"
+#include "random.hpp"
+#include "serialization/base64.hpp"
 
+#ifndef __APPLE__
+#include <openssl/rand.h>
+#else
+#include <cstdlib>
+#endif
+
+#include <array>
 #include <ctime>
+#include <sstream>
 
 bool user_handler::send_mail(const std::string& to_user,
 		const std::string& /*subject*/, const std::string& /*message*/) {
@@ -27,7 +36,7 @@ bool user_handler::send_mail(const std::string& to_user,
 	}
 
 	// If this user did not provide an email
-	if(get_mail(to_user) == "") {
+	if(get_mail(to_user).empty()) {
 		throw error("Could not send email. The email address of the user '" + to_user + "' is empty.");
 	}
 
@@ -37,14 +46,39 @@ bool user_handler::send_mail(const std::string& to_user,
 void user_handler::init_mailer(const config &) {
 }
 
-std::string user_handler::create_salt(int length) {
-	srand(static_cast<unsigned>(time(NULL)));
+std::string user_handler::create_unsecure_nonce(int length) {
+	srand(static_cast<unsigned>(time(nullptr)));
 
 	std::stringstream ss;
 
 	for(int i = 0; i < length; i++) {
-		ss << (rand() % 10);
+		ss << randomness::rng::default_instance().get_random_int(0, 9);
 	}
 
 	return  ss.str();
 }
+
+#ifndef __APPLE__
+namespace {
+	class RAND_bytes_exception: public std::exception
+	{
+	};
+}
+#endif
+
+std::string user_handler::create_secure_nonce()
+{
+	// Must be full base64 encodings (3 bytes = 4 chars) else we skew the PRNG results
+	std::array<unsigned char, (3 * 32) / 4> buf;
+
+#ifndef __APPLE__
+	if(!RAND_bytes(buf.data(), buf.size())) {
+		throw RAND_bytes_exception();
+	}
+#else
+	arc4random_buf(buf.data(), buf.size());
+#endif
+
+	return base64::encode({buf.data(), buf.size()});
+}
+
