@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2003 - 2015 by David White <dave@whitevine.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2003 - 2018 by David White <dave@whitevine.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,17 +12,21 @@
    See the COPYING file for more details.
 */
 
-#include "global.hpp"
-
 #define GETTEXT_DOMAIN "wesnoth-lib"
 
-#include "display.hpp"
-#include "gettext.hpp"
-#include "gui/auxiliary/event/handler.hpp"
-#include "help.hpp"
-#include "log.hpp"
-#include "marked-up_text.hpp"
+#include "show_dialog.hpp"
 
+#include "floating_label.hpp"
+#include "font/sdl_ttf.hpp"
+#include "picture.hpp"
+#include "gettext.hpp"
+#include "gui/core/event/handler.hpp"
+#include "help/help.hpp"
+#include "hotkey/command_executor.hpp"
+#include "log.hpp"
+#include "font/marked-up_text.hpp"
+#include "font/standard_colors.hpp"
+#include "sdl/rect.hpp"
 
 static lg::log_domain log_display("display");
 #define ERR_DP LOG_STREAM(err, log_display)
@@ -74,7 +78,7 @@ dialog_manager::~dialog_manager()
 	SDL_PushEvent(&pb_event);
 }
 
-dialog_frame::dialog_frame(CVideo &video, const std::string& title,
+dialog_frame::dialog_frame(CVideo& video, const std::string& title,
 		const style& style, bool auto_restore,
 		std::vector<button*>* buttons, button* help_button) :
 	title_(title),
@@ -82,7 +86,7 @@ dialog_frame::dialog_frame(CVideo &video, const std::string& title,
 	dialog_style_(style),
 	buttons_(buttons),
 	help_button_(help_button),
-	restorer_(NULL),
+	restorer_(nullptr),
 	auto_restore_(auto_restore),
 	dim_(),
 	top_(image::get_image("dialogs/" + dialog_style_.panel + "-border-top.png")),
@@ -94,7 +98,8 @@ dialog_frame::dialog_frame(CVideo &video, const std::string& title,
 	top_right_(image::get_image("dialogs/" + dialog_style_.panel + "-border-topright.png")),
 	bot_right_(image::get_image("dialogs/" + dialog_style_.panel + "-border-botright.png")),
 	bg_(image::get_image("dialogs/" + dialog_style_.panel + "-background.png")),
-	have_border_(top_ != NULL && bot_ != NULL && left_ != NULL && right_ != NULL)
+	have_border_(top_ != nullptr && bot_ != nullptr && left_ != nullptr && right_ != nullptr),
+	dirty_(true)
 {
 }
 
@@ -104,10 +109,10 @@ dialog_frame::~dialog_frame()
 }
 
 dialog_frame::dimension_measurements::dimension_measurements() :
-	interior(empty_rect), exterior(empty_rect), title(empty_rect), button_row(empty_rect)
+	interior(sdl::empty_rect), exterior(sdl::empty_rect), title(sdl::empty_rect), button_row(sdl::empty_rect)
 {}
 
-dialog_frame::dimension_measurements dialog_frame::layout(SDL_Rect const& rect) {
+dialog_frame::dimension_measurements dialog_frame::layout(const SDL_Rect& rect) {
 	return layout(rect.x, rect.y, rect.w, rect.h);
 }
 
@@ -117,14 +122,48 @@ int dialog_frame::top_padding() const {
 		padding += top_->h;
 	}
 	if(!title_.empty()) {
-		padding += font::get_max_height(font::SIZE_LARGE) + 2*dialog_frame::title_border_h;
+		padding += font::get_max_height(font::SIZE_TITLE) + 2*dialog_frame::title_border_h;
 	}
 	return padding;
 }
 
+void dialog_frame::set_dirty(bool dirty) {
+	dirty_ = dirty;
+}
+
+void dialog_frame::handle_window_event(const SDL_Event& event) {
+
+	if (event.type == SDL_WINDOWEVENT) {
+		switch (event.window.event) {
+		case SDL_WINDOWEVENT_RESIZED:
+		case SDL_WINDOWEVENT_RESTORED:
+		case SDL_WINDOWEVENT_SHOWN:
+		case SDL_WINDOWEVENT_EXPOSED:
+			set_dirty();
+		}
+	}
+}
+
+void dialog_frame::handle_event(const SDL_Event& event) {
+
+	if (event.type == DRAW_ALL_EVENT) {
+		set_dirty();
+
+		if (buttons_) {
+			for(std::vector<button *>::iterator it = buttons_->begin(); it != buttons_->end(); ++it) {
+				(*it)->set_dirty(true);
+			}
+		}
+	}
+
+	if (event.type == DRAW_EVENT || event.type == DRAW_ALL_EVENT) {
+		draw();
+	}
+}
+
 int dialog_frame::bottom_padding() const {
 	int padding = 0;
-	if(buttons_ != NULL) {
+	if(buttons_ != nullptr) {
 		for(std::vector<button*>::const_iterator b = buttons_->begin(); b != buttons_->end(); ++b) {
 			padding = std::max<int>((**b).height() + ButtonVPadding, padding);
 		}
@@ -138,10 +177,10 @@ int dialog_frame::bottom_padding() const {
 dialog_frame::dimension_measurements dialog_frame::layout(int x, int y, int w, int h) {
 	dim_ = dimension_measurements();
 	if(!title_.empty()) {
-		dim_.title = draw_title(NULL);
+		dim_.title = draw_title(nullptr);
 		dim_.title.w += title_border_w;
 	}
-	if(buttons_ != NULL) {
+	if(buttons_ != nullptr) {
 		for(std::vector<button*>::const_iterator b = buttons_->begin(); b != buttons_->end(); ++b) {
 			dim_.button_row.w += (**b).width() + ButtonHPadding;
 			dim_.button_row.h = std::max<int>((**b).height() + ButtonVPadding,dim_.button_row.h);
@@ -155,17 +194,17 @@ dialog_frame::dimension_measurements dialog_frame::layout(int x, int y, int w, i
 
 	size_t buttons_width = dim_.button_row.w;
 
-	if(help_button_ != NULL) {
+	if(help_button_ != nullptr) {
 		buttons_width += help_button_->width() + ButtonHPadding*2;
 		dim_.button_row.y = y + h;
 	}
 
 	y -= dim_.title.h;
-	w = std::max<int>(w,std::max<int>(int(dim_.title.w),int(buttons_width)));
+	w = std::max(w, std::max(dim_.title.w, static_cast<int>(buttons_width)));
 	h += dim_.title.h + dim_.button_row.h;
 	dim_.button_row.x += x + w;
 
-	SDL_Rect bounds = screen_area();
+	SDL_Rect bounds = video_.screen_area();
 	if(have_border_) {
 		bounds.x += left_->w;
 		bounds.y += top_->h;
@@ -215,31 +254,29 @@ void dialog_frame::draw_border()
 
 	surface top_image(scale_surface(top_, dim_.interior.w, top_->h));
 
-	if(top_image != NULL) {
+	if(top_image != nullptr) {
 		video_.blit_surface(dim_.interior.x, dim_.exterior.y, top_image);
 	}
 
 	surface bot_image(scale_surface(bot_, dim_.interior.w, bot_->h));
 
-	if(bot_image != NULL) {
+	if(bot_image != nullptr) {
 		video_.blit_surface(dim_.interior.x, dim_.interior.y + dim_.interior.h, bot_image);
 	}
 
 	surface left_image(scale_surface(left_, left_->w, dim_.interior.h));
 
-	if(left_image != NULL) {
+	if(left_image != nullptr) {
 		video_.blit_surface(dim_.exterior.x, dim_.interior.y, left_image);
 	}
 
 	surface right_image(scale_surface(right_, right_->w, dim_.interior.h));
 
-	if(right_image != NULL) {
+	if(right_image != nullptr) {
 		video_.blit_surface(dim_.interior.x + dim_.interior.w, dim_.interior.y, right_image);
 	}
 
-	update_rect(dim_.exterior);
-
-	if(top_left_ == NULL || bot_left_ == NULL || top_right_ == NULL || bot_right_ == NULL) {
+	if(top_left_ == nullptr || bot_left_ == nullptr || top_right_ == nullptr || bot_right_ == nullptr) {
 		return;
 	}
 
@@ -252,7 +289,7 @@ void dialog_frame::draw_border()
 void dialog_frame::clear_background()
 {
 	delete restorer_;
-	restorer_ = NULL;
+	restorer_ = nullptr;
 }
 
 void dialog_frame::draw_background()
@@ -264,17 +301,17 @@ void dialog_frame::draw_background()
 
 	if (dialog_style_.blur_radius) {
 		surface surf = ::get_surface_portion(video_.getSurface(), dim_.exterior);
-		surf = blur_surface(surf, dialog_style_.blur_radius, false);
-		sdl_blit(surf, NULL, video_.getSurface(), &dim_.exterior);
+		surf = blur_surface(surf, dialog_style_.blur_radius);
+		sdl_blit(surf, nullptr, video_.getSurface(), &dim_.exterior);
 	}
 
-	if(bg_ == NULL) {
-		ERR_DP << "could not find dialog background '" << dialog_style_.panel << "'\n";
+	if(bg_ == nullptr) {
+		ERR_DP << "could not find dialog background '" << dialog_style_.panel << "'" << std::endl;
 		return;
 	}
 	for(int i = 0; i < dim_.interior.w; i += bg_->w) {
 		for(int j = 0; j < dim_.interior.h; j += bg_->h) {
-			SDL_Rect src = {0,0,0,0};
+			SDL_Rect src {0,0,0,0};
 			src.w = std::min(dim_.interior.w - i, bg_->w);
 			src.h = std::min(dim_.interior.h - j, bg_->h);
 			SDL_Rect dst = src;
@@ -287,13 +324,16 @@ void dialog_frame::draw_background()
 
 SDL_Rect dialog_frame::draw_title(CVideo* video)
 {
-	SDL_Rect rect = screen_area();
-	return font::draw_text(video, rect, font::SIZE_LARGE, font::TITLE_COLOR,
-	                       title_, dim_.title.x, dim_.title.y, false, TTF_STYLE_BOLD);
+	SDL_Rect rect = CVideo::get_singleton().screen_area();
+	return font::draw_text(video, rect, font::SIZE_TITLE, font::TITLE_COLOR,
+	                       title_, dim_.title.x, dim_.title.y, false, TTF_STYLE_NORMAL);
 }
 
 void dialog_frame::draw()
 {
+	if (!dirty_)
+		return;
+
 	//draw background
 	draw_background();
 
@@ -307,7 +347,7 @@ void dialog_frame::draw()
 
 	//draw buttons
 	SDL_Rect buttons_area = dim_.button_row;
-	if(buttons_ != NULL) {
+	if(buttons_ != nullptr) {
 #ifdef OK_BUTTON_ON_RIGHT
 		std::reverse(buttons_->begin(),buttons_->end());
 #endif
@@ -317,107 +357,11 @@ void dialog_frame::draw()
 		}
 	}
 
-	if(help_button_ != NULL) {
+	if(help_button_ != nullptr) {
 		help_button_->set_location(dim_.interior.x+ButtonHPadding, buttons_area.y);
 	}
-}
 
-} //end namespace gui
-
-namespace {
-
-struct help_handler : public hotkey::command_executor
-{
-	help_handler(display& disp, const std::string& topic) : disp_(disp), topic_(topic)
-	{}
-
-private:
-	void show_help()
-	{
-		if(topic_.empty() == false) {
-			help::show_help(disp_,topic_);
-		}
-	}
-
-	bool can_execute_command(const hotkey::hotkey_command& cmd, int /*index*/) const
-	{
-		hotkey::HOTKEY_COMMAND command = cmd.id;
-		return (topic_.empty() == false && command == hotkey::HOTKEY_HELP) || command == hotkey::HOTKEY_SCREENSHOT;
-	}
-
-	display& disp_;
-	std::string topic_;
-};
-
-}
-
-namespace gui
-{
-
-int show_dialog(display& screen, surface image,
-				const std::string& caption, const std::string& message,
-				DIALOG_TYPE type,
-				const std::vector<std::string>* menu_items,
-				const std::vector<preview_pane*>* preview_panes,
-				const std::string& text_widget_label,
-				std::string* text_widget_text,
-				const int text_widget_max_chars,
-				std::vector<check_item>* options,
-				int xloc,
-				int yloc,
-				const dialog_frame::style* dialog_style,
-				std::vector<dialog_button_info>* action_buttons,
-				const menu::sorter* sorter,
-				menu::style* menu_style)
-{
-	std::string title;
-	if (image.null()) title = caption;
-	const dialog::style& style = (dialog_style)? *dialog_style : dialog::default_style;
-	CVideo &disp = screen.video();
-
-	gui::dialog d(screen, title, message, type, style);
-
-	//add the components
-	if(!image.null()) {
-		d.set_image(image, caption);
-	}
-	if(menu_items) {
-		d.set_menu( new gui::menu(disp,*menu_items,type == MESSAGE,-1,dialog::max_menu_width,sorter,menu_style,false));
-	}
-	if(preview_panes) {
-		for(unsigned int i=0; i < preview_panes->size(); ++i) {
-			d.add_pane((*preview_panes)[i]);
-		}
-	}
-	if(text_widget_text) {
-		d.set_textbox(text_widget_label,*text_widget_text, text_widget_max_chars);
-	}
-	if(options) {
-		for(unsigned int i=0; i < options->size(); ++i) {
-			check_item& item = (*options)[i];
-			d.add_option(item.label, item.checked);
-		}
-	}
-	if(action_buttons) {
-		for(unsigned int i=0; i < action_buttons->size(); ++i) {
-			d.add_button((*action_buttons)[i]);
-		}
-	}
-	//enter the dialog loop
-	d.show(xloc, yloc);
-
-	//send back results
-	if(options) {
-		for(unsigned int i=0; i < options->size(); ++i)
-		{
-			(*options)[i].checked = d.option_checked(i);
-		}
-	}
-	if(text_widget_text) {
-		*text_widget_text = d.textbox_text();
-	}
-	return d.result();
+	dirty_ = false;
 }
 
 }
-
