@@ -741,7 +741,7 @@ void validate_side(int side)
 		return;
 	}
 
-	if(side < 1 || side > int(resources::gameboard->teams().size())) {
+	if(side < 1 || side > static_cast<int>(resources::gameboard->teams().size())) {
 		throw game::game_error("invalid side(" + std::to_string(side) + ") found in unit definition");
 	}
 }
@@ -986,7 +986,7 @@ std::string team::get_side_color_id_from_config(const config& cfg)
 
 std::string team::get_side_highlight_pango(int side)
 {
-	return get_side_color_range(side + 1).mid().to_hex_string();
+	return get_side_color_range(side).mid().to_hex_string();
 }
 
 void team::log_recruitable() const
