@@ -29,6 +29,7 @@ BOOST_AUTO_TEST_CASE (test_empty_options)
 	BOOST_CHECK(!co.campaign);
 	BOOST_CHECK(!co.campaign_difficulty);
 	BOOST_CHECK(!co.campaign_scenario);
+	BOOST_CHECK(!co.campaign_skip_story);
 	BOOST_CHECK(!co.clock);
 	BOOST_CHECK(!co.data_dir);
 	BOOST_CHECK(!co.data_path);
@@ -64,7 +65,6 @@ BOOST_AUTO_TEST_CASE (test_empty_options)
 	BOOST_CHECK(!co.nomusic);
 	BOOST_CHECK(!co.nosound);
 	BOOST_CHECK(!co.new_widgets);
-	BOOST_CHECK(!co.path);
 	BOOST_CHECK(!co.preprocess);
 	BOOST_CHECK(!co.preprocess_defines);
 	BOOST_CHECK(!co.preprocess_input_macros);
@@ -104,6 +104,7 @@ BOOST_AUTO_TEST_CASE (test_default_options)
 	BOOST_CHECK(co.campaign && co.campaign->empty());
 	BOOST_CHECK(!co.campaign_difficulty);
 	BOOST_CHECK(!co.campaign_scenario);
+	BOOST_CHECK(!co.campaign_skip_story);
 	BOOST_CHECK(!co.clock);
 	BOOST_CHECK(!co.data_dir);
 	BOOST_CHECK(!co.data_path);
@@ -140,7 +141,6 @@ BOOST_AUTO_TEST_CASE (test_default_options)
 	BOOST_CHECK(!co.nomusic);
 	BOOST_CHECK(!co.nosound);
 	BOOST_CHECK(!co.new_widgets);
-	BOOST_CHECK(!co.path);
 	BOOST_CHECK(!co.preprocess);
 	BOOST_CHECK(!co.preprocess_defines);
 	BOOST_CHECK(!co.preprocess_input_macros);
@@ -175,6 +175,7 @@ BOOST_AUTO_TEST_CASE (test_full_options)
 		"--campaign=campfoo",
 		"--campaign-difficulty=16",
 		"--campaign-scenario=scenfoo",
+		"--campaign-skip-story",
 		"--clock",
 		"--controller=5:confoo",
 		"--controller=6:conbar",
@@ -211,7 +212,6 @@ BOOST_AUTO_TEST_CASE (test_full_options)
 		"--nogui",
 		"--parm=7:parmfoo:valfoo",
 		"--parm=8:parmbar:valbar",
-		"--path",
 		"--preprocess", "preppathfoo", "preptargfoo",
 		"--preprocess-defines=DEFFOO,DEFBAR",
 		"--preprocess-input-macros=inmfoo",
@@ -239,6 +239,7 @@ BOOST_AUTO_TEST_CASE (test_full_options)
 	BOOST_CHECK(co.campaign && *co.campaign == "campfoo");
 	BOOST_CHECK(co.campaign_difficulty && *co.campaign_difficulty == 16);
 	BOOST_CHECK(co.campaign_scenario && *co.campaign_scenario == "scenfoo");
+	BOOST_CHECK(co.campaign_skip_story);
 	BOOST_CHECK(co.clock);
 	BOOST_CHECK(co.data_dir && *co.data_dir == "datadirfoo");
 	BOOST_CHECK(co.data_path);
@@ -296,7 +297,6 @@ BOOST_AUTO_TEST_CASE (test_full_options)
 	BOOST_CHECK(co.nomusic);
 	BOOST_CHECK(co.nosound);
 	BOOST_CHECK(co.new_widgets);
-	BOOST_CHECK(co.path);
 	BOOST_CHECK(co.preprocess && co.preprocess_path && co.preprocess_target);
 	BOOST_CHECK(*co.preprocess_path == "preppathfoo" && *co.preprocess_target == "preptargfoo");
 	BOOST_CHECK(co.preprocess_defines && co.preprocess_defines->size() == 2);
@@ -331,6 +331,7 @@ BOOST_AUTO_TEST_CASE (test_positional_options)
 	BOOST_CHECK(!co.campaign);
 	BOOST_CHECK(!co.campaign_difficulty);
 	BOOST_CHECK(!co.campaign_scenario);
+	BOOST_CHECK(!co.campaign_skip_story);
 	BOOST_CHECK(!co.clock);
 	BOOST_CHECK(co.data_dir && *co.data_dir == "datadirfoo");
 	BOOST_CHECK(!co.data_path);
@@ -367,7 +368,6 @@ BOOST_AUTO_TEST_CASE (test_positional_options)
 	BOOST_CHECK(!co.nomusic);
 	BOOST_CHECK(!co.nosound);
 	BOOST_CHECK(!co.new_widgets);
-	BOOST_CHECK(!co.path);
 	BOOST_CHECK(!co.preprocess);
 	BOOST_CHECK(!co.preprocess_defines);
 	BOOST_CHECK(!co.preprocess_input_macros);
