@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2012 - 2015 by Mark de Wever <koraq@xs4all.nl>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2012 - 2018 by Mark de Wever <koraq@xs4all.nl>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,22 +12,21 @@
    See the COPYING file for more details.
 */
 
-#ifndef TESTS_TEST_SDL_UTILS_HPP_INCLUDED
-#define TESTS_TEST_SDL_UTILS_HPP_INCLUDED
+#pragma once
 
-#include "sdl_utils.hpp"
+#include "sdl/surface.hpp"
 
-#include <boost/function.hpp>
+#include "utils/functional.hpp"
 
-typedef boost::function<
-		void(const surface&, const double, const Uint32)>
+typedef std::function<
+		void(const surface&, const double, const uint32_t)>
 		tblend_functor;
 
 
 inline void
 blend_image(const surface& src, tblend_functor functor)
 {
-	for(Uint32 color = 0x00FF0000; color != 0x00000000; color >>= 8) {
+	for(uint32_t color = 0x00FF0000; color != 0x00000000; color >>= 8) {
 		for(int i = 0xf; i < 0x100; i += 0x10) {
 			const surface dst = blend_surface(src, i / 255., color);
 			if(functor) {
@@ -38,7 +37,7 @@ blend_image(const surface& src, tblend_functor functor)
 }
 
 inline std::string
-blend_get_filename(std::string root, const Uint8 amount, const Uint32 color)
+blend_get_filename(std::string root, const uint8_t amount, const uint32_t color)
 {
 	// The name of the file is
 	// A the amount of blended [0..256) as hex.
@@ -48,5 +47,3 @@ blend_get_filename(std::string root, const Uint8 amount, const Uint32 color)
 
 	return root + filename;
 }
-
-#endif
