@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2008 - 2015 by Pauli Nieminen <paniemin@cc.hut.fi>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2008 - 2018 by Pauli Nieminen <paniemin@cc.hut.fi>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
    See the COPYING file for more details.
 */
 
-#ifndef TESTS_UTILS_AUTO_PARAMETERIZED_HPP_INCLUDED
-#define TESTS_UTILS_AUTO_PARAMETERIZED_HPP_INCLUDED
+#pragma once
 
 #include <boost/version.hpp>
 
@@ -79,4 +78,3 @@ void test_name::test_method(const type_name& param_name)                \
 #endif
 
 }
-#endif
