@@ -24,7 +24,7 @@
 #include "generic_event.hpp"
 
 #include <memory>
-#include <SDL_rect.h>
+#include <SDL2/SDL_rect.h>
 
 struct _rect { size_t x1,y1,x2,y2; };
 
@@ -142,15 +142,6 @@ public:
 		color_t font_rgb_;
 	};
 
-	class countdown : public status_item
-	{
-	public:
-		explicit countdown(const config& cfg) : status_item(cfg)
-		{}
-
-		SDL_Rect& location(const SDL_Rect& screen) const override;
-	};
-
 	class panel : public object
 	{
 	public:
@@ -317,4 +308,6 @@ private:
 	object main_map_, mini_map_, unit_image_, palette_;
 
 	border_t border_;
+
+	SDL_Rect screen_dimensions_;
 };
