@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2003 - 2015 by David White <dave@whitevine.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2003 - 2018 by David White <dave@whitevine.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,26 +12,29 @@
    See the COPYING file for more details.
 */
 
-#ifndef TOOLTIPS_HPP_INCLUDED
-#define TOOLTIPS_HPP_INCLUDED
-
-#include "SDL.h"
+#pragma once
 
 #include <string>
+#include "sdl/surface.hpp"
 
-class CVideo;
+struct SDL_Rect;
 
 namespace tooltips {
 
 struct manager
 {
-	manager(CVideo& video);
+	manager();
 	~manager();
 };
 
 void clear_tooltips();
 void clear_tooltips(const SDL_Rect& rect);
-void add_tooltip(const SDL_Rect& rect, const std::string& message, const std::string& action ="", bool use_markup = true);
+int  add_tooltip(const SDL_Rect& rect, const std::string& message, const std::string& action ="", bool use_markup = true, const surface& foreground = surface(nullptr));
+bool update_tooltip(int id, const SDL_Rect& rect, const std::string& message,
+		const std::string& action, bool use_markup, const surface& foreground);
+bool update_tooltip(int id, const SDL_Rect& rect, const std::string& message,
+		const std::string& action, bool use_markup);
+void remove_tooltip(int id);
 void process(int mousex, int mousey);
 
 // Check if we clicked on a tooltip having an action.
@@ -40,5 +43,3 @@ void process(int mousex, int mousey);
 bool click(int mousex, int mousey);
 
 }
-
-#endif
