@@ -19,9 +19,11 @@
 
 #include "display.hpp"
 #include "display_context.hpp"
+#include "font/text_formatting.hpp"
 #include "game_board.hpp"
 #include "lexical_cast.hpp"
 #include "log.hpp"
+#include "map/map.hpp"
 #include "resources.hpp"
 #include "team.hpp"
 #include "terrain/filter.hpp"
@@ -258,20 +260,17 @@ namespace {
 		                     gender == unit_race::MALE ? male_key : female_key,
 		                     default_key);
 	}
-}
 
-std::vector<std::tuple<std::string, t_string, t_string, t_string>> unit::ability_tooltips(boost::dynamic_bitset<>* active_list) const
-{
-	std::vector<std::tuple<std::string, t_string,t_string,t_string>> res;
-	if ( active_list )
-		active_list->clear();
-
-	for (const config::any_child &ab : this->abilities_.all_children_range())
+	/**
+	 * Adds a quadruple consisting of (in order) id, base name,
+	 * male or female name as appropriate for the unit, and description.
+	 *
+	 * @returns Whether name was resolved and quadruple added.
+	 */
+	bool add_ability_tooltip(const config::any_child &ab, unit_race::GENDER gender, std::vector<std::tuple<std::string, t_string,t_string,t_string>>& res, bool active)
 	{
-		if ( !active_list || ability_active(ab.key, ab.cfg, loc_) )
-		{
-			const t_string& name =
-				gender_value(ab.cfg, gender_, "name", "female_name", "name").t_str();
+		if (active) {
+			const t_string& name = gender_value(ab.cfg, gender, "name", "female_name", "name").t_str();
 
 			if (!name.empty()) {
 				res.emplace_back(
@@ -279,18 +278,17 @@ std::vector<std::tuple<std::string, t_string, t_string, t_string>> unit::ability
 						ab.cfg["name"].t_str(),
 						name,
 						ab.cfg["description"].t_str() );
-				if ( active_list )
-					active_list->push_back(true);
+				return true;
 			}
 		}
 		else
 		{
 			// See if an inactive name was specified.
 			const config::attribute_value& inactive_value =
-				gender_value(ab.cfg, gender_, "name_inactive",
-				             "female_name_inactive", "name_inactive");
+				gender_value(ab.cfg, gender, "name_inactive",
+						"female_name_inactive", "name_inactive");
 			const t_string& name = !inactive_value.blank() ? inactive_value.t_str() :
-				gender_value(ab.cfg, gender_, "name", "female_name", "name").t_str();
+				gender_value(ab.cfg, gender, "name", "female_name", "name").t_str();
 
 			if (!name.empty()) {
 				res.emplace_back(
@@ -298,9 +296,38 @@ std::vector<std::tuple<std::string, t_string, t_string, t_string>> unit::ability
 						default_value(ab.cfg, "name_inactive", "name").t_str(),
 						name,
 						default_value(ab.cfg, "description_inactive", "description").t_str() );
-				active_list->push_back(false);
+				return true;
 			}
 		}
+
+		return false;
+	}
+}
+
+std::vector<std::tuple<std::string, t_string, t_string, t_string>> unit::ability_tooltips() const
+{
+	std::vector<std::tuple<std::string, t_string,t_string,t_string>> res;
+
+	for (const config::any_child &ab : this->abilities_.all_children_range())
+	{
+		add_ability_tooltip(ab, gender_, res, true);
+	}
+
+	return res;
+}
+
+std::vector<std::tuple<std::string, t_string, t_string, t_string>> unit::ability_tooltips(boost::dynamic_bitset<>& active_list, const map_location& loc) const
+{
+	std::vector<std::tuple<std::string, t_string,t_string,t_string>> res;
+	active_list.clear();
+
+	for (const config::any_child &ab : this->abilities_.all_children_range())
+	{
+		bool active = ability_active(ab.key, ab.cfg, loc);
+		if (add_ability_tooltip(ab, gender_, res, active))
+		{
+			active_list.push_back(active);
+		}
 	}
 	return res;
 }
@@ -679,13 +706,14 @@ std::string attack_type::weapon_specials(bool only_active, bool is_backstab) con
 	std::string res;
 	for (const config::any_child &sp : specials_.all_children_range())
 	{
-		if ( only_active  &&  !special_active(sp.cfg, AFFECT_EITHER, is_backstab) )
-			continue;
+		const bool active = special_active(sp.cfg, AFFECT_EITHER, is_backstab);
 
 		const std::string& name = sp.cfg["name"].str();
 		if (!name.empty()) {
 			if (!res.empty()) res += ", ";
+			if (only_active && !active) res += font::span_color(font::inactive_details_color);
 			res += name;
+			if (only_active && !active) res += "</span>";
 		}
 	}
 
@@ -760,10 +788,11 @@ attack_type::specials_context_t::specials_context_t(const attack_type& weapon, c
 	weapon.is_for_listing_ = false;
 }
 
-attack_type::specials_context_t::specials_context_t(const attack_type& weapon)
+attack_type::specials_context_t::specials_context_t(const attack_type& weapon, bool attacking)
 	: parent(weapon.shared_from_this())
 {
 	weapon.is_for_listing_ = true;
+	weapon.is_attacker_ = attacking;
 }
 
 attack_type::specials_context_t::~specials_context_t()
@@ -1000,6 +1029,21 @@ bool attack_type::special_active(const config& special, AFFECTS whom,
 	temporary_facing self_facing(self, self_loc_.get_relative_dir(other_loc_));
 	temporary_facing other_facing(other, other_loc_.get_relative_dir(self_loc_));
 
+	// Filter poison, plague, drain
+	if (special["id"] == "drains" && other && other->get_state("undrainable")) {
+		return false;
+	}
+	if (special["id"] == "plague" && other &&
+		(other->get_state("unplagueable") ||
+		 resources::gameboard->map().is_village(other_loc_))) {
+		return false;
+	}
+	if (special["id"] == "poison" && other &&
+		(other->get_state("unpoisonable") || other->get_state(unit::STATE_POISONED))) {
+		return false;
+	}
+
+
 	// Translate our context into terms of "attacker" and "defender".
 	unit_const_ptr & att = is_attacker_ ? self : other;
 	unit_const_ptr & def = is_attacker_ ? other : self;
@@ -1233,7 +1277,7 @@ effect::effect(const unit_ability_list& list, int def, bool backstab) :
 		effect_list_.push_back(val.second);
 	}
 
-	composite_value_ = int((value_set + addition) * multiplier / divisor);
+	composite_value_ = static_cast<int>((value_set + addition) * multiplier / divisor);
 }
 
 } // end namespace unit_abilities
