@@ -71,12 +71,20 @@ static void teleport_unit_between(const map_location& a, const map_location& b,
 	if ( disp.fogged(a) && disp.fogged(b) ) {
 		return;
 	}
+	const display_context& dc = disp.get_disp_context();
+	const team& viewing_team = dc.get_team(disp.viewing_side());
+
+	const bool a_visible = temp_unit.is_visible_to_team(a, viewing_team, dc, false);
+	const bool b_visible = temp_unit.is_visible_to_team(b, viewing_team, dc, false);
 
 	temp_unit.set_location(a);
-	if ( !disp.fogged(a) ) { // teleport
+	if ( a_visible ) { // teleport
 		disp.invalidate(a);
 		temp_unit.set_facing(a.get_relative_dir(b));
-		disp.scroll_to_tiles(a, b, game_display::ONSCREEN, true, 0.0, false);
+		if ( b_visible )
+			disp.scroll_to_tiles(a, b, game_display::ONSCREEN, true, 0.0, false);
+		else
+			disp.scroll_to_tile(a, game_display::ONSCREEN, true, false);
 		unit_animator animator;
 		animator.add_animation(&temp_unit,"pre_teleport",a);
 		animator.start_animations();
@@ -84,10 +92,13 @@ static void teleport_unit_between(const map_location& a, const map_location& b,
 	}
 
 	temp_unit.set_location(b);
-	if ( !disp.fogged(b) ) { // teleport
+	if ( b_visible ) { // teleport
 		disp.invalidate(b);
 		temp_unit.set_facing(a.get_relative_dir(b));
-		disp.scroll_to_tiles(b, a, game_display::ONSCREEN, true, 0.0, false);
+		if ( a_visible )
+			disp.scroll_to_tiles(b, a, game_display::ONSCREEN, true, 0.0, false);
+		else
+			disp.scroll_to_tile(b, game_display::ONSCREEN, true, false);
 		unit_animator animator;
 		animator.add_animation(&temp_unit,"post_teleport",b);
 		animator.start_animations();
@@ -316,10 +327,17 @@ void unit_mover::proceed_to(unit_ptr u, size_t path_index, bool update, bool wai
 	// Safety check.
 	path_index = std::min(path_index, path_.size()-1);
 
-	for ( ; current_ < path_index; ++current_ )
+	for ( ; current_ < path_index; ++current_ ) {
+		// It is possible for path_[current_] and path_[current_+1] not to be adjacent.
+		// When that is the case, and the unit is invisible at path_[current_], we shouldn't
+		// scroll to that hex.
+		std::vector<map_location> locs;
+		if (!temp_unit_ptr_->invisible(path_[current_], disp_->get_disp_context()))
+			locs.push_back(path_[current_]);
+		if (!temp_unit_ptr_->invisible(path_[current_+1], disp_->get_disp_context()))
+			locs.push_back(path_[current_+1]);
 		// If the unit can be seen by the viewing side while making this step:
-		if ( !is_enemy_ || !temp_unit_ptr_->invisible(path_[current_], disp_->get_disp_context()) ||
-		     !temp_unit_ptr_->invisible(path_[current_+1], disp_->get_disp_context()) )
+		if ( !is_enemy_ || !locs.empty() )
 		{
 			// Wait for the previous step to complete before drawing the next one.
 			wait_for_anims();
@@ -333,8 +351,7 @@ void unit_mover::proceed_to(unit_ptr u, size_t path_index, bool update, bool wai
 				// scroll in as much of the remaining path as possible
 				if ( temp_unit_ptr_->anim_comp().get_animation() )
 					temp_unit_ptr_->anim_comp().get_animation()->pause_animation();
-				disp_->scroll_to_tiles(path_.begin() + current_,
-				                       path_.end(), game_display::ONSCREEN,
+				disp_->scroll_to_tiles(locs, game_display::ONSCREEN,
 				                       true, false, 0.0, force_scroll_);
 				if ( temp_unit_ptr_->anim_comp().get_animation() )
 					temp_unit_ptr_->anim_comp().get_animation()->restart_animation();
@@ -350,6 +367,7 @@ void unit_mover::proceed_to(unit_ptr u, size_t path_index, bool update, bool wai
 				teleport_unit_between(path_[current_], path_[current_+1],
 				                      *temp_unit_ptr_, *disp_);
 		}
+	}
 
 	// Update the unit's facing.
 	u->set_facing(temp_unit_ptr_->facing());
@@ -698,20 +716,35 @@ void reset_helpers(const unit *attacker,const unit *defender)
 void unit_recruited(const map_location& loc,const map_location& leader_loc)
 {
 	game_display* disp = game_display::get_singleton();
-	if(!disp || disp->video().update_locked() || disp->video().faked() ||disp->fogged(loc)) return;
+	const display_context& dc = disp->get_disp_context();
+	const team& viewing_team = dc.get_team(disp->viewing_side());
+	if(!disp || disp->video().update_locked() || disp->video().faked() ||
+		(disp->fogged(loc) && disp->fogged(leader_loc))) return;
+
 	unit_map::const_iterator u = disp->get_units().find(loc);
 	if(u == disp->get_units().end()) return;
+	const bool unit_visible = u->is_visible_to_team(viewing_team, dc, false);
+
+	unit_map::const_iterator leader = disp->get_units().find(leader_loc); // may be null_location
+	const bool leader_visible = (leader != disp->get_units().end()) && leader->is_visible_to_team(viewing_team, dc, false);
+
 	u->set_hidden(true);
 
 	unit_animator animator;
-	if(leader_loc != map_location::null_location()) {
-		unit_map::const_iterator leader = disp->get_units().find(leader_loc);
-		if(leader == disp->get_units().end()) return;
+	if (leader_visible && unit_visible) {
 		disp->scroll_to_tiles(loc,leader_loc,game_display::ONSCREEN,true,0.0,false);
-		leader->set_facing(leader_loc.get_relative_dir(loc));
-		animator.add_animation(&*leader, "recruiting", leader_loc, loc, 0, true);
-	} else {
+	} else if (leader_visible) {
+		disp->scroll_to_tile(leader_loc,game_display::ONSCREEN,true,false);
+	} else if (unit_visible) {
 		disp->scroll_to_tile(loc,game_display::ONSCREEN,true,false);
+	} else {
+		return;
+	}
+	if (leader != disp->get_units().end()) {
+		leader->set_facing(leader_loc.get_relative_dir(loc));
+		if (leader_visible) {
+			animator.add_animation(&*leader, "recruiting", leader_loc, loc, 0, true);
+		}
 	}
 
 	disp->draw();
