@@ -959,7 +959,7 @@ void unit::advance_to(const unit_type& u_type, bool use_traits)
 	max_attacks_ = new_type.max_attacks();
 
 	flag_rgb_ = new_type.flag_rgb();
-	
+
 	upkeep_ = upkeep_full();
 	parse_upkeep(new_type.get_cfg()["upkeep"]);
 
@@ -1037,7 +1037,7 @@ static color_t hp_color_impl(int hitpoints, int max_hitpoints)
 	color_t energy_color {0,0,0,255};
 
 	if(max_hitpoints > 0) {
-		unit_energy = double(hitpoints)/double(max_hitpoints);
+		unit_energy = static_cast<double>(hitpoints)/static_cast<double>(max_hitpoints);
 	}
 
 	if(1.0 == unit_energy) {
@@ -1514,7 +1514,7 @@ void unit::write(config& cfg) const
 
 void unit::set_facing(map_location::DIRECTION dir) const
 {
-	if(dir != map_location::NDIRECTIONS) {
+	if(dir != map_location::NDIRECTIONS && dir != facing_) {
 		appearance_changed_ = true;
 		facing_ = dir;
 	}
@@ -1669,7 +1669,7 @@ std::vector<config> unit::get_modification_advances() const
 			continue;
 		}
 
-		if(modification_count("advancement", adv["id"]) >= unsigned(adv["max_times"].to_int(1))) {
+		if(modification_count("advancement", adv["id"]) >= static_cast<unsigned>(adv["max_times"].to_int(1))) {
 			continue;
 		}
 
@@ -1865,7 +1865,7 @@ void unit::apply_builtin_effect(std::string apply_to, const config& effect)
 		const bool violate_max = effect["violate_maximum"].to_bool();
 
 		if(!set_hp.empty()) {
-			if(set_hp[set_hp.size()-1] == '%') {
+			if(set_hp.back() == '%') {
 				hit_points_ = lexical_cast_default<int>(set_hp)*max_hit_points_/100;
 			} else {
 				hit_points_ = lexical_cast_default<int>(set_hp);
@@ -1873,7 +1873,7 @@ void unit::apply_builtin_effect(std::string apply_to, const config& effect)
 		}
 
 		if(!set_total.empty()) {
-			if(set_total[set_total.size()-1] == '%') {
+			if(set_total.back() == '%') {
 				max_hit_points_ = lexical_cast_default<int>(set_total)*max_hit_points_/100;
 			} else {
 				max_hit_points_ = lexical_cast_default<int>(set_total);
@@ -1939,7 +1939,7 @@ void unit::apply_builtin_effect(std::string apply_to, const config& effect)
 		const std::string& set = effect["set"];
 
 		if(!set.empty()) {
-			if(set[set.size()-1] == '%') {
+			if(set.back() == '%') {
 				experience_ = lexical_cast_default<int>(set)*max_experience_/100;
 			} else {
 				experience_ = lexical_cast_default<int>(set);
@@ -1954,7 +1954,7 @@ void unit::apply_builtin_effect(std::string apply_to, const config& effect)
 		const std::string& set = effect["set"];
 
 		if(set.empty() == false) {
-			if(set[set.size()-1] == '%') {
+			if(set.back() == '%') {
 				max_experience_ = lexical_cast_default<int>(set)*max_experience_/100;
 			} else {
 				max_experience_ = lexical_cast_default<int>(set);
@@ -1979,27 +1979,10 @@ void unit::apply_builtin_effect(std::string apply_to, const config& effect)
 		{
 			set_state(to_remove, false);
 		}
-	// Note: It would not be hard to define a new "applies_to=" that
-	//       combines the next five options (the movetype effects).
-	} else if(apply_to == "movement_costs") {
-		if(const config& ap = effect.child("movement_costs")) {
-			movement_type_.get_movement().merge(ap, effect["replace"].to_bool());
-		}
-	} else if(apply_to == "vision_costs") {
-		if(const config& ap = effect.child("vision_costs")) {
-			movement_type_.get_vision().merge(ap, effect["replace"].to_bool());
-		}
-	} else if(apply_to == "jamming_costs") {
-		if(const config& ap = effect.child("jamming_costs")) {
-			movement_type_.get_jamming().merge(ap, effect["replace"].to_bool());
-		}
-	} else if(apply_to == "defense") {
-		if(const config& ap = effect.child("defense")) {
-			movement_type_.get_defense().merge(ap, effect["replace"].to_bool());
-		}
-	} else if(apply_to == "resistance") {
-		if(const config& ap = effect.child("resistance")) {
-			movement_type_.get_resistances().merge(ap, effect["replace"].to_bool());
+	} else if(std::find(movetype::effects.cbegin(), movetype::effects.cend(), apply_to) != movetype::effects.cend()) {
+		// "movement_costs", "vision_costs", "jamming_costs", "defense", "resistance"
+		if(const config& ap = effect.child(apply_to)) {
+			movement_type_.merge(ap, apply_to, effect["replace"].to_bool());
 		}
 	} else if(apply_to == "zoc") {
 		if(const config::attribute_value* v = effect.get("value")) {
@@ -2117,7 +2100,7 @@ void unit::apply_builtin_effect(std::string apply_to, const config& effect)
 		const int recall_cost = recall_cost_ < 0 ? resources::gameboard->teams().at(side_).recall_cost() : recall_cost_;
 
 		if(!set.empty()) {
-			if(set[set.size()-1] == '%') {
+			if(set.back() == '%') {
 				recall_cost_ = lexical_cast_default<int>(set)*recall_cost/100;
 			} else {
 				recall_cost_ = lexical_cast_default<int>(set);
@@ -2256,7 +2239,9 @@ void unit::add_modification(const std::string& mod_type, const config& mod, bool
 			description += "\n";
 		}
 
-		description += utils::format_conjunct_list("", effects_description);
+		for(const auto& desc_line : effects_description) {
+			description += desc_line + "\n";
+		}
 	}
 
 	// store trait info
@@ -2358,6 +2343,11 @@ bool unit::invisible(const map_location& loc, const display_context& dc, bool se
 bool unit::is_visible_to_team(const team& team,const  display_context& dc, bool const see_all) const
 {
 	const map_location& loc = get_location();
+	return is_visible_to_team(loc, team, dc, see_all);
+}
+
+bool unit::is_visible_to_team(const map_location& loc, const team& team, const  display_context& dc, bool const see_all) const
+{
 	if(!dc.map().on_board(loc)) {
 		return false;
 	}
@@ -2535,7 +2525,7 @@ void unit::parse_upkeep(const config::attribute_value& upkeep)
 	} else if(upkeep == upkeep_full::type()) {
 		upkeep_ = upkeep_full();
 	} else {
-		WRN_UT << "Fund invalid upkeep=\"" << upkeep <<  "\" in a unit" << std::endl;
+		WRN_UT << "Found invalid upkeep=\"" << upkeep <<  "\" in a unit" << std::endl;
 		upkeep_ = upkeep_full();
 	}
 }
