@@ -1495,17 +1495,28 @@ public:
 	}
 
 	/**
-	 * Gets the names and descriptions of this unit's abilities.
+	 * Gets the names and descriptions of this unit's abilities. Location-independent variant
+	 * with all abilities shown as active.
 	 *
-	 * @param active_list         If nullptr, then all abilities are forced active. If not, this vector
-	 *                            will be the same length as the returned one and will indicate whether or
-	 *                            not the corresponding ability is active.
-	 *
-	 * @returns                   A list of triples consisting of (in order) id, base name, male or female
-	 *                            name as appropriate for the unit, and description.
+	 * @returns                   A list of quadruples consisting of (in order) id, base name,
+	 *                            male or female name as appropriate for the unit, and description.
 	 */
 	std::vector<std::tuple<std::string, t_string, t_string, t_string>>
-	ability_tooltips(boost::dynamic_bitset<>* active_list = nullptr) const;
+	ability_tooltips() const;
+
+	/**
+	 * Gets the names and descriptions of this unit's abilities.
+	 *
+	 * @param active_list         This vector will be the same length as the returned one and will
+	 *                            indicate whether or not the corresponding ability is active.
+	 *
+	 * @param loc                 The location on which to resolve the ability.
+	 *
+	 * @returns                   A list of quadruples consisting of (in order) id, base name,
+	 *                            male or female name as appropriate for the unit, and description.
+	 */
+	std::vector<std::tuple<std::string, t_string, t_string, t_string>>
+	ability_tooltips(boost::dynamic_bitset<>& active_list, const map_location& loc) const;
 
 	/** Get a list of all abilities by ID. */
 	std::vector<std::string> get_ability_list() const;
@@ -1571,6 +1582,8 @@ public:
 	bool invisible(const map_location& loc, const display_context& dc, bool see_all = true) const;
 
 	bool is_visible_to_team(const team& team, const display_context& dc, bool const see_all = true) const;
+	/// Return true if the unit would be visible to team if its location were loc.
+	bool is_visible_to_team(const map_location& loc, const team& team, const display_context& dc, bool const see_all = true) const;
 
 	/**
 	 * Serializes the current unit metadata values.
