@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2004 - 2015 by Philippe Plantier <ayin@anathas.org>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org
+   Copyright (C) 2004 - 2018 by Philippe Plantier <ayin@anathas.org>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
    See the COPYING file for more details.
 */
 
-#ifndef UTILS_REFERENCE_COUTER_H_INCLUDED
-#define UTILS_REFERENCE_COUTER_H_INCLUDED
+#pragma once
 
 /**
  * @file
@@ -21,27 +20,26 @@
 
 
 #include <limits>
-#include <boost/static_assert.hpp>
 
 namespace n_ref_counter {
 
 
 /**
-   @class t_ref_counter
-   @brief t_ref_counter is a reference counter.  If the counter overflows it stops counting.
+   @class ref_counter
+   @brief ref_counter is a reference counter.  If the counter overflows it stops counting.
    So any negative count disables reference counting.
 **/
-template <typename T_integral> class t_ref_counter {
-	BOOST_STATIC_ASSERT( std::numeric_limits<T_integral>::is_signed);
+template <typename T_integral> class ref_counter {
+	static_assert(std::numeric_limits<T_integral>::is_signed, "Reference counter must be a signed integer");
 
 	T_integral count_;
 
 public:
 	enum {NEW=0, NOT_COUNTED = -1};
 
-	explicit t_ref_counter(T_integral x = 0) : count_(x) {}
-	t_ref_counter(t_ref_counter const &a) : count_(a.count_) {}
-	t_ref_counter & operator=(t_ref_counter const &a){count_ = a.count_; return *this;}
+	explicit ref_counter(T_integral x = 0) : count_(x) {}
+	ref_counter(const ref_counter& a) : count_(a.count_) {}
+	ref_counter & operator=(const ref_counter& a){count_ = a.count_; return *this;}
 
 	operator T_integral const () const {return count_;}
 
@@ -67,5 +65,3 @@ public:
 
 
 }//end namepace
-
-#endif
