@@ -66,7 +66,7 @@
 #include <fenv.h>
 #endif // _MSC_VER
 
-#include <SDL.h> // for SDL_Init, SDL_INIT_TIMER
+#include <SDL2/SDL.h> // for SDL_Init, SDL_INIT_TIMER
 
 #include <boost/iostreams/categories.hpp>   // for input, output
 #include <boost/iostreams/copy.hpp>         // for copy
@@ -116,10 +116,6 @@
 
 #include <windows.h>
 
-#if defined(_OPENMP) && _MSC_VER >= 1600
-#include <process.h>
-#endif
-
 #endif // _WIN32
 
 #ifdef DEBUG_WINDOW_LAYOUT_GRAPHS
@@ -449,11 +445,6 @@ static int process_command_args(const commandline_options& cmdline_opts)
 		return 0;
 	}
 
-	if(cmdline_opts.path) {
-		std::cout << game_config::path << "\n";
-		return 0;
-	}
-
 	if(cmdline_opts.log_precise_timestamps) {
 		lg::precise_timestamps(true);
 	}
@@ -963,42 +954,6 @@ static void wesnoth_terminate_handler(int)
 }
 #endif
 
-#if defined(_OPENMP) && _MSC_VER >= 1600
-static void restart_process()
-{
-	wchar_t process_path[MAX_PATH];
-	SetLastError(ERROR_SUCCESS);
-	GetModuleFileNameW(nullptr, process_path, MAX_PATH);
-
-	if(GetLastError() != ERROR_SUCCESS) {
-		throw std::runtime_error("Failed to retrieve the process path");
-	}
-
-	std::wstring commandline_str(GetCommandLineW());
-
-	// CreateProcessW is allowed to modify the passed command line.
-	// Therefore we need to copy it.
-	wchar_t* commandline_c_str = new wchar_t[commandline_str.length() + 1];
-	commandline_str.copy(commandline_c_str, commandline_str.length());
-	commandline_c_str[commandline_str.length()] = L'\0';
-
-	STARTUPINFOW startup_info;
-	ZeroMemory(&startup_info, sizeof(startup_info));
-	startup_info.cb = sizeof(startup_info);
-
-	PROCESS_INFORMATION process_info;
-	ZeroMemory(&process_info, sizeof(process_info));
-
-	CreateProcessW(
-		process_path, commandline_c_str, nullptr, nullptr, false, 0u, nullptr, nullptr, &startup_info, &process_info);
-
-	CloseHandle(process_info.hProcess);
-	CloseHandle(process_info.hThread);
-
-	std::exit(EXIT_SUCCESS);
-}
-#endif
-
 #ifdef _WIN32
 #define error_exit(res)                                                                                                \
 	do {                                                                                                               \
@@ -1020,8 +975,8 @@ int main(int argc, char** argv)
 #endif
 {
 #ifdef _WIN32
-	(void)argc;
-	(void)argv;
+	UNUSED(argc);
+	UNUSED(argv);
 
 	// windows argv is ansi encoded by default
 	std::vector<std::string> args =
@@ -1035,7 +990,6 @@ int main(int argc, char** argv)
 		if(args[k] == "--wconsole" ||
 		   args[k] == "--help" ||
 		   args[k] == "--logdomains" ||
-		   args[k] == "--path" ||
 		   args[k] == "--render-image" ||
 		   args[k] == "--report" ||
 		   args[k] == "-R" ||
@@ -1060,32 +1014,6 @@ int main(int argc, char** argv)
 
 	assert(!args.empty());
 
-#ifdef _OPENMP
-	// Wesnoth is a special case for OMP
-	// OMP wait strategy is to have threads busy-loop for 100ms
-	// if there is nothing to do, they then go to sleep.
-	// this avoids the scheduler putting the thread to sleep when work
-	// is about to be available
-	//
-	// However Wesnoth has a lot of very small jobs that need to be done
-	// at each redraw => 50fps every 2ms.
-	// All the threads are thus busy-waiting all the time, hogging the CPU
-	// To avoid that problem, we need to set the OMP_WAIT_POLICY env var
-	// but that var is read by OMP at library loading time (before main)
-	// thus the relaunching of ourselves after setting the variable.
-#if !defined(_WIN32) && !defined(__APPLE__)
-	if(!getenv("OMP_WAIT_POLICY")) {
-		setenv("OMP_WAIT_POLICY", "PASSIVE", 1);
-		execv(argv[0], argv);
-	}
-#elif _MSC_VER >= 1600
-	if(!getenv("OMP_WAIT_POLICY")) {
-		_putenv_s("OMP_WAIT_POLICY", "PASSIVE");
-		restart_process();
-	}
-#endif
-#endif //_OPENMP
-
 	filesystem::init();
 
 	if(SDL_Init(SDL_INIT_TIMER) < 0) {
@@ -1105,11 +1033,11 @@ int main(int argc, char** argv)
 
 	// Mac's touchpad generates touch events too.
 	// Ignore them until Macs have a touchscreen: https://forums.libsdl.org/viewtopic.php?p=45758
-#if defined(__APPLE__) && !defined(__IPHONEOS__) 
+#if defined(__APPLE__) && !defined(__IPHONEOS__)
 	SDL_EventState(SDL_FINGERMOTION, SDL_DISABLE);
 	SDL_EventState(SDL_FINGERDOWN, SDL_DISABLE);
 	SDL_EventState(SDL_FINGERUP, SDL_DISABLE);
-#endif	
+#endif
 
 	// declare this here so that it will always be at the front of the event queue.
 	events::event_context global_context;
