@@ -1,6 +1,6 @@
 /*
- Copyright (C) 2010 - 2015 by Gabriel Morin <gabrielmorin (at) gmail (dot) com>
- Part of the Battle for Wesnoth Project http://www.wesnoth.org
+ Copyright (C) 2010 - 2018 by Gabriel Morin <gabrielmorin (at) gmail (dot) com>
+ Part of the Battle for Wesnoth Project https://www.wesnoth.org
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -16,10 +16,11 @@
  * @file
  */
 
-#ifndef WB_ACTION_HPP_
-#define WB_ACTION_HPP_
+#pragma once
 
 #include "typedefs.hpp"
+#include "map/location.hpp"
+#include "game_errors.hpp"
 
 namespace wb {
 
@@ -28,11 +29,11 @@ class visitor;
 /**
  * Abstract base class for all the whiteboard planned actions.
  */
-class action : public boost::enable_shared_from_this<action>
+class action : public std::enable_shared_from_this<action>
 {
 public:
 	action(size_t team_index, bool hidden);
-	action(config const&, bool hidden); // For deserialization
+	action(const config&, bool hidden); // For deserialization
 	virtual ~action();
 
 	virtual std::ostream& print(std::ostream& s) const = 0;
@@ -66,13 +67,15 @@ public:
 	virtual map_location get_numbering_hex() const = 0;
 
 	/** Return the unit targeted by this action. Null if unit doesn't exist. */
-	virtual unit* get_unit() const = 0;
+	virtual unit_ptr get_unit() const = 0;
 
+	/** Returns true for recall and recruit actions */
+	virtual bool places_new_unit() const { return false; };
 	/**
 	 * Returns the id of the unit targeted by this action.
 	 * @retval 0 no unit is targeted.
 	 */
-	size_t get_unit_id() const;
+	virtual size_t get_unit_id() const;
 
 	/** @return pointer to the fake unit used only for visuals */
 	virtual fake_unit_ptr get_fake_unit() = 0;
@@ -87,7 +90,7 @@ public:
 	/** Constructs and returns a config object representing this object. */
 	virtual config to_config() const;
 	/** Constructs an object of a subclass of wb::action using a config. Current behavior is to return a null pointer for unrecognized config. */
-	static action_ptr from_config(config const&, bool hidden);
+	static action_ptr from_config(const config&, bool hidden);
 
 	struct ctor_err	: public game::error
 	{
@@ -143,5 +146,3 @@ std::ostream& operator<<(std::ostream& s, action_ptr action);
 std::ostream& operator<<(std::ostream& s, action_const_ptr action);
 
 } // end namespace wb
-
-#endif /* WB_ACTION_HPP_ */
