@@ -1,6 +1,6 @@
 /*
- Copyright (C) 2010 - 2015 by Gabriel Morin <gabrielmorin (at) gmail (dot) com>
- Part of the Battle for Wesnoth Project http://www.wesnoth.org
+ Copyright (C) 2010 - 2018 by Gabriel Morin <gabrielmorin (at) gmail (dot) com>
+ Part of the Battle for Wesnoth Project https://www.wesnoth.org
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -16,10 +16,10 @@
  * @file
  */
 
-#ifndef WB_HIGHLIGHTER_HPP_
-#define WB_HIGHLIGHTER_HPP_
+#pragma once
 
 #include "visitor.hpp"
+#include "map/location.hpp"
 
 static lg::log_domain log_whiteboard_highlight("whiteboard/highlight");
 #define ERR_WB_H LOG_STREAM(err, log_whiteboard_highlight)
@@ -38,7 +38,7 @@ class highlighter
 {
 
 public:
-	highlighter(unit_map& unit_map, side_actions_ptr side_actions);
+	highlighter(side_actions_ptr side_actions);
 	virtual ~highlighter();
 
 	void set_mouseover_hex(const map_location& hex);
@@ -50,7 +50,7 @@ public:
 	action_ptr get_execute_target();
 	action_ptr get_delete_target();
 	action_ptr get_bump_target();
-	unit* get_selection_target();
+	unit_ptr get_selection_target();
 
 	/// @return the action that currently receives the highlight focus
 	weak_action_ptr get_main_highlight() { return main_highlight_; }
@@ -58,7 +58,10 @@ public:
 	/// @return the collection of actions that are highlighted but don't have the focus
 	secondary_highlights_t get_secondary_highlights() { return secondary_highlights_; }
 
+	void set_selection_candidate(unit_ptr candidate) { selection_candidate_ = candidate; }
+
 private:
+	unit_map& get_unit_map();
 	/** Unhighlight a given action (main or secondary). */
 	class unhighlight_visitor;
 
@@ -75,12 +78,10 @@ private:
 	/** Redraw the given move action when needed. */
 	void last_action_redraw(move_ptr);
 
-	unit_map& unit_map_;
-
 	map_location mouseover_hex_;
 	std::set<map_location> exclusive_display_hexes_;
-	unit* owner_unit_;
-	unit* selection_candidate_;
+	unit_ptr owner_unit_;
+	unit_ptr selection_candidate_;
 
 	weak_action_ptr selected_action_;
 	weak_action_ptr main_highlight_;
@@ -127,5 +128,3 @@ private:
 };
 
 } // end namespace wb
-
-#endif /* WB_HIGHLIGHTER_HPP_ */
