@@ -1,6 +1,6 @@
 /*
-   Copyright (C) 2003 - 2015 by David White <dave@whitevine.net>
-   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+   Copyright (C) 2003 - 2018 by David White <dave@whitevine.net>
+   Part of the Battle for Wesnoth Project https://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,12 +11,13 @@
 
    See the COPYING file for more details.
 */
-#ifndef BUTTON_H_INCLUDED
-#define BUTTON_H_INCLUDED
+
+#pragma once
 
 #include "widget.hpp"
 
-#include "../exceptions.hpp"
+#include "exceptions.hpp"
+
 
 namespace gui {
 
@@ -30,6 +31,7 @@ public:
     };
 
 	enum TYPE { TYPE_PRESS, TYPE_CHECK, TYPE_TURBO, TYPE_IMAGE, TYPE_RADIO };
+	TYPE get_type() const { return type_; }
 
 	enum SPACE_CONSUMPTION { DEFAULT_SPACE, MINIMUM_SPACE };
 
@@ -47,7 +49,7 @@ public:
 	void set_label(const std::string& val);
 	void set_image(const std::string& image_file_base);
 	void set_overlay(const std::string& image_file_base);
-	const std::string& overlay() const;
+	void set_image_path_suffix(const std::string& suffix) { button_image_path_suffix_ = suffix; load_images(); }
 
 	bool pressed();
 	bool hit(int x, int y) const;
@@ -69,7 +71,8 @@ private:
 
 	void calculate_size();
 
-	std::string label_;
+	std::string label_text_;
+
 	surface image_, pressedImage_, activeImage_, pressedActiveImage_,
 		touchedImage_, disabledImage_, pressedDisabledImage_,
 		overlayImage_, overlayPressedImage_, overlayPressedDisabledImage_, overlayDisabledImage_,
@@ -87,9 +90,8 @@ private:
 
 	std::string button_image_name_;
 	std::string button_overlay_image_name_;
+	std::string button_image_path_suffix_;
 
 }; //end class button
 
 }
-
-#endif
