@@ -60,7 +60,7 @@ void textbox::update_location(const SDL_Rect& rect)
 void textbox::set_inner_location(const SDL_Rect& rect)
 {
 	bg_register(rect);
-	if (text_image_.null()) return;
+	if (!text_image_) return;
 	text_pos_ = 0;
 	update_text_cache(false);
 }
@@ -99,7 +99,7 @@ void textbox::append_text(const std::string& text, bool auto_scroll, const color
 	const ucs4::string& wtext = unicode_cast<ucs4::string>(text);
 
 	surface new_text = add_text_line(wtext, color);
-	surface new_surface = create_compatible_surface(text_image_,std::max<size_t>(text_image_->w,new_text->w),text_image_->h+new_text->h);
+	surface new_surface(std::max<size_t>(text_image_->w,new_text->w),text_image_->h+new_text->h);
 
 	adjust_surface_alpha(new_text, SDL_ALPHA_TRANSPARENT);
 	adjust_surface_alpha(text_image_, SDL_ALPHA_TRANSPARENT);
@@ -115,7 +115,7 @@ void textbox::append_text(const std::string& text, bool auto_scroll, const color
 	};
 	SDL_SetSurfaceBlendMode(new_text, SDL_BLENDMODE_NONE);
 	sdl_blit(new_text,nullptr,new_surface,&target);
-	text_image_.assign(new_surface);
+	text_image_ = new_surface;
 
 	text_.insert(text_.end(), wtext.begin(), wtext.end());
 
@@ -371,7 +371,7 @@ void textbox::update_text_cache(bool changed, const color_t& color)
 		char_x_.clear();
 		char_y_.clear();
 
-		text_image_.assign(add_text_line(text_, color));
+		text_image_ = add_text_line(text_, color);
 	}
 
 	int cursor_x = char_x_[cursor_];
@@ -383,7 +383,7 @@ void textbox::update_text_cache(bool changed, const color_t& color)
 	}
 	cursor_pos_ = cursor_x - text_pos_;
 
-	if (!text_image_.null()) {
+	if (text_image_) {
 		set_full_size(text_image_->h);
 		set_shown_size(location().h);
 	}
