@@ -30,14 +30,6 @@ namespace gui {
 
 bool widget::mouse_lock_ = false;
 
-widget::widget(const widget &o)
-	: events::sdl_handler(), focus_(o.focus_), video_(o.video_), restorer_(o.restorer_), rect_(o.rect_),
-	   needs_restore_(o.needs_restore_), state_(o.state_), hidden_override_(o.hidden_override_),
-	  enabled_(o.enabled_), clip_(o.clip_), clip_rect_(o.clip_rect_), volatile_(o.volatile_),
-	  help_text_(o.help_text_), tooltip_text_(o.tooltip_text_), help_string_(o.help_string_), id_(o.id_), mouse_lock_local_(o.mouse_lock_local_)
-{
-}
-
 widget::widget(CVideo& video, const bool auto_join)
 	: events::sdl_handler(auto_join), focus_(true), video_(&video), rect_(EmptyRect), needs_restore_(false),
 	  state_(UNINIT), hidden_override_(false), enabled_(true), clip_(false),
