@@ -257,14 +257,17 @@ website_stringfixes = {
 # any time soon.
 
 # Source
-("wesnoth-1.14.3/wesnoth-1.14.3.tar.bz2", "wesnoth-1.14.4/wesnoth-1.14.4.tar.bz2"),
-("450.2 MB", "450.6"),
+("wesnoth-1.14.6/wesnoth-1.14.6.tar.bz2", "wesnoth-1.14.7/wesnoth-1.14.7.tar.bz2"),
+("451.8", "452.7"),
 # Windows
-("wesnoth-1.14.3/wesnoth-1.14.3-win32.exe", "wesnoth-1.14.4/wesnoth-1.14.4-win32.exe"),
-("407.9 MB", "408.2"),
+("wesnoth-1.14.6/wesnoth-1.14.6-win32.exe", "wesnoth-1.14.7/wesnoth-1.14.7-win32.exe"),
+("408.3", "408.2"),
 # macOS
-("wesnoth-1.14.3/Wesnoth_1.14.3a.dmg", "wesnoth-1.14.4/Wesnoth_1.14.4.dmg"),
-("468.2 MB", "466.9"),
+("wesnoth-1.14.7/Wesnoth_1.14.7a.dmg", "wesnoth-1.14.7/Wesnoth_1.14.8a.dmg"),
+("466.0", "465.6"),
+
+("&#169; 2003&#8211;2018", "&#169; 2003&#8211;2019"),
+("&#169; 2017&#8211;2018", "&#169; 2017&#8211;2019"),
 ),
 
 }
@@ -294,6 +297,7 @@ except ImportError:
 def process_file(path):
     before = io.open(path, "r", encoding="utf-8").read()
     decommented = re.sub("#.*", "", before)
+    decommented_msgids = re.sub(r'^msgstr .*?' + '\n\n', '', decommented, flags = re.MULTILINE | re.DOTALL)
     lines = before.split('\n')
     if website_mode:
         stringfixes = website_stringfixes
@@ -314,7 +318,7 @@ def process_file(path):
             #lead to "real" probs not found, the real check would be "does replacing
             #old with new lead to duplicate msgids? (including old ones marked with #~)"
             #which is not easily done in the current design...
-            elif new in decommented and old in decommented and not new in old:
+            elif new in decommented_msgids and old in decommented_msgids and not new in old:
                 print ("pofix: %s already includes the new string\n\t\"%s\"\nbut also the old\n\t\"%s\"\nthis needs handfixing for now since it likely creates duplicate msgids." % (path, new, old))
             else:
                 for (i, line) in enumerate(lines):
