@@ -5,7 +5,8 @@ set -ev
 if [[ $TRAVIS_OS_NAME == 'osx' ]]; then
 
 	brew update
-	brew install scons cairo pango moreutils sdl2_image sdl2_ttf sdl2_mixer openssl
+	brew install scons cairo pango moreutils sdl2_image sdl2_ttf sdl2_mixer
+  brew reinstall libffi
 
 else
 
