@@ -11,7 +11,7 @@ if [ "$TRAVIS_OS_NAME" = "osx" ]; then
         export CCACHE_MAXSIZE=2G
         export CCACHE_COMPILERCHECK=content
 
-        xcodebuild -project Wesnoth.xcodeproj -target Wesnoth -configuration Debug
+        xcodebuild -project "The Battle for Wesnoth.xcodeproj" -target "The Battle for Wesnoth" -configuration Debug
 
         BUILD_RET=$?
 
@@ -24,13 +24,16 @@ if [ "$TRAVIS_OS_NAME" = "osx" ]; then
         ./utils/travis/check_utf8.sh
         ./utils/travis/utf8_bom_dog.sh
         "$CXX" --version
+        export PKG_CONFIG_PATH="/usr/local/opt/libffi/lib/pkgconfig"
+        
         scons wesnoth wesnothd campaignd boost_unit_tests build=release \
               ctool="$CC" cxxtool="$CXX" cxx_std="$CXXSTD" \
               extra_flags_config="-pipe" extra_flags_release="$EXTRA_FLAGS_RELEASE" strict=true \
               nls="$NLS" enable_lto="$LTO" jobs=2 --debug=time
     fi
 else
-    docker run -v "$HOME"/build-cache:/home/wesnoth-travis/build \
+    docker run --cap-add=SYS_PTRACE \
+               -v "$HOME"/build-cache:/home/wesnoth-travis/build \
                -v "$HOME"/.ccache:/root/.ccache wesnoth-repo:"$LTS"-"$BRANCH" \
                bash -c './utils/travis/docker_run.sh "$@"' \
                bash "$NLS" "$TOOL" "$CC" "$CXX" "$CXXSTD" "$EXTRA_FLAGS_RELEASE" "$WML_TESTS" "$WML_TEST_TIME" "$PLAY_TEST" "$MP_TEST" "$BOOST_TEST" "$LTO"
